@@ -26,7 +26,8 @@
 #include <gio/gio.h>
 #endif
 
-#include "gegl-types.h"
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
@@ -36,6 +37,7 @@
 #include "gegl-sampler-linear.h"
 #include "gegl-sampler-cubic.h"
 #include "gegl-sampler-lanczos.h"
+#include "gegl-sampler-sharp.h"
 #include "gegl-sampler-yafr.h"
 #include "gegl-buffer-index.h"
 #include "gegl-tile-backend.h"
@@ -45,29 +47,19 @@
 GStaticRecMutex mutex = G_STATIC_REC_MUTEX_INIT;
 #endif
 
-#ifdef BABL
-#undef BABL
-#endif
-
-#define BABL(o)     ((Babl *) (o))
-
-#ifdef FMTPXS
-#undef FMTPXS
-#endif
-#define FMTPXS(fmt)    (BABL (fmt)->format.bytes_per_pixel)
 
 #if 0
 static inline void
-pset (GeglBuffer *buffer,
-      gint        x,
-      gint        y,
-      const Babl *format,
-      guchar     *buf)
+gegl_buffer_pixel_set (GeglBuffer *buffer,
+                       gint        x,
+                       gint        y,
+                       const Babl *format,
+                       guchar     *buf)
 {
   gint  tile_width  = buffer->tile_storage->tile_width;
   gint  tile_height  = buffer->tile_storage->tile_width;
   gint  px_size     = gegl_buffer_px_size (buffer);
-  gint  bpx_size    = FMTPXS (format);
+  gint  bpx_size    = babl_format_get_bytes_per_pixel (format);
   Babl *fish        = NULL;
 
   gint  abyss_x_total  = buffer->abyss.x + buffer->abyss.width;
@@ -123,26 +115,44 @@ pset (GeglBuffer *buffer,
 }
 #endif
 
-static inline void
-pset (GeglBuffer *buffer,
-      gint        x,
-      gint        y,
-      const Babl *format,
-      gpointer    data)
+static gboolean
+gegl_buffer_in_abyss( GeglBuffer *buffer,
+                      gint        x,
+                      gint        y )
 {
-  guchar *buf         = data;
-  gint    tile_width  = buffer->tile_storage->tile_width;
-  gint    tile_height = buffer->tile_storage->tile_height;
-  gint    bpx_size    = FMTPXS (format);
-  Babl   *fish        = NULL;
-
   gint  buffer_shift_x = buffer->shift_x;
   gint  buffer_shift_y = buffer->shift_y;
   gint  buffer_abyss_x = buffer->abyss.x + buffer_shift_x;
   gint  buffer_abyss_y = buffer->abyss.y + buffer_shift_y;
   gint  abyss_x_total  = buffer_abyss_x + buffer->abyss.width;
   gint  abyss_y_total  = buffer_abyss_y + buffer->abyss.height;
-  gint  px_size        = FMTPXS (buffer->format);
+
+
+  gint tiledy = y + buffer_shift_y;
+  gint tiledx = x + buffer_shift_x;
+
+  return !(tiledy >= buffer_abyss_y &&
+           tiledy <  abyss_y_total  &&
+           tiledx >= buffer_abyss_x &&
+           tiledx <  abyss_x_total);
+}
+
+static inline void
+gegl_buffer_set_pixel (GeglBuffer *buffer,
+                       gint        x,
+                       gint        y,
+                       const Babl *format,
+                       gpointer    data)
+{
+  guchar *buf         = data;
+  gint    tile_width  = buffer->tile_storage->tile_width;
+  gint    tile_height = buffer->tile_storage->tile_height;
+  gint    bpx_size    = babl_format_get_bytes_per_pixel (format);
+  Babl   *fish        = NULL;
+
+  gint  buffer_shift_x = buffer->shift_x;
+  gint  buffer_shift_y = buffer->shift_y;
+  gint  px_size        = babl_format_get_bytes_per_pixel (buffer->format);
 
   if (format != buffer->format)
     {
@@ -154,10 +164,7 @@ pset (GeglBuffer *buffer,
     gint tiledy   = y + buffer_shift_y;
     gint tiledx   = x + buffer_shift_x;
 
-    if (!(tiledy >= buffer_abyss_y &&
-          tiledy  < abyss_y_total &&
-          tiledx >= buffer_abyss_x &&
-          tiledx  < abyss_x_total))
+    if (gegl_buffer_in_abyss( buffer, x, y))
       { /* in abyss */
         return;
       }
@@ -208,25 +215,21 @@ pset (GeglBuffer *buffer,
 }
 
 static inline void
-pget (GeglBuffer *buffer,
-      gint        x,
-      gint        y,
-      const Babl *format,
-      gpointer    data)
+gegl_buffer_get_pixel (GeglBuffer *buffer,
+                       gint        x,
+                       gint        y,
+                       const Babl *format,
+                       gpointer    data)
 {
   guchar *buf         = data;
   gint    tile_width  = buffer->tile_storage->tile_width;
   gint    tile_height = buffer->tile_storage->tile_height;
-  gint    bpx_size    = FMTPXS (format);
+  gint    bpx_size    = babl_format_get_bytes_per_pixel (format);
   Babl   *fish        = NULL;
 
   gint  buffer_shift_x = buffer->shift_x;
   gint  buffer_shift_y = buffer->shift_y;
-  gint  buffer_abyss_x = buffer->abyss.x + buffer_shift_x;
-  gint  buffer_abyss_y = buffer->abyss.y + buffer_shift_y;
-  gint  abyss_x_total  = buffer_abyss_x + buffer->abyss.width;
-  gint  abyss_y_total  = buffer_abyss_y + buffer->abyss.height;
-  gint  px_size        = FMTPXS (buffer->format);
+  gint  px_size        = babl_format_get_bytes_per_pixel (buffer->format);
 
   if (format != buffer->format)
     {
@@ -238,10 +241,7 @@ pget (GeglBuffer *buffer,
     gint tiledy = y + buffer_shift_y;
     gint tiledx = x + buffer_shift_x;
 
-    if (!(tiledy >= buffer_abyss_y &&
-          tiledy <  abyss_y_total  &&
-          tiledx >= buffer_abyss_x &&
-          tiledx <  abyss_x_total))
+    if (gegl_buffer_in_abyss (buffer, x, y))
       { /* in abyss */
         memset (buf, 0x00, bpx_size);
         return;
@@ -316,19 +316,18 @@ gegl_buffer_flush (GeglBuffer *buffer)
 
 
 static void inline
-gegl_buffer_iterate (GeglBuffer *buffer,
-                     guchar     *buf,
-                     gint        rowstride,
-                     gboolean    write,
-                     const Babl *format,
-                     gint        level)
+gegl_buffer_iterate (GeglBuffer          *buffer,
+                     const GeglRectangle *roi, /* or NULL for extent */
+                     guchar              *buf,
+                     gint                 rowstride,
+                     gboolean             write,
+                     const Babl          *format,
+                     gint                 level)
 {
-  gint  width       = buffer->extent.width;
-  gint  height      = buffer->extent.height;
   gint  tile_width  = buffer->tile_storage->tile_width;
   gint  tile_height = buffer->tile_storage->tile_height;
-  gint  px_size     = FMTPXS (buffer->format);
-  gint  bpx_size    = FMTPXS (format);
+  gint  px_size     = babl_format_get_bytes_per_pixel (buffer->format);
+  gint  bpx_size    = babl_format_get_bytes_per_pixel (format);
   gint  tile_stride = px_size * tile_width;
   gint  buf_stride;
   gint  bufy = 0;
@@ -336,8 +335,12 @@ gegl_buffer_iterate (GeglBuffer *buffer,
 
   gint  buffer_shift_x = buffer->shift_x;
   gint  buffer_shift_y = buffer->shift_y;
+
+  gint  width          = buffer->extent.width;
+  gint  height         = buffer->extent.height;
   gint  buffer_x       = buffer->extent.x + buffer_shift_x;
   gint  buffer_y       = buffer->extent.y + buffer_shift_y;
+
   gint  buffer_abyss_x = buffer->abyss.x + buffer_shift_x;
   gint  buffer_abyss_y = buffer->abyss.y + buffer_shift_y;
   gint  abyss_x_total  = buffer_abyss_x + buffer->abyss.width;
@@ -345,6 +348,14 @@ gegl_buffer_iterate (GeglBuffer *buffer,
   gint  i;
   gint  factor = 1;
 
+  /* roi specified, override buffers extent */
+  if (roi)
+    {
+      width  = roi->width;
+      height = roi->height;
+      buffer_x = roi->x + buffer_shift_x;
+      buffer_y = roi->y + buffer_shift_y;
+    }
 
   for (i = 0; i < level; i++)
     {
@@ -579,8 +590,6 @@ gegl_buffer_set (GeglBuffer          *buffer,
                  void                *src,
                  gint                 rowstride)
 {
-  GeglBuffer *sub_buf;
-
   g_return_if_fail (GEGL_IS_BUFFER (buffer));
 
 #if ENABLE_MP
@@ -593,21 +602,11 @@ gegl_buffer_set (GeglBuffer          *buffer,
 
   if (rect && rect->width == 1 && rect->height == 1) /* fast path */
     {
-      pset (buffer, rect->x, rect->y, format, src);
-    }
-  /* FIXME: if rect->width == TILE_WIDTH and rect->height == TILE_HEIGHT and
-   * aligned with tile grid, do a fast path, also provide helper functions
-   * for figuring out how to align accesses with the tile grid.
-   */
-  else if (rect == NULL)
-    {
-      gegl_buffer_iterate (buffer, src, rowstride, TRUE, format, 0);
+      gegl_buffer_set_pixel (buffer, rect->x, rect->y, format, src);
     }
   else
     {
-      sub_buf = gegl_buffer_create_sub_buffer (buffer, rect);
-      gegl_buffer_iterate (sub_buf, src, rowstride, TRUE, format, 0);
-      g_object_unref (sub_buf);
+      gegl_buffer_iterate (buffer, rect, src, rowstride, TRUE, format, 0);
     }
 
   if (gegl_buffer_is_shared(buffer))
@@ -620,26 +619,7 @@ gegl_buffer_set (GeglBuffer          *buffer,
 #endif
 }
 
-/*
- * buffer: the buffer to get data from
- * rect:   the (full size rectangle to sample)
- * dst:    the destination buffer to write to
- * format: the format to write in
- * level:  halving levels 0 = 1:1 1=1:2 2=1:4 3=1:8 ..
- *
- */
-static void
-gegl_buffer_get_scaled (GeglBuffer          *buffer,
-                        const GeglRectangle *rect,
-                        void                *dst,
-                        gint                 rowstride,
-                        const void          *format,
-                        gint                 level)
-{
-  GeglBuffer *sub_buf = gegl_buffer_create_sub_buffer (buffer, rect);
-  gegl_buffer_iterate (sub_buf, dst, rowstride, FALSE, format, level);
-  g_object_unref (sub_buf);
-}
+
 
 #if 0
 
@@ -778,19 +758,33 @@ box_filter (guint          left_weight,
   /* NOTE: this box filter presumes pre-multiplied alpha, if there
    * is alpha.
    */
-  gint i;
-  for (i = 0; i < components; i++)
+   guint lt, lm, lb;
+   guint ct, cm, cb;
+   guint rt, rm, rb;
+
+   lt = left_weight * top_weight;
+   lm = left_weight * middle_weight;
+   lb = left_weight * bottom_weight;
+   ct = center_weight * top_weight;
+   cm = center_weight * middle_weight;
+   cb = center_weight * bottom_weight;
+   rt = right_weight * top_weight;
+   rm = right_weight * middle_weight;
+   rb = right_weight * bottom_weight;
+
+#define docomponent(i) \
+      dest[i] = (src[0][i] * lt + src[3][i] * lm + src[6][i] * lb + \
+                 src[1][i] * ct + src[4][i] * cm + src[7][i] * cb + \
+                 src[2][i] * rt + src[5][i] * rm + src[8][i] * rb) / sum
+  switch (components)
     {
-      dest[i] = ( left_weight   * ((src[0][i] * top_weight) +
-                                   (src[3][i] * middle_weight) +
-                                   (src[6][i] * bottom_weight))
-                + center_weight * ((src[1][i] * top_weight) +
-                                   (src[4][i] * middle_weight) +
-                                   (src[7][i] * bottom_weight))
-                + right_weight  * ((src[2][i] * top_weight) +
-                                   (src[5][i] * middle_weight) +
-                                   (src[8][i] * bottom_weight))) / sum;
+      case 5: docomponent(4);
+      case 4: docomponent(3);
+      case 3: docomponent(2);
+      case 2: docomponent(1);
+      case 1: docomponent(0);
     }
+#undef docomponent
 }
 
 static void
@@ -962,7 +956,7 @@ gegl_buffer_get (GeglBuffer          *buffer,
       rect->width == 1 &&
       rect->height == 1)  /* fast path */
     {
-      pget (buffer, rect->x, rect->y, format, dest_buf);
+      gegl_buffer_get_pixel (buffer, rect->x, rect->y, format, dest_buf);
 #if ENABLE_MP
       g_static_rec_mutex_unlock (&mutex);
 #endif
@@ -971,7 +965,7 @@ gegl_buffer_get (GeglBuffer          *buffer,
 
   if (!rect && scale == 1.0)
     {
-      gegl_buffer_iterate (buffer, dest_buf, rowstride, FALSE, format, 0);
+      gegl_buffer_iterate (buffer, NULL, dest_buf, rowstride, FALSE, format, 0);
 #if ENABLE_MP
       g_static_rec_mutex_unlock (&mutex);
 #endif
@@ -987,7 +981,7 @@ gegl_buffer_get (GeglBuffer          *buffer,
     }
   if (GEGL_FLOAT_EQUAL (scale, 1.0))
     {
-      gegl_buffer_get_scaled (buffer, rect, dest_buf, rowstride, format, 0);
+      gegl_buffer_iterate (buffer, rect, dest_buf, rowstride, FALSE, format, 0);
 #if ENABLE_MP
       g_static_rec_mutex_unlock (&mutex);
 #endif
@@ -998,16 +992,18 @@ gegl_buffer_get (GeglBuffer          *buffer,
       gint          level       = 0;
       gint          buf_width   = rect->width / scale;
       gint          buf_height  = rect->height / scale;
-      gint          bpp         = BABL (format)->format.bytes_per_pixel;
-      GeglRectangle sample_rect = { floor(rect->x/scale),
-                                    floor(rect->y/scale),
-                                    buf_width,
-                                    buf_height };
+      gint          bpp         = babl_format_get_bytes_per_pixel (format);
+      GeglRectangle sample_rect;
       void         *sample_buf;
       gint          factor = 1;
       gdouble       offset_x;
       gdouble       offset_y;
 
+      sample_rect.x = floor(rect->x/scale);
+      sample_rect.y = floor(rect->y/scale);
+      sample_rect.width = buf_width;
+      sample_rect.height = buf_height;
+
       while (scale <= 0.5)
         {
           scale  *= 2;
@@ -1024,15 +1020,17 @@ gegl_buffer_get (GeglBuffer          *buffer,
       buf_width          += 2;
       buf_height         += 2;
 
-
       offset_x = rect->x-floor(rect->x/scale) * scale;
       offset_y = rect->y-floor(rect->y/scale) * scale;
 
-
       sample_buf = g_malloc (buf_width * buf_height * bpp);
-      gegl_buffer_get_scaled (buffer, &sample_rect, sample_buf, GEGL_AUTO_ROWSTRIDE, format, level);
+      gegl_buffer_iterate (buffer, &sample_rect, sample_buf, GEGL_AUTO_ROWSTRIDE, FALSE, format, level);
+#if 1
+  /* slows testing of rendering code speed to much for now and
+   * no time to make a fast implementation
+   */
 
-      if (BABL (format)->format.type[0] == (BablType *) babl_type ("u8")
+      if (babl_format_get_type (format, 0) == babl_type ("u8")
           && !(level == 0 && scale > 1.99))
         { /* do box-filter resampling if we're 8bit (which projections are) */
 
@@ -1052,6 +1050,7 @@ gegl_buffer_get (GeglBuffer          *buffer,
                                  rowstride);
         }
       else
+#endif
         {
           resample_nearest (dest_buf,
                             sample_buf,
@@ -1094,7 +1093,7 @@ gegl_buffer_sample (GeglBuffer       *buffer,
 
 /*#define USE_WORKING_SHORTCUT*/
 #ifdef USE_WORKING_SHORTCUT
-  pget (buffer, x, y, format, dest);
+  gegl_buffer_get_pixel (buffer, x, y, format, dest);
   return;
 #endif
 
@@ -1202,14 +1201,15 @@ gegl_buffer_clear (GeglBuffer          *dst,
       dst_rect->height == 0)
     return;
 
-  pxsize = dst->format->format.bytes_per_pixel;
+  pxsize = babl_format_get_bytes_per_pixel (dst->format);
 
+  /* FIXME: this can be even further optimized by special casing it so
+   * that fully voided tiles are dropped.
+   */
   i = gegl_buffer_iterator_new (dst, dst_rect, dst->format, GEGL_BUFFER_WRITE);
   while (gegl_buffer_iterator_next (i))
     {
-      gint j;
-      for (j=0;j<i->length * pxsize;j++)
-        ((guchar*)(i->data[0]))[j]=0;
+      memset (((guchar*)(i->data[0])), 0, i->length * pxsize);
     }
 }
 
