@@ -17,13 +17,15 @@
  */
 
 #include "config.h"
+#include <stdlib.h>
 #include <string.h>
 #include <math.h>
 
 #include <glib-object.h>
 #include <glib/gprintf.h>
 
-#include "gegl-types.h"
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer-iterator.h"
 #include "gegl-buffer-private.h"
@@ -190,7 +192,7 @@ gulp:
          i->data = gegl_tile_get_data (i->tile);
 
          {
-         gint bpp = i->buffer->format->format.bytes_per_pixel;
+         gint bpp = babl_format_get_bytes_per_pixel (i->buffer->format);
          i->rowstride = bpp * tile_width;
          i->sub_data = (guchar*)(i->data) + bpp * (i->subrect.y * tile_width + i->subrect.x);
          }
@@ -327,7 +329,8 @@ static gpointer iterator_buf_pool_get (gint size)
         }
     }
   {
-    BufInfo info = {size, 1, NULL};
+    BufInfo info = {0, 1, NULL};
+    info.size = size;
     info.buf = gegl_malloc (size);
     g_array_append_val (buf_pool, info);
     return info.buf;
@@ -355,7 +358,7 @@ static void ensure_buf (GeglBufferIterators *i, gint no)
    * would probably improve performance
    */
   if (i->buf[no]==NULL)
-    i->buf[no] = iterator_buf_pool_get (i->format[no]->format.bytes_per_pixel *
+    i->buf[no] = iterator_buf_pool_get (babl_format_get_bytes_per_pixel (i->format[no]) *
                                         i->i[0].max_size);
 }
 
