@@ -31,8 +31,9 @@
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 
+#include "gegl.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
@@ -43,7 +44,7 @@
 #include "gegl-tile-handler-cache.h"
 #include "gegl-tile-handler-log.h"
 #include "gegl-tile-handler-empty.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
 #include "gegl-buffer-save.h"
 #include "gegl-buffer-index.h"
@@ -204,7 +205,7 @@ gegl_buffer_header_init (GeglBufferHeader *header,
   {
     gchar buf[64];
     g_snprintf (buf, 64, "%s%c\n%i×%i %ibpp\n%ix%i\n\n\n\n\n\n\n\n\n", 
-          format->instance.name, 0,
+          babl_get_name (format), 0,
           header->tile_width,
           header->tile_height,
           header->bytes_per_pixel,
