@@ -21,6 +21,7 @@
 #include <math.h>
 #include <string.h>
 #include <errno.h>
+#include <stdlib.h>
 
 #include <sys/types.h>
 #ifdef HAVE_UNISTD_H
@@ -45,8 +46,8 @@
 #include <gio/gio.h>
 #endif
 
-#include "gegl-types.h"
-
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-buffer-types.h"
 #include "gegl-buffer.h"
 #include "gegl-buffer-private.h"
@@ -62,13 +63,21 @@
 #include "gegl-sampler-linear.h"
 #include "gegl-sampler-cubic.h"
 #include "gegl-sampler-lanczos.h"
+#include "gegl-sampler-sharp.h"
 #include "gegl-sampler-yafr.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
 #include "gegl-id-pool.h"
 #include "gegl-buffer-index.h"
 #include "gegl-config.h"
 
+/* #define GEGL_BUFFER_DEBUG_ALLOCATIONS to print allocation stack
+ * traces for leaked GeglBuffers using GNU C libs backtrace_symbols()
+ */
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+#include <execinfo.h>
+#endif
+
 
 G_DEFINE_TYPE (GeglBuffer, gegl_buffer, GEGL_TYPE_TILE_HANDLER)
 
@@ -100,35 +109,37 @@ enum {
   LAST_SIGNAL
 };
 
+static GeglBuffer *gegl_buffer_new_from_format     (const void *babl_format,
+                                                    gint        x,
+                                                    gint        y,
+                                                    gint        width,
+                                                    gint        height,
+                                                    gint        tile_width,
+                                                    gint        tile_height,
+                                                    gboolean    use_ram);
+static const void *gegl_buffer_internal_get_format (GeglBuffer *buffer);
+
+
 guint gegl_buffer_signals[LAST_SIGNAL] = { 0 };
 
-static GeglBuffer * gegl_buffer_new_from_format (const void *babl_format,
-                                                 gint        x,
-                                                 gint        y,
-                                                 gint        width,
-                                                 gint        height,
-                                                 gint        tile_width,
-                                                 gint        tile_height,
-                                                 gboolean    use_ram);
 
-static inline gint needed_tiles (gint w,
-                                 gint stride)
+static inline gint gegl_buffer_needed_tiles (gint w,
+                                             gint stride)
 {
   return ((w - 1) / stride) + 1;
 }
 
-static inline gint needed_width (gint w,
-                                 gint stride)
+static inline gint gegl_buffer_needed_width (gint w,
+                                             gint stride)
 {
-  return needed_tiles (w, stride) * stride;
+  return gegl_buffer_needed_tiles (w, stride) * stride;
 }
 
-static const void *int_gegl_buffer_get_format (GeglBuffer *buffer);
 static void
-get_property (GObject    *gobject,
-              guint       property_id,
-              GValue     *value,
-              GParamSpec *pspec)
+gegl_buffer_get_property (GObject    *gobject,
+                          guint       property_id,
+                          GValue     *value,
+                          GParamSpec *pspec)
 {
   GeglBuffer *buffer = GEGL_BUFFER (gobject);
 
@@ -177,7 +188,7 @@ get_property (GObject    *gobject,
          */
 
         if (buffer->format == NULL)
-          buffer->format = int_gegl_buffer_get_format (buffer);
+          buffer->format = gegl_buffer_internal_get_format (buffer);
 
         g_value_set_pointer (value, (void*)buffer->format); /* Eeeek? */
         break;
@@ -205,10 +216,10 @@ get_property (GObject    *gobject,
 }
 
 static void
-set_property (GObject      *gobject,
-              guint         property_id,
-              const GValue *value,
-              GParamSpec   *pspec)
+gegl_buffer_set_property (GObject      *gobject,
+                          guint         property_id,
+                          const GValue *value,
+                          GParamSpec   *pspec)
 {
   GeglBuffer *buffer = GEGL_BUFFER (gobject);
 
@@ -283,8 +294,11 @@ set_property (GObject      *gobject,
     }
 }
 
-static gint allocated_buffers    = 0;
-static gint de_allocated_buffers = 0;
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+static GList *allocated_buffers_list = NULL;
+#endif
+static gint   allocated_buffers      = 0;
+static gint   de_allocated_buffers   = 0;
 
 /* this should only be possible if this buffer matches all the buffers down to
  * storage, all of those parent buffers would change size as well, no tiles
@@ -317,6 +331,23 @@ void gegl_buffer_stats (void)
 
 gint gegl_buffer_leaks (void)
 {
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+  {
+    GList *leaked_buffer = NULL;
+
+    for (leaked_buffer = allocated_buffers_list;
+         leaked_buffer != NULL;
+         leaked_buffer = leaked_buffer->next)
+      {
+        GeglBuffer *buffer = GEGL_BUFFER (leaked_buffer->data);
+
+        g_printerr ("\n"
+                   "Leaked buffer allocation stack trace:\n");
+        g_printerr ("%s\n", buffer->alloc_stack_trace);
+      }
+  }
+#endif
+
   return allocated_buffers - de_allocated_buffers;
 }
 
@@ -353,6 +384,10 @@ gegl_buffer_dispose (GObject *object)
 static void
 gegl_buffer_finalize (GObject *object)
 {
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+  allocated_buffers_list = g_list_remove (allocated_buffers_list, object);
+#endif
+
   de_allocated_buffers++;
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -395,9 +430,9 @@ gegl_buffer_tile_storage (GeglBuffer *buffer)
 
 void babl_backtrack (void);
 
-static void storage_changed (GeglTileStorage     *storage,
-                             const GeglRectangle *rect,
-                             gpointer             userdata)
+static void gegl_buffer_storage_changed (GeglTileStorage     *storage,
+                                         const GeglRectangle *rect,
+                                         gpointer             userdata)
 {
   g_signal_emit_by_name (GEGL_BUFFER (userdata), "changed", rect, NULL);
 }
@@ -499,7 +534,7 @@ gegl_buffer_constructor (GType                  type,
           g_object_unref (source);
 
           g_signal_connect (storage, "changed",
-                            G_CALLBACK(storage_changed), buffer);
+                            G_CALLBACK(gegl_buffer_storage_changed), buffer);
 
           g_assert (source);
           backend = gegl_buffer_backend (GEGL_BUFFER (source));
@@ -610,19 +645,20 @@ gegl_buffer_constructor (GType                  type,
    */
   if (GEGL_IS_BUFFER (source))
     {
-      GeglRectangle parent = {
-        GEGL_BUFFER (source)->abyss.x - buffer->shift_x,
-        GEGL_BUFFER (source)->abyss.y - buffer->shift_y,
-        GEGL_BUFFER (source)->abyss.width,
-        GEGL_BUFFER (source)->abyss.height
-      };
-      GeglRectangle request = {
-        buffer->abyss.x,
-        buffer->abyss.y,
-        buffer->abyss.width,
-        buffer->abyss.height
-      };
+      GeglRectangle parent;
+      GeglRectangle request;
       GeglRectangle self;
+
+      parent.x = GEGL_BUFFER (source)->abyss.x - buffer->shift_x;
+      parent.y = GEGL_BUFFER (source)->abyss.y - buffer->shift_y;
+      parent.width = GEGL_BUFFER (source)->abyss.width;
+      parent.height = GEGL_BUFFER (source)->abyss.height;
+      
+      request.x = buffer->abyss.x;
+      request.y = buffer->abyss.y;
+      request.width = buffer->abyss.width;
+      request.height = buffer->abyss.height;
+
       gegl_rectangle_intersect (&self, &parent, &request);
 
       buffer->abyss.x      = self.x;
@@ -652,10 +688,10 @@ gegl_buffer_constructor (GType                  type,
 }
 
 static GeglTile *
-get_tile (GeglTileSource *source,
-          gint        x,
-          gint        y,
-          gint        z)
+gegl_buffer_get_tile (GeglTileSource *source,
+                      gint        x,
+                      gint        y,
+                      gint        z)
 {
   GeglTileHandler *handler = GEGL_HANDLER (source);
   GeglTile    *tile   = NULL;
@@ -709,7 +745,7 @@ gegl_buffer_command (GeglTileSource *source,
   switch (command)
     {
       case GEGL_TILE_GET:
-        return get_tile (source, x, y, z);
+        return gegl_buffer_get_tile (source, x, y, z);
       default:
         return gegl_tile_handler_chain_up (handler, command, x, y, z, data);
     }
@@ -725,8 +761,8 @@ gegl_buffer_class_init (GeglBufferClass *class)
   gobject_class->dispose      = gegl_buffer_dispose;
   gobject_class->finalize     = gegl_buffer_finalize;
   gobject_class->constructor  = gegl_buffer_constructor;
-  gobject_class->set_property = set_property;
-  gobject_class->get_property = get_property;
+  gobject_class->set_property = gegl_buffer_set_property;
+  gobject_class->get_property = gegl_buffer_get_property;
   tile_source_class->command = gegl_buffer_command;
 
   g_object_class_install_property (gobject_class, PROP_PX_SIZE,
@@ -749,12 +785,12 @@ gegl_buffer_class_init (GeglBufferClass *class)
                                                      G_PARAM_CONSTRUCT));
   g_object_class_install_property (gobject_class, PROP_X,
                                    g_param_spec_int ("x", "x", "local origin's offset relative to source origin",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT));
   g_object_class_install_property (gobject_class, PROP_Y,
                                    g_param_spec_int ("y", "y", "local origin's offset relative to source origin",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT));
   g_object_class_install_property (gobject_class, PROP_ABYSS_WIDTH,
@@ -769,22 +805,22 @@ gegl_buffer_class_init (GeglBufferClass *class)
                                                      G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (gobject_class, PROP_ABYSS_X,
                                    g_param_spec_int ("abyss-x", "abyss-x", "",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (gobject_class, PROP_ABYSS_Y,
                                    g_param_spec_int ("abyss-y", "abyss-y", "",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (gobject_class, PROP_SHIFT_X,
                                    g_param_spec_int ("shift-x", "shift-x", "",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (gobject_class, PROP_SHIFT_Y,
                                    g_param_spec_int ("shift-y", "shift-y", "",
-                                                     G_MININT, G_MAXINT, 0,
+                                                     G_MININT / 2, G_MAXINT / 2, 0,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
   g_object_class_install_property (gobject_class, PROP_FORMAT,
@@ -821,6 +857,42 @@ gegl_buffer_class_init (GeglBufferClass *class)
 
 }
 
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+#define MAX_N_FUNCTIONS 100
+static gchar *
+gegl_buffer_get_alloc_stack (void)
+{
+  void  *functions[MAX_N_FUNCTIONS];
+  int    n_functions    = 0;
+  char **function_names = NULL;
+  int    i              = 0;
+  int    result_size    = 0;
+  char  *result         = NULL;
+  
+  n_functions = backtrace (functions, MAX_N_FUNCTIONS);
+  function_names = backtrace_symbols (functions, n_functions);
+
+  for (i = 0; i < n_functions; i++)
+    {
+      result_size += strlen (function_names[i]);
+      result_size += 1; /* for '\n' */
+    }
+
+  result = g_new (gchar, result_size + 1);
+  result[0] = '\0';
+
+  for (i = 0; i < n_functions; i++)
+    {
+      strcat (result, function_names[i]);
+      strcat (result, "\n");
+    }
+
+  free (function_names);
+
+  return result;
+}
+#endif
+
 static void
 gegl_buffer_init (GeglBuffer *buffer)
 {
@@ -849,6 +921,11 @@ gegl_buffer_init (GeglBuffer *buffer)
   buffer->tile_height = 64;
 
   allocated_buffers++;
+
+#ifdef GEGL_BUFFER_DEBUG_ALLOCATIONS
+  buffer->alloc_stack_trace = gegl_buffer_get_alloc_stack ();
+  allocated_buffers_list = g_list_prepend (allocated_buffers_list, buffer);
+#endif
 }
 
 
@@ -1028,7 +1105,7 @@ gegl_buffer_new_from_format (const void *babl_format,
 }
 
 
-static const void *int_gegl_buffer_get_format (GeglBuffer *buffer)
+static const void *gegl_buffer_internal_get_format (GeglBuffer *buffer)
 {
   g_assert (buffer);
   if (buffer->format != NULL)
