@@ -24,7 +24,8 @@
 
 #include <babl/babl.h>
 
-#include "gegl-types.h"
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
 
 #include "graph/gegl-node.h"
@@ -40,7 +41,7 @@ enum
   PROP_Y,
   PROP_WIDTH,
   PROP_HEIGHT,
-  PROP_NODE,
+  PROP_NODE
 };
 
 enum
@@ -61,7 +62,7 @@ static void            get_property (GObject      *object,
                                      GValue       *value,
                                      GParamSpec   *pspec);
 
-G_DEFINE_TYPE (GeglCache, gegl_cache, GEGL_TYPE_BUFFER);
+G_DEFINE_TYPE (GeglCache, gegl_cache, GEGL_TYPE_BUFFER)
 
 guint gegl_cache_signals[LAST_SIGNAL] = { 0 };
 
@@ -84,6 +85,38 @@ gegl_cache_constructor (GType                  type,
   return object;
 }
 
+/* expand invalidated regions to be align with coordinates divisible by 8 in both
+ * directions. This improves improves the performance of GeglProcessor when it
+ * iterates the resulting dirtied rectangles in the GeglRegion.
+ */
+static GeglRectangle gegl_rectangle_expand (const GeglRectangle *rectangle)
+{
+  gint align = 8;
+  GeglRectangle expanded = *rectangle;
+  gint xdiff;
+  gint ydiff;
+
+  if (gegl_rectangle_is_infinite_plane (rectangle))
+    return *rectangle;
+
+  xdiff = expanded.x % align;
+  if (xdiff < 0)
+    xdiff = align + xdiff;
+  expanded.width += xdiff;
+  expanded.x -= xdiff;
+  xdiff = align -(expanded.width % align);
+  expanded.width += xdiff;
+
+  ydiff = expanded.y % align;
+  if (ydiff < 0)
+    ydiff = align + ydiff;
+  expanded.height += ydiff;
+  expanded.y -= ydiff;
+  ydiff = align -(expanded.height % align);
+  expanded.height += ydiff;
+
+  return expanded;
+}
 
 static void
 gegl_cache_class_init (GeglCacheClass *klass)
@@ -108,14 +141,14 @@ gegl_cache_class_init (GeglCacheClass *klass)
   g_object_class_install_property (gobject_class, PROP_X,
                                    g_param_spec_int ("x", "x",
                                                      "local origin's offset relative to source origin",
-                                                     G_MININT, G_MAXINT, -4096,
+                                                     G_MININT / 2, G_MAXINT / 2, -4096,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
 
   g_object_class_install_property (gobject_class, PROP_Y,
                                    g_param_spec_int ("y", "y",
                                                      "local origin's offset relative to source origin",
-                                                     G_MININT, G_MAXINT, -4096,
+                                                     G_MININT / 2, G_MAXINT / 2, -4096,
                                                      G_PARAM_READWRITE |
                                                      G_PARAM_CONSTRUCT_ONLY));
 
@@ -172,7 +205,10 @@ dispose (GObject *gobject)
 
   while (g_idle_remove_by_data (gobject)) ;
 
-  if (self->node)
+  /* Check with GEGL_IS_NODE since sometimes the node is destroyed
+   * before we get here
+   */
+  if (GEGL_IS_NODE (self->node))
     {
       gint handler = g_signal_handler_find (self->node, G_SIGNAL_MATCH_DATA,
                                             g_signal_lookup ("invalidated",
@@ -204,15 +240,16 @@ node_invalidated (GeglNode            *source,
                   gpointer             data)
 {
   GeglCache *cache = GEGL_CACHE (data);
+  GeglRectangle expanded = gegl_rectangle_expand (rect);
 
   {
     GeglRegion *region;
-    region = gegl_region_rectangle (rect);
+    region = gegl_region_rectangle (&expanded);
     gegl_region_subtract (cache->valid_region, region);
     gegl_region_destroy (region);
   }
 
-  g_signal_emit_by_name (cache, "invalidated", rect, NULL);
+  g_signal_emit_by_name (cache, "invalidated", &expanded, NULL);
 }
 
 static void
@@ -333,18 +370,21 @@ gegl_cache_invalidate (GeglCache           *self,
 #if 0
   if (roi)
     {
-      g_print ("invalidate of %i,%i %i×%i\n", roi->x, roi->y, roi->width, roi->height);
       gegl_buffer_clear (GEGL_BUFFER (self), roi);
     }
   else
     {
-      g_print ("full invalidate of a GeglCache\n");
+      g_warning ("XXX: full invalidation of GeglCache NYI\n");
     }
 #endif
+
+
   if (roi)
     {
+      GeglRectangle expanded = gegl_rectangle_expand (roi);
+
       GeglRegion *temp_region;
-      temp_region = gegl_region_rectangle (roi);
+      temp_region = gegl_region_rectangle (&expanded);
       gegl_region_subtract (self->valid_region, temp_region);
       gegl_region_destroy (temp_region);
       g_signal_emit (self, gegl_cache_signals[INVALIDATED], 0,
