@@ -32,93 +32,108 @@
 #include <glib-object.h>
 #include <glib/gprintf.h>
 
+#include "gegl.h"
 #include "gegl-tile-backend.h"
 #include "gegl-tile-backend-file.h"
 #include "gegl-buffer-index.h"
 #include "gegl-debug.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
+
 
 struct _GeglTileBackendFile
 {
   GeglTileBackend  parent_instance;
 
-  gchar           *path;    /* the path to our buffer */
-#if HAVE_GIO
-  GFile           *file;    /* gfile refering to our buffer */
-  GOutputStream   *o;       /* for writing */
-  GInputStream    *i;       /* for reading */
-#else
-  int             o;
-  int             i;
-#endif
-  gboolean         exist;   /* the file exist (and we've thus been able
-                             * to initialize i and o, the utility_call ensure_exist
-                             * should be called before any code using i and o)
-                             */
+  /* the path to our buffer */
+  gchar           *path;
 
-  GHashTable      *index;   /* hashtable containing all entries
-                             * of buffer, the index is
-                             * written to the swapfile conforming
-                             * to the structures laid out in
-                             * gegl-buffer-index.h
-                             */
+  /* the file exist (and we've thus been able to initialize i and o,
+   * the utility call ensure_exist() should be called before any code
+   * using i and o)
+   */
+  gboolean         exist;
 
-  GSList          *free_list; /* list of offsets to tiles that are free */
+  /* total size of file */
+  guint            total;
 
-  guint            next_pre_alloc; /* offset to next pre allocated tile slot */
-  guint            total;          /* total size of file */
+  /* hashtable containing all entries of buffer, the index is written
+   * to the swapfile conforming to the structures laid out in
+   * gegl-buffer-index.h
+   */
+  GHashTable      *index;
 
-  /* duplicated from gegl-buffer-save */
+  /* list of offsets to tiles that are free */
+  GSList          *free_list;
 
-  GeglBufferHeader header;     /* a local copy of the header that will be
-                                * written to the file, in a multiple user
-                                * per buffer scenario, the flags in the
-                                * header might be used for locking/signalling
-                                */
+  /* offset to next pre allocated tile slot */
+  guint            next_pre_alloc;
 
-  gint             offset;     /* current offset, used when writing the
-                                * index,
-                                */
-  GeglBufferBlock *in_holding; /* when writing buffer blocks the writer
-                                * keeps one block unwritten at all times
-                                * to be able to keep track of the ->next
-                                * offsets in the blocks.
-                                */
+  /* revision of last index sync, for cooperated sharing of a buffer
+   * file
+   */
+  guint32          rev;
+
+  /* a local copy of the header that will be written to the file, in a
+   * multiple user per buffer scenario, the flags in the header might
+   * be used for locking/signalling
+   */
+  GeglBufferHeader header;
+
+  /* current offset, used when writing the index */
+  gint             offset;
+
+  /* when writing buffer blocks the writer keeps one block unwritten
+   * at all times to be able to keep track of the ->next offsets in
+   * the blocks.
+   */
+  GeglBufferBlock *in_holding; 
 
   /* loading buffer */
+  GList           *tiles;
 
-  GList *tiles;
-
-  /* cooperative sharing of file */
 #if HAVE_GIO
-  GFileMonitor    *monitor; /* Before using mmap we'll use GIO's infrastructure
-                             * for monitoring the file for changes, this should
-                             * also be more portable.
-                             */
+  /* GFile refering to our buffer */
+  GFile           *file;
+
+  /* for writing */
+  GOutputStream   *o;
+
+  /* for reading */
+  GInputStream    *i;
+
+  /* Before using mmap we'll use GIO's infrastructure for monitoring
+   * the file for changes, this should also be more portable. This is
+   * used for for cooperated sharing of a buffer file
+   */
+  GFileMonitor    *monitor;
+#else
+  /* for writing */
+  int              o;
+
+  /* for reading */
+  int              i;
 #endif
-  guint32          rev;     /* revision of last index sync */
 };
 
-static void ensure_exist (GeglTileBackendFile *self);
 
-static gboolean
-write_block (GeglTileBackendFile *self,
-             GeglBufferBlock     *block);
+static void     gegl_tile_backend_file_ensure_exist (GeglTileBackendFile *self);
+static gboolean gegl_tile_backend_file_write_block  (GeglTileBackendFile *self,
+                                                     GeglBufferBlock     *block);
+static void     gegl_tile_backend_file_dbg_alloc    (int                  size);
+static void     gegl_tile_backend_file_dbg_dealloc  (int                  size);
 
-static void dbg_alloc (int size);
-static void dbg_dealloc (int size);
 
 static void inline
-file_entry_read (GeglTileBackendFile *self,
-                 GeglBufferTile      *entry,
-                 guchar              *dest)
+gegl_tile_backend_file_file_entry_read (GeglTileBackendFile *self,
+                                        GeglBufferTile      *entry,
+                                        guchar              *dest)
 {
   gint     to_be_read;
   gboolean success;
   gint     tile_size = GEGL_TILE_BACKEND (self)->tile_size;
   goffset  offset = entry->offset;
 
-  ensure_exist (self);
+  gegl_tile_backend_file_ensure_exist (self);
 
 #if HAVE_GIO
   success = g_seekable_seek (G_SEEKABLE (self->i),
@@ -140,8 +155,8 @@ file_entry_read (GeglTileBackendFile *self,
 
 #if HAVE_GIO
       byte_read = g_input_stream_read (G_INPUT_STREAM (self->i),
-                                 dest + tile_size - to_be_read, to_be_read,
-                                 NULL, NULL);
+                                       dest + tile_size - to_be_read, to_be_read,
+                                       NULL, NULL);
 #else
       byte_read = read (self->i, dest + tile_size - to_be_read, to_be_read);
 #endif
@@ -156,20 +171,20 @@ file_entry_read (GeglTileBackendFile *self,
     }
 
 
-  GEGL_NOTE (TILE_BACKEND, "read entry %i,%i,%i at %i", entry->x, entry->y, entry->z, (gint)offset);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "read entry %i,%i,%i at %i", entry->x, entry->y, entry->z, (gint)offset);
 }
 
 static void inline
-file_entry_write (GeglTileBackendFile *self,
-                  GeglBufferTile      *entry,
-                  guchar              *source)
+gegl_tile_backend_file_file_entry_write (GeglTileBackendFile *self,
+                                         GeglBufferTile      *entry,
+                                         guchar              *source)
 {
   gint     to_be_written;
   gboolean success;
   gint     tile_size = GEGL_TILE_BACKEND (self)->tile_size;
   goffset  offset = entry->offset;
 
-  ensure_exist (self);
+  gegl_tile_backend_file_ensure_exist (self);
 
 #if HAVE_GIO
   success = g_seekable_seek (G_SEEKABLE (self->o),
@@ -193,8 +208,9 @@ file_entry_write (GeglTileBackendFile *self,
                                      source + tile_size - to_be_written,
                                      to_be_written, NULL, NULL);
 #else
-	  wrote = write (self->o, source + tile_size - to_be_written,
-					  to_be_written);
+      wrote = write (self->o,
+                     source + tile_size - to_be_written,
+                     to_be_written);
 #endif
       if (wrote <= 0)
         {
@@ -205,17 +221,17 @@ file_entry_write (GeglTileBackendFile *self,
         }
       to_be_written -= wrote;
     }
-   GEGL_NOTE (TILE_BACKEND, "wrote entry %i,%i,%i at %i", entry->x, entry->y, entry->z, (gint)offset);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "wrote entry %i,%i,%i at %i", entry->x, entry->y, entry->z, (gint)offset);
 }
 
 static inline GeglBufferTile *
-file_entry_new (GeglTileBackendFile *self)
+gegl_tile_backend_file_file_entry_new (GeglTileBackendFile *self)
 {
   GeglBufferTile *entry = gegl_tile_entry_new (0,0,0);
 
-  GEGL_NOTE (TILE_BACKEND, "Creating new entry");
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "Creating new entry");
 
-  ensure_exist (self);
+  gegl_tile_backend_file_ensure_exist (self);
 
   if (self->free_list)
     {
@@ -224,37 +240,37 @@ file_entry_new (GeglTileBackendFile *self)
       entry->offset = offset;
       self->free_list = g_slist_remove (self->free_list, self->free_list->data);
 
-      GEGL_NOTE (TILE_BACKEND, "  set offset %i from free list", ((gint)entry->offset));
+      GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "  set offset %i from free list", ((gint)entry->offset));
     }
   else
     {
       gint tile_size = GEGL_TILE_BACKEND (self)->tile_size;
 
       entry->offset = self->next_pre_alloc;
-      GEGL_NOTE (TILE_BACKEND, "  set offset %i (next allocation)", (gint)entry->offset);
+      GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "  set offset %i (next allocation)", (gint)entry->offset);
       self->next_pre_alloc += tile_size;
 
       if (self->next_pre_alloc >= self->total)
         {
           self->total = self->total + 32 * tile_size;
 
-          GEGL_NOTE (TILE_BACKEND, "growing file to %i bytes", (gint)self->total);
+          GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "growing file to %i bytes", (gint)self->total);
 
 #if HAVE_GIO
           g_assert (g_seekable_truncate (G_SEEKABLE (self->o),
-                    self->total, NULL,NULL));
+                                         self->total, NULL,NULL));
 #else
-		  g_assert (ftruncate (self->o, self->total) == 0);
+          g_assert (ftruncate (self->o, self->total) == 0);
 #endif
         }
     }
-  dbg_alloc (GEGL_TILE_BACKEND (self)->tile_size);
+  gegl_tile_backend_file_dbg_alloc (GEGL_TILE_BACKEND (self)->tile_size);
   return entry;
 }
 
 static inline void
-file_entry_destroy (GeglBufferTile      *entry,
-                    GeglTileBackendFile *self)
+gegl_tile_backend_file_file_entry_destroy (GeglBufferTile      *entry,
+                                           GeglTileBackendFile *self)
 {
   /* XXX: EEEk, throwing away bits */
   guint offset = entry->offset;
@@ -262,16 +278,16 @@ file_entry_destroy (GeglBufferTile      *entry,
                                      GUINT_TO_POINTER (offset));
   g_hash_table_remove (self->index, entry);
 
-  dbg_dealloc (GEGL_TILE_BACKEND (self)->tile_size);
+  gegl_tile_backend_file_dbg_dealloc (GEGL_TILE_BACKEND (self)->tile_size);
   g_free (entry);
 }
 
 static gboolean
-write_header (GeglTileBackendFile *self)
+gegl_tile_backend_file_write_header (GeglTileBackendFile *self)
 {
   gboolean success;
 
-  ensure_exist (self);
+  gegl_tile_backend_file_ensure_exist (self);
 
 #if HAVE_GIO
   success = g_seekable_seek (G_SEEKABLE (self->o), 0, G_SEEK_SET,
@@ -289,84 +305,84 @@ write_header (GeglTileBackendFile *self)
 #else
   write (self->o, &(self->header), 256);
 #endif
-  GEGL_NOTE (TILE_BACKEND, "Wrote header, next=%i", (gint)self->header.next);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "Wrote header, next=%i", (gint)self->header.next);
   return TRUE;
 }
 
 static gboolean
-write_block (GeglTileBackendFile *self,
-             GeglBufferBlock     *block)
+gegl_tile_backend_file_write_block (GeglTileBackendFile *self,
+                                    GeglBufferBlock     *block)
 {
-  ensure_exist (self);
-   if (self->in_holding)
-     {
-       guint64 next_allocation = self->offset + self->in_holding->length;
+  gegl_tile_backend_file_ensure_exist (self);
+  if (self->in_holding)
+    {
+      guint64 next_allocation = self->offset + self->in_holding->length;
 
-       /* update the next offset pointer in the previous block */
-       self->in_holding->next = next_allocation;
+      /* update the next offset pointer in the previous block */
+      self->in_holding->next = next_allocation;
 
-       if (block == NULL) /* the previous block was the last block */
-         {
-           self->in_holding->next = 0;
-         }
+      if (block == NULL) /* the previous block was the last block */
+        {
+          self->in_holding->next = 0;
+        }
 
 #if HAVE_GIO
-       if(!g_seekable_seek (G_SEEKABLE (self->o),
-                            self->offset, G_SEEK_SET,
-                            NULL, NULL))
+      if(!g_seekable_seek (G_SEEKABLE (self->o),
+                           self->offset, G_SEEK_SET,
+                           NULL, NULL))
 #else
-       if(lseek (self->o, self->offset, G_SEEK_SET) == -1)
+      if(lseek (self->o, self->offset, G_SEEK_SET) == -1)
 #endif
-         goto fail;
+        goto fail;
 
-       GEGL_NOTE (TILE_BACKEND, "Wrote block: length:%i flags:%i next:%i at offset %i",
-             self->in_holding->length,
-             self->in_holding->flags,
-             (gint)self->in_holding->next,
-             (gint)self->offset);
+      GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "Wrote block: length:%i flags:%i next:%i at offset %i",
+                 self->in_holding->length,
+                 self->in_holding->flags,
+                 (gint)self->in_holding->next,
+                 (gint)self->offset);
 #if HAVE_GIO
-       self->offset += g_output_stream_write (self->o, self->in_holding,
-                                              self->in_holding->length,
-                                              NULL, NULL);
+      self->offset += g_output_stream_write (self->o, self->in_holding,
+                                             self->in_holding->length,
+                                             NULL, NULL);
 #else
-       {
-         ssize_t written = write (self->o, self->in_holding,
-                                  self->in_holding->length);
-         if(written != -1)
-           self->offset += written;
-       }
+      {
+        ssize_t written = write (self->o, self->in_holding,
+                                 self->in_holding->length);
+        if(written != -1)
+          self->offset += written;
+      }
 #endif
 
-       g_assert (next_allocation == self->offset); /* true as long as
-                                                      the simple allocation
-                                                      scheme is used */
+      g_assert (next_allocation == self->offset); /* true as long as
+                                                     the simple allocation
+                                                     scheme is used */
 
-       self->offset = next_allocation;
-     }
-   else
-     {
-        /* we're setting up for the first write */
+      self->offset = next_allocation;
+    }
+  else
+    {
+      /* we're setting up for the first write */
 
-        self->offset = self->next_pre_alloc; /* start writing header at end
-                                              * of file, worry about writing
-                                              * header inside free list later
-                                              */
+      self->offset = self->next_pre_alloc; /* start writing header at end
+                                            * of file, worry about writing
+                                            * header inside free list later
+                                            */
 #if HAVE_GIO
-        if(!g_seekable_seek (G_SEEKABLE (self->o),
-                             (goffset) self->offset, G_SEEK_SET,
-                             NULL, NULL))
+      if(!g_seekable_seek (G_SEEKABLE (self->o),
+                           (goffset) self->offset, G_SEEK_SET,
+                           NULL, NULL))
 #else
-        if(lseek (self->o, self->offset, G_SEEK_SET) == -1)
+      if(lseek (self->o, self->offset, G_SEEK_SET) == -1)
 #endif
-          goto fail;
-     }
-   self->in_holding = block;
+        goto fail;
+    }
+  self->in_holding = block;
 
-   return TRUE;
+  return TRUE;
 fail:
-   g_warning ("gegl buffer index writing problems for %s",
-              self->path);
-   return FALSE;
+  g_warning ("gegl buffer index writing problems for %s",
+             self->path);
+  return FALSE;
 }
 
 G_DEFINE_TYPE (GeglTileBackendFile, gegl_tile_backend_file, GEGL_TYPE_TILE_BACKEND)
@@ -388,7 +404,7 @@ gegl_tile_backend_file_stats (void)
 }
 
 static void
-dbg_alloc (gint size)
+gegl_tile_backend_file_dbg_alloc (gint size)
 {
   allocs++;
   file_size += size;
@@ -399,14 +415,14 @@ dbg_alloc (gint size)
 }
 
 static void
-dbg_dealloc (gint size)
+gegl_tile_backend_file_dbg_dealloc (gint size)
 {
   allocs--;
   file_size -= size;
 }
 
 static inline GeglBufferTile *
-lookup_entry (GeglTileBackendFile *self,
+gegl_tile_backend_file_lookup_entry (GeglTileBackendFile *self,
               gint                 x,
               gint                 y,
               gint                 z)
@@ -424,7 +440,7 @@ lookup_entry (GeglTileBackendFile *self,
  * too often.
  */
 static GeglTile *
-get_tile (GeglTileSource *self,
+gegl_tile_backend_file_get_tile (GeglTileSource *self,
           gint            x,
           gint            y,
           gint            z)
@@ -437,7 +453,7 @@ get_tile (GeglTileSource *self,
 
   backend           = GEGL_TILE_BACKEND (self);
   tile_backend_file = GEGL_TILE_BACKEND_FILE (backend);
-  entry             = lookup_entry (tile_backend_file, x, y, z);
+  entry             = gegl_tile_backend_file_lookup_entry (tile_backend_file, x, y, z);
 
   if (!entry)
     return NULL;
@@ -446,16 +462,16 @@ get_tile (GeglTileSource *self,
   tile->rev        = entry->rev;
   tile->stored_rev = entry->rev;
 
-  file_entry_read (tile_backend_file, entry, tile->data);
+  gegl_tile_backend_file_file_entry_read (tile_backend_file, entry, tile->data);
   return tile;
 }
 
 static gpointer
-set_tile (GeglTileSource *self,
-          GeglTile       *tile,
-          gint            x,
-          gint            y,
-          gint            z)
+gegl_tile_backend_file_set_tile (GeglTileSource *self,
+                                 GeglTile       *tile,
+                                 gint            x,
+                                 gint            y,
+                                 gint            z)
 {
   GeglTileBackend     *backend;
   GeglTileBackendFile *tile_backend_file;
@@ -463,11 +479,11 @@ set_tile (GeglTileSource *self,
 
   backend           = GEGL_TILE_BACKEND (self);
   tile_backend_file = GEGL_TILE_BACKEND_FILE (backend);
-  entry             = lookup_entry (tile_backend_file, x, y, z);
+  entry             = gegl_tile_backend_file_lookup_entry (tile_backend_file, x, y, z);
 
   if (entry == NULL)
     {
-      entry    = file_entry_new (tile_backend_file);
+      entry    = gegl_tile_backend_file_file_entry_new (tile_backend_file);
       entry->x = x;
       entry->y = y;
       entry->z = z;
@@ -475,17 +491,17 @@ set_tile (GeglTileSource *self,
     }
   entry->rev = tile->rev;
 
-  file_entry_write (tile_backend_file, entry, tile->data);
+  gegl_tile_backend_file_file_entry_write (tile_backend_file, entry, tile->data);
   tile->stored_rev = tile->rev;
   return NULL;
 }
 
 static gpointer
-void_tile (GeglTileSource *self,
-           GeglTile       *tile,
-           gint            x,
-           gint            y,
-           gint            z)
+gegl_tile_backend_file_void_tile (GeglTileSource *self,
+                                  GeglTile       *tile,
+                                  gint            x,
+                                  gint            y,
+                                  gint            z)
 {
   GeglTileBackend     *backend;
   GeglTileBackendFile *tile_backend_file;
@@ -493,22 +509,22 @@ void_tile (GeglTileSource *self,
 
   backend           = GEGL_TILE_BACKEND (self);
   tile_backend_file = GEGL_TILE_BACKEND_FILE (backend);
-  entry             = lookup_entry (tile_backend_file, x, y, z);
+  entry             = gegl_tile_backend_file_lookup_entry (tile_backend_file, x, y, z);
 
   if (entry != NULL)
     {
-      file_entry_destroy (entry, tile_backend_file);
+      gegl_tile_backend_file_file_entry_destroy (entry, tile_backend_file);
     }
 
   return NULL;
 }
 
 static gpointer
-exist_tile (GeglTileSource *self,
-            GeglTile       *tile,
-            gint            x,
-            gint            y,
-            gint            z)
+gegl_tile_backend_file_exist_tile (GeglTileSource *self,
+                                   GeglTile       *tile,
+                                   gint            x,
+                                   gint            y,
+                                   gint            z)
 {
   GeglTileBackend     *backend;
   GeglTileBackendFile *tile_backend_file;
@@ -516,18 +532,18 @@ exist_tile (GeglTileSource *self,
 
   backend           = GEGL_TILE_BACKEND (self);
   tile_backend_file = GEGL_TILE_BACKEND_FILE (backend);
-  entry             = lookup_entry (tile_backend_file, x, y, z);
+  entry             = gegl_tile_backend_file_lookup_entry (tile_backend_file, x, y, z);
 
   return entry!=NULL?((gpointer)0x1):NULL;
 }
 
 
 static gpointer
-flush (GeglTileSource *source,
-       GeglTile       *tile,
-       gint            x,
-       gint            y,
-       gint            z)
+gegl_tile_backend_file_flush (GeglTileSource *source,
+                              GeglTile       *tile,
+                              gint            x,
+                              gint            y,
+                              gint            z)
 {
   GeglTileBackend     *backend;
   GeglTileBackendFile *self;
@@ -536,9 +552,9 @@ flush (GeglTileSource *source,
   backend  = GEGL_TILE_BACKEND (source);
   self     = GEGL_TILE_BACKEND_FILE (backend);
 
-  ensure_exist (self);
+  gegl_tile_backend_file_ensure_exist (self);
 
-  GEGL_NOTE (TILE_BACKEND, "flushing %s", self->path);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "flushing %s", self->path);
 
 
   self->header.rev ++;
@@ -556,20 +572,20 @@ flush (GeglTileSource *source,
         {
           GeglBufferItem *item = iter->data;
 
-          write_block (self, &item->block);
+          gegl_tile_backend_file_write_block (self, &item->block);
         }
-      write_block (self, NULL); /* terminate the index */
+      gegl_tile_backend_file_write_block (self, NULL); /* terminate the index */
       g_list_free (tiles);
     }
 
-  write_header (self);
+  gegl_tile_backend_file_write_header (self);
 #if HAVE_GIO
   g_output_stream_flush (self->o, NULL, NULL);
 #else
   fsync (self->o);
 #endif
 
-  GEGL_NOTE (TILE_BACKEND, "flushed %s", self->path);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "flushed %s", self->path);
 
   return (gpointer)0xf0f;
 }
@@ -591,23 +607,23 @@ gegl_tile_backend_file_command (GeglTileSource  *self,
   switch (command)
     {
       case GEGL_TILE_GET:
-        return get_tile (self, x, y, z);
+        return gegl_tile_backend_file_get_tile (self, x, y, z);
       case GEGL_TILE_SET:
-        return set_tile (self, data, x, y, z);
+        return gegl_tile_backend_file_set_tile (self, data, x, y, z);
 
       case GEGL_TILE_IDLE:
         return NULL;       /* we could perhaps lazily be writing indexes
-                              at some intervals, making it work as an
-                              autosave for the buffer?
+                            * at some intervals, making it work as an
+                            * autosave for the buffer?
                             */
 
       case GEGL_TILE_VOID:
-        return void_tile (self, data, x, y, z);
+        return gegl_tile_backend_file_void_tile (self, data, x, y, z);
 
       case GEGL_TILE_EXIST:
-        return exist_tile (self, data, x, y, z);
+        return gegl_tile_backend_file_exist_tile (self, data, x, y, z);
       case GEGL_TILE_FLUSH:
-        return flush (self, data, x, y, z);
+        return gegl_tile_backend_file_flush (self, data, x, y, z);
 
       default:
         g_assert (command < GEGL_TILE_LAST_COMMAND &&
@@ -617,10 +633,10 @@ gegl_tile_backend_file_command (GeglTileSource  *self,
 }
 
 static void
-set_property (GObject      *object,
-              guint         property_id,
-              const GValue *value,
-              GParamSpec   *pspec)
+gegl_tile_backend_file_set_property (GObject      *object,
+                                     guint         property_id,
+                                     const GValue *value,
+                                     GParamSpec   *pspec)
 {
   GeglTileBackendFile *self = GEGL_TILE_BACKEND_FILE (object);
 
@@ -639,10 +655,10 @@ set_property (GObject      *object,
 }
 
 static void
-get_property (GObject    *object,
-              guint       property_id,
-              GValue     *value,
-              GParamSpec *pspec)
+gegl_tile_backend_file_get_property (GObject    *object,
+                                     guint       property_id,
+                                     GValue     *value,
+                                     GParamSpec *pspec)
 {
   GeglTileBackendFile *self = GEGL_TILE_BACKEND_FILE (object);
 
@@ -659,7 +675,7 @@ get_property (GObject    *object,
 }
 
 static void
-finalize (GObject *object)
+gegl_tile_backend_file_finalize (GObject *object)
 {
   GeglTileBackendFile *self = (GeglTileBackendFile *) object;
 
@@ -668,7 +684,7 @@ finalize (GObject *object)
 
   if (self->exist)
     {
-      GEGL_NOTE (TILE_BACKEND, "finalizing buffer %s", self->path);
+      GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "finalizing buffer %s", self->path);
 
 #if HAVE_GIO
       if (self->i)
@@ -680,14 +696,14 @@ finalize (GObject *object)
         g_file_delete  (self->file, NULL, NULL);
 #else
       if (self->i != -1)
-	    {
+        {
           close (self->i);
           self->i = -1;
         }
       if (self->o != -1)
-	    {
+        {
           close (self->o);
-		  self->o = -1;
+          self->o = -1;
         }
 #endif
     }
@@ -707,7 +723,7 @@ finalize (GObject *object)
 }
 
 static guint
-hashfunc (gconstpointer key)
+gegl_tile_backend_file_hashfunc (gconstpointer key)
 {
   const GeglBufferTile *e = key;
   guint            hash;
@@ -723,9 +739,7 @@ hashfunc (gconstpointer key)
   hash = 0;
   for (i = 9; i >= 0; i--)
     {
-#define ADD_BIT(bit)    do { hash |= (((bit) != 0) ? 1 : 0); hash <<= 1; \
-    } \
-  while (0)
+#define ADD_BIT(bit)    do { hash |= (((bit) != 0) ? 1 : 0); hash <<= 1; } while (0)
       ADD_BIT (srcA & (1 << i));
       ADD_BIT (srcB & (1 << i));
       ADD_BIT (srcC & (1 << i));
@@ -735,7 +749,7 @@ hashfunc (gconstpointer key)
 }
 
 static gboolean
-equalfunc (gconstpointer a,
+gegl_tile_backend_file_equalfunc (gconstpointer a,
            gconstpointer b)
 {
   const GeglBufferTile *ea = a;
@@ -751,8 +765,8 @@ equalfunc (gconstpointer a,
 
 
 static void
-load_index (GeglTileBackendFile *self,
-            gboolean             block)
+gegl_tile_backend_file_load_index (GeglTileBackendFile *self,
+                                   gboolean             block)
 {
   GeglBufferHeader new_header;
   GList           *iter;
@@ -760,9 +774,9 @@ load_index (GeglTileBackendFile *self,
   goffset offset = 0;
   goffset max=0;
 
-/* compute total from and next pre alloc by monitoring tiles as they
- * are added here
- */
+  /* compute total from and next pre alloc by monitoring tiles as they
+   * are added here
+   */
   /* reload header */
   new_header = gegl_buffer_read_header (self->i, &offset)->header;
 
@@ -774,13 +788,13 @@ load_index (GeglTileBackendFile *self,
 
   if (new_header.rev == self->header.rev)
     {
-      GEGL_NOTE(TILE_BACKEND, "header not changed: %s", self->path);
+      GEGL_NOTE(GEGL_DEBUG_TILE_BACKEND, "header not changed: %s", self->path);
       return;
     }
   else
     {
       self->header=new_header;
-      GEGL_NOTE(TILE_BACKEND, "loading index: %s", self->path);
+      GEGL_NOTE(GEGL_DEBUG_TILE_BACKEND, "loading index: %s", self->path);
     }
 
 
@@ -811,9 +825,9 @@ load_index (GeglTileBackendFile *self,
               GeglRectangle rect;
               g_hash_table_remove (self->index, existing);
               gegl_tile_source_refetch (GEGL_TILE_SOURCE (backend->storage),
-                                            existing->tile.x,
-                                            existing->tile.y,
-                                            existing->tile.z);
+                                        existing->tile.x,
+                                        existing->tile.y,
+                                        existing->tile.z);
 
               if (existing->tile.z == 0)
                 {
@@ -826,7 +840,7 @@ load_index (GeglTileBackendFile *self,
               g_signal_emit_by_name (backend->storage, "changed", &rect, NULL);
             }
         }
-        g_hash_table_insert (self->index, iter->data, iter->data);
+      g_hash_table_insert (self->index, iter->data, iter->data);
     }
   g_list_free (self->tiles);
   g_slist_free (self->free_list);
@@ -838,16 +852,15 @@ load_index (GeglTileBackendFile *self,
 
 #if HAVE_GIO
 static void
-file_changed (GFileMonitor        *monitor,
+gegl_tile_backend_file_file_changed (GFileMonitor        *monitor,
               GFile               *file,
               GFile               *other_file,
               GFileMonitorEvent    event_type,
               GeglTileBackendFile *self)
 {
-  if (event_type == G_FILE_MONITOR_EVENT_CHANGED)
-  /*if (event_type == G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT)*/
+  if (event_type == G_FILE_MONITOR_EVENT_CHANGED /*G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT*/ )
     {
-      load_index (self, TRUE);
+      gegl_tile_backend_file_load_index (self, TRUE);
     }
 }
 #endif
@@ -865,13 +878,13 @@ gegl_tile_backend_file_constructor (GType                  type,
   self    = GEGL_TILE_BACKEND_FILE (object);
   backend = GEGL_TILE_BACKEND (object);
 
-  GEGL_NOTE (TILE_BACKEND, "constructing file backend: %s", self->path);
+  GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "constructing file backend: %s", self->path);
 #if HAVE_GIO
   self->file = g_file_new_for_commandline_arg (self->path);
 #else
   self->i = self->o = -1;
 #endif
-  self->index = g_hash_table_new (hashfunc, equalfunc);
+  self->index = g_hash_table_new (gegl_tile_backend_file_hashfunc, gegl_tile_backend_file_equalfunc);
 
   /* If the file already exists open it, assuming it is a GeglBuffer. */
 #if HAVE_GIO
@@ -889,7 +902,7 @@ gegl_tile_backend_file_constructor (GType                  type,
       self->monitor = g_file_monitor_file (self->file, G_FILE_MONITOR_NONE,
                                            NULL, NULL);
       g_signal_connect (self->monitor, "changed",
-                        G_CALLBACK (file_changed),
+                        G_CALLBACK (gegl_tile_backend_file_file_changed),
                         self);
 
 #ifndef HACKED_GIO_WITH_READWRITE
@@ -906,8 +919,8 @@ gegl_tile_backend_file_constructor (GType                  type,
       self->i = g_object_get_data (G_OBJECT (self->o), "istream");
 #endif
 #else
-	  self->o = open (self->path, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
-	  self->i = dup (self->o);
+      self->o = open (self->path, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
+      self->i = dup (self->o);
 #endif
       /*self->i = G_INPUT_STREAM (g_file_read (self->file, NULL, NULL));*/
       self->header = gegl_buffer_read_header (self->i, &offset)->header;
@@ -917,11 +930,11 @@ gegl_tile_backend_file_constructor (GType                  type,
       backend->tile_width = self->header.tile_width;
       backend->tile_height = self->header.tile_height;
       backend->format = babl_format (self->header.description);
-      backend->px_size = backend->format->format.bytes_per_pixel;
+      backend->px_size = babl_format_get_bytes_per_pixel (backend->format);
       backend->tile_size = backend->tile_width * backend->tile_height * backend->px_size;
 
       /* insert each of the entries into the hash table */
-      load_index (self, TRUE);
+      gegl_tile_backend_file_load_index (self, TRUE);
       self->exist = TRUE;
 #if HAVE_GIO
       g_assert (self->i);
@@ -949,7 +962,7 @@ gegl_tile_backend_file_constructor (GType                  type,
 }
 
 static void
-ensure_exist (GeglTileBackendFile *self)
+gegl_tile_backend_file_ensure_exist (GeglTileBackendFile *self)
 {
   if (!self->exist)
     {
@@ -958,7 +971,7 @@ ensure_exist (GeglTileBackendFile *self)
       self->exist = TRUE;
       backend = GEGL_TILE_BACKEND (self);
 
-      GEGL_NOTE (TILE_BACKEND, "creating swapfile  %s", self->path);
+      GEGL_NOTE (GEGL_DEBUG_TILE_BACKEND, "creating swapfile  %s", self->path);
 #ifdef HACKED_GIO_WITH_READWRITE
 
       self->o = G_OUTPUT_STREAM (g_file_append_to (self->file,
@@ -969,8 +982,8 @@ ensure_exist (GeglTileBackendFile *self)
                                backend->tile_height,
                                backend->px_size,
                                backend->format
-                             );
-      write_header (self);
+                               );
+      gegl_tile_backend_file_write_header (self);
       g_output_stream_flush (self->o, NULL, NULL);
       self->i = g_object_get_data (G_OBJECT (self->o), "istream");
 #else
@@ -979,7 +992,7 @@ ensure_exist (GeglTileBackendFile *self)
       self->o = G_OUTPUT_STREAM (g_file_replace (self->file, NULL, FALSE, G_FILE_CREATE_NONE, NULL, NULL));
       g_output_stream_flush (self->o, NULL, NULL);
 #else
-	  self->o = open (self->path, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
+      self->o = open (self->path, O_RDWR|O_CREAT, S_IRUSR|S_IWUSR|S_IRGRP|S_IWGRP|S_IROTH|S_IWOTH);
 #endif
 
       self->next_pre_alloc = 256;  /* reserved space for header */
@@ -993,7 +1006,7 @@ ensure_exist (GeglTileBackendFile *self)
                                backend->px_size,
                                backend->format
                                );
-      write_header (self);
+      gegl_tile_backend_file_write_header (self);
 #if HAVE_GIO
       g_output_stream_flush (self->o, NULL, NULL);
       self->i = G_INPUT_STREAM (g_file_read (self->file, NULL, NULL));
@@ -1024,10 +1037,10 @@ gegl_tile_backend_file_class_init (GeglTileBackendFileClass *klass)
 
   parent_class = g_type_class_peek_parent (klass);
 
-  gobject_class->get_property = get_property;
-  gobject_class->set_property = set_property;
+  gobject_class->get_property = gegl_tile_backend_file_get_property;
+  gobject_class->set_property = gegl_tile_backend_file_set_property;
   gobject_class->constructor  = gegl_tile_backend_file_constructor;
-  gobject_class->finalize     = finalize;
+  gobject_class->finalize     = gegl_tile_backend_file_finalize;
 
   gegl_tile_source_class->command = gegl_tile_backend_file_command;
 
@@ -1070,7 +1083,7 @@ gegl_tile_backend_file_try_lock (GeglTileBackendFile *self)
       return FALSE;
     }
   self->header.flags += GEGL_FLAG_LOCKED;
-  write_header (self);
+  gegl_tile_backend_file_write_header (self);
 #if HAVE_GIO
   g_output_stream_flush (self->o, NULL, NULL);
 #else
@@ -1079,7 +1092,8 @@ gegl_tile_backend_file_try_lock (GeglTileBackendFile *self)
   return TRUE;
 }
 
-gboolean gegl_tile_backend_file_unlock (GeglTileBackendFile *self)
+gboolean
+gegl_tile_backend_file_unlock (GeglTileBackendFile *self)
 {
   if (!(self->header.flags & GEGL_FLAG_LOCKED))
     {
@@ -1087,7 +1101,7 @@ gboolean gegl_tile_backend_file_unlock (GeglTileBackendFile *self)
       return FALSE;
     }
   self->header.flags -= GEGL_FLAG_LOCKED;
-  write_header (self);
+  gegl_tile_backend_file_write_header (self);
 #if HAVE_GIO
   g_output_stream_flush (self->o, NULL, NULL);
 #else
