@@ -124,7 +124,12 @@ lookup_entry (GeglTileBackendRam *self,
               gint         y,
               gint         z)
 {
-  RamEntry key = { x, y, z, 0 };
+  RamEntry key;
+
+  key.x = x;
+  key.y = y;
+  key.z = z;
+  key.offset = 0;
 
   return g_hash_table_lookup (self->entries, &key);
 }
@@ -220,7 +225,7 @@ gboolean exist_tile (GeglTileSource *store,
 
 enum
 {
-  PROP_0,
+  PROP_0
 };
 
 static gpointer
