@@ -15,6 +15,7 @@
  *
  * Copyright 2006,2007 Øyvind Kolås <pippin@gimp.org>
  */
+#include "config.h"
 #include <glib.h>
 #include <glib-object.h>
 #include <string.h>
@@ -146,16 +147,16 @@ constructor (GType                  type,
 
 
 static gpointer
-command (GeglTileSource  *buffer,
-         GeglTileCommand  command,
-         gint             x,
-         gint             y,
-         gint             z,
-         gpointer         data)
+gegl_tile_handler_empty_command (GeglTileSource  *buffer,
+                                 GeglTileCommand  command,
+                                 gint             x,
+                                 gint             y,
+                                 gint             z,
+                                 gpointer         data)
 {
   if (command == GEGL_TILE_GET)
     return get_tile (buffer, x, y, z);
-  return gegl_tile_handler_chain_up (GEGL_HANDLER(buffer), command, x, y, z, data);
+  return gegl_tile_handler_chain_up (buffer, command, x, y, z, data);
 }
 
 
@@ -169,7 +170,7 @@ gegl_tile_handler_empty_class_init (GeglTileHandlerEmptyClass *klass)
   gobject_class->finalize     = finalize;
   gobject_class->set_property = set_property;
   gobject_class->get_property = get_property;
-  source_class->command = command;
+  source_class->command = gegl_tile_handler_empty_command;
 
   g_object_class_install_property (gobject_class, PROP_BACKEND,
                                    g_param_spec_object ("backend",
