@@ -15,6 +15,7 @@
  *
  * Copyright 2006, 2007 Øyvind Kolås <pippin@gimp.org>
  */
+#include "config.h"
 #include <glib.h>
 #include <glib-object.h>
 #include <string.h>
@@ -41,12 +42,12 @@ static char *commands[] =
 };
 
 static gpointer
-command (GeglTileSource  *gegl_tile_source,
-         GeglTileCommand  command,
-         gint             x,
-         gint             y,
-         gint             z,
-         gpointer         data)
+gegl_tile_handler_log_command (GeglTileSource  *gegl_tile_source,
+                               GeglTileCommand  command,
+                               gint             x,
+                               gint             y,
+                               gint             z,
+                               gpointer         data)
 {
   GeglTileHandler *handler = GEGL_HANDLER (gegl_tile_source);
   gpointer         result = NULL;
@@ -75,7 +76,7 @@ gegl_tile_handler_log_class_init (GeglTileHandlerLogClass *klass)
 {
   GeglTileSourceClass *source_class = GEGL_TILE_SOURCE_CLASS (klass);
 
-  source_class->command  = command;
+  source_class->command = gegl_tile_handler_log_command;
 }
 
 static void
