@@ -15,6 +15,7 @@
  *
  * Copyright 2006,2007 Øyvind Kolås <pippin@gimp.org>
  */
+#include "config.h"
 #include <glib.h>
 #include <glib-object.h>
 #include "gegl-tile-source.h"
@@ -22,7 +23,7 @@
 G_DEFINE_TYPE (GeglTileSource, gegl_tile_source, G_TYPE_OBJECT)
 
 static gpointer
-command (GeglTileSource  *gegl_tile_source,
+gegl_tile_source_command_eek (GeglTileSource  *gegl_tile_source,
          GeglTileCommand  command,
          gint             x,
          gint             y,
@@ -36,25 +37,10 @@ command (GeglTileSource  *gegl_tile_source,
 static void
 gegl_tile_source_class_init (GeglTileSourceClass *klass)
 {  
-  klass->command  = command;
+  klass->command = gegl_tile_source_command_eek;
 }
 
 static void
 gegl_tile_source_init (GeglTileSource *self)
 {
 }
-
-gpointer
-gegl_tile_source_command (GeglTileSource  *gegl_tile_source,
-                          GeglTileCommand  command,
-                          gint             x,
-                          gint             y,
-                          gint             z,
-                          gpointer         data)
-{
-  GeglTileSourceClass *klass;
-
-  klass = GEGL_TILE_SOURCE_GET_CLASS (gegl_tile_source);
-
-  return klass->command (gegl_tile_source, command, x, y, z, data);
-}
