@@ -20,6 +20,7 @@
 
 #include <glib-object.h>
 
+#include "gegl.h"
 #include "gegl-tile-storage.h"
 #include "gegl-tile.h"
 #include "gegl-tile-backend-file.h"
@@ -31,7 +32,7 @@
 #include "gegl-tile-handler-zoom.h"
 #include "gegl-tile-handler-cache.h"
 #include "gegl-tile-handler-log.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
 #include "gegl-config.h"
 
@@ -198,34 +199,31 @@ gegl_tile_storage_constructor (GType                  type,
   if (tile_storage->path != NULL)
     {
 #if 1
-      g_object_set (tile_storage,
-                    "source", g_object_new (GEGL_TYPE_TILE_BACKEND_FILE,
+      gegl_tile_handler_set_source (handler,
+                              g_object_new (GEGL_TYPE_TILE_BACKEND_FILE,
                                             "tile-width", tile_storage->tile_width,
                                             "tile-height", tile_storage->tile_height,
                                             "format", tile_storage->format,
                                             "path", tile_storage->path,
-                                            NULL),
-                    NULL);
+                                            NULL));
 #else
-      g_object_set (tile_storage,
-                    "source", g_object_new (GEGL_TYPE_TILE_BACKEND_TILEDIR,
+      gegl_tile_handler_set_source (handler,
+                    g_object_new (GEGL_TYPE_TILE_BACKEND_TILEDIR,
                                             "tile-width", tile_storage->tile_width,
                                             "tile-height", tile_storage->tile_height,
                                             "format", tile_storage->format,
                                             "path", tile_storage->path,
-                                            NULL),
-                    NULL);
+                                            NULL));
 #endif
     }
   else
     {
-      g_object_set (tile_storage,
-                    "source", g_object_new (GEGL_TYPE_TILE_BACKEND_RAM,
+      gegl_tile_handler_set_source (handler,
+                              g_object_new (GEGL_TYPE_TILE_BACKEND_RAM,
                                             "tile-width", tile_storage->tile_width,
                                             "tile-height", tile_storage->tile_height,
                                             "format", tile_storage->format,
-                                            NULL),
-                    NULL);
+                                            NULL));
     }
 
   g_object_get (handler->source,
@@ -274,6 +272,7 @@ gegl_tile_storage_constructor (GType                  type,
                                               tile_storage_idle,
                                               tile_storage,
                                               NULL);
+  tile_storage->seen_zoom = FALSE;
 
   return object;
 }
