@@ -107,7 +107,7 @@ typedef struct
   GeglOperationClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_META
@@ -123,7 +123,7 @@ typedef struct
   GeglOperationMetaClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_META);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_META)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_SOURCE
@@ -138,7 +138,7 @@ typedef struct
   GeglOperationSourceClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_SOURCE);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_SOURCE)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_SINK
@@ -153,7 +153,7 @@ typedef struct
   GeglOperationSinkClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_SINK);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_SINK)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_FILTER
@@ -168,7 +168,7 @@ typedef struct
   GeglOperationFilterClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_FILTER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_FILTER)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_COMPOSER
@@ -183,7 +183,7 @@ typedef struct
   GeglOperationComposerClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER)
 
 #endif
 
@@ -199,7 +199,7 @@ typedef struct
   GeglOperationComposer3Class parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER3);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_COMPOSER3)
 
 #endif
 
@@ -215,7 +215,7 @@ typedef struct
   GeglOperationPointFilterClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_FILTER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_FILTER)
 
 #endif
 
@@ -232,7 +232,7 @@ typedef struct
   GeglOperationPointRenderClass parent_class;
 } GeglChantClass;
 
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_RENDER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_RENDER)
 
 #endif
 
@@ -248,7 +248,7 @@ typedef struct
 {
   GeglOperationTemporalClass parent_class;
 } GeglChantClass;
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_TEMPORAL);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_TEMPORAL)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_AREA_FILTER
@@ -262,7 +262,7 @@ typedef struct
 {
   GeglOperationAreaFilterClass parent_class;
 } GeglChantClass;
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_AREA_FILTER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_AREA_FILTER)
 #endif
 
 
@@ -277,7 +277,7 @@ typedef struct
 {
   GeglOperationPointComposerClass parent_class;
 } GeglChantClass;
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER)
 #endif
 
 #ifdef GEGL_CHANT_TYPE_POINT_COMPOSER3
@@ -291,7 +291,7 @@ typedef struct
 {
   GeglOperationPointComposer3Class parent_class;
 } GeglChantClass;
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER3);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_POINT_COMPOSER3)
 #endif
 
 #define GEGL_CHANT(obj)  ((GeglChant*)(obj))
@@ -347,14 +347,15 @@ struct _GeglChantO
 #define gegl_chant_double(name, nick, min, max, def, blurb)  gdouble     name;
 #define gegl_chant_boolean(name, nick, def, blurb)           gboolean    name;
 #define gegl_chant_string(name, nick, def, blurb)            gchar      *name;
-#define gegl_chant_path(name, nick, def, blurb)              gchar      *name;
+#define gegl_chant_file_path(name, nick, def, blurb)         gchar      *name;
 #define gegl_chant_multiline(name, nick, def, blurb)         gchar      *name;
 #define gegl_chant_multiline(name, nick, def, blurb)         gchar      *name;
 #define gegl_chant_object(name,nick,  blurb)                 GObject    *name;
 #define gegl_chant_pointer(name, nick, blurb)                gpointer    name;
 #define gegl_chant_color(name, nick, def, blurb)             GeglColor  *name;
 #define gegl_chant_curve(name, nick, blurb)                  GeglCurve  *name;
-#define gegl_chant_vector(name, nick, blurb)                 GeglVector *name;
+#define gegl_chant_path(name, nick, blurb)                   GeglPath   *name;\
+                                                   guint path_changed_handler;
 
 #include GEGL_CHANT_C_FILE
 
@@ -362,14 +363,14 @@ struct _GeglChantO
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
 };
 
 #define GEGL_CHANT_OPERATION(obj) ((Operation*)(obj))
@@ -381,13 +382,13 @@ enum
 #define gegl_chant_double(name, nick, min, max, def, blurb)  PROP_##name,
 #define gegl_chant_boolean(name, nick, def, blurb)           PROP_##name,
 #define gegl_chant_string(name, nick, def, blurb)            PROP_##name,
-#define gegl_chant_path(name, nick, def, blurb)              PROP_##name,
+#define gegl_chant_file_path(name, nick, def, blurb)         PROP_##name,
 #define gegl_chant_multiline(name, nick, def, blurb)         PROP_##name,
 #define gegl_chant_object(name, nick, blurb)                 PROP_##name,
 #define gegl_chant_pointer(name, nick, blurb)                PROP_##name,
 #define gegl_chant_color(name, nick, def, blurb)             PROP_##name,
 #define gegl_chant_curve(name, nick, blurb)                  PROP_##name,
-#define gegl_chant_vector(name, nick, blurb)                 PROP_##name,
+#define gegl_chant_path(name, nick, blurb)                   PROP_##name,
 
 #include GEGL_CHANT_C_FILE
 
@@ -395,13 +396,13 @@ enum
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
   PROP_LAST
 };
 
@@ -433,7 +434,7 @@ get_property (GObject      *gobject,
     case PROP_##name:                                         \
       g_value_set_string (value, properties->name);           \
       break;
-#define gegl_chant_path(name, nick, def, blurb)               \
+#define gegl_chant_file_path(name, nick, def, blurb)          \
     case PROP_##name:                                         \
       g_value_set_string (value, properties->name);           \
       break;
@@ -457,8 +458,9 @@ get_property (GObject      *gobject,
     case PROP_##name:                                         \
       g_value_set_object (value, properties->name);           \
       break;
-#define gegl_chant_vector(name, nick, blurb)                  \
+#define gegl_chant_path(name, nick, blurb)                    \
     case PROP_##name:                                         \
+      if (!properties->name)properties->name = gegl_path_new (); /* this feels ugly */\
       g_value_set_object (value, properties->name);           \
       break;/*XXX*/
 
@@ -468,13 +470,13 @@ get_property (GObject      *gobject,
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
       break;
@@ -511,7 +513,7 @@ set_property (GObject      *gobject,
         g_free (properties->name);                                    \
       properties->name = g_strdup (g_value_get_string (value));       \
       break;
-#define gegl_chant_path(name, nick, def, blurb)                       \
+#define gegl_chant_file_path(name, nick, def, blurb)                  \
     case PROP_##name:                                                 \
       if (properties->name)                                           \
         g_free (properties->name);                                    \
@@ -545,19 +547,21 @@ set_property (GObject      *gobject,
          g_object_unref (properties->name);                           \
       properties->name = g_value_dup_object (value);                  \
       break;
-#define gegl_chant_vector(name, nick, blurb)                          \
+#define gegl_chant_path(name, nick, blurb)                            \
     case PROP_##name:                                                 \
       if (properties->name != NULL)                                   \
-        {/*XXX: remove old signal */                                  \
-         g_object_unref (properties->name);                           \
+        {\
+          if (properties->path_changed_handler) \
+            g_signal_handler_disconnect (G_OBJECT (properties->name), properties->path_changed_handler);\
+         properties->path_changed_handler = 0;\
         }                                                             \
       properties->name = NULL;                                        \
       if (g_value_peek_pointer (value))                               \
         {                                                             \
           properties->name = g_value_dup_object (value);              \
-          g_signal_connect (G_OBJECT (properties->name), "changed",   \
-          G_CALLBACK(gegl_operation_vector_prop_changed), gobject);   \
-         }
+          properties->path_changed_handler = g_signal_connect (G_OBJECT (properties->name), "changed",   \
+          G_CALLBACK(path_changed), gobject);     \
+         }\
       break; /*XXX*/
 
 #include GEGL_CHANT_C_FILE
@@ -566,13 +570,13 @@ set_property (GObject      *gobject,
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
 
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, property_id, pspec);
@@ -593,7 +597,7 @@ static void gegl_chant_destroy_notify (gpointer data)
       g_free (properties->name);                    \
       properties->name = NULL;                      \
     }
-#define gegl_chant_path(name, nick, def, blurb)     \
+#define gegl_chant_file_path(name, nick, def, blurb) \
   if (properties->name)                             \
     {                                               \
       g_free (properties->name);                    \
@@ -624,7 +628,7 @@ static void gegl_chant_destroy_notify (gpointer data)
       g_object_unref (properties->name);            \
       properties->name = NULL;                      \
     }
-#define gegl_chant_vector(name, nick, blurb)        \
+#define gegl_chant_path(name, nick, blurb)          \
   if (properties->name)                             \
     {                                               \
       g_object_unref (properties->name);            \
@@ -637,13 +641,13 @@ static void gegl_chant_destroy_notify (gpointer data)
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
 
   g_slice_free (GeglChantO, properties);
 }
@@ -654,10 +658,43 @@ gegl_chant_constructor (GType                  type,
                         GObjectConstructParam *construct_properties)
 {
   GObject *obj;
+  GeglChantO *properties;
 
   obj = G_OBJECT_CLASS (gegl_chant_parent_class)->constructor (
             type, n_construct_properties, construct_properties);
 
+  /* create dummy colors and vectors */
+  properties = GEGL_CHANT_PROPERTIES (obj);
+
+#define gegl_chant_int(name, nick, min, max, def, blurb)              
+#define gegl_chant_double(name, nick, min, max, def, blurb)           
+#define gegl_chant_boolean(name, nick, def, blurb)                    
+#define gegl_chant_string(name, nick, def, blurb)                     
+#define gegl_chant_file_path(name, nick, def, blurb)                  
+#define gegl_chant_multiline(name, nick, def, blurb)                  
+#define gegl_chant_object(name, nick, blurb)                          
+#define gegl_chant_pointer(name, nick, blurb)                         
+#define gegl_chant_color(name, nick, def, blurb)              \
+    if (properties->name == NULL) \
+    {properties->name = gegl_color_new(def?def:"black");}
+#define gegl_chant_path(name, nick, blurb)
+#define gegl_chant_curve(name, nick, blurb)
+
+#include GEGL_CHANT_C_FILE
+
+#undef gegl_chant_int
+#undef gegl_chant_double
+#undef gegl_chant_boolean
+#undef gegl_chant_string
+#undef gegl_chant_file_path
+#undef gegl_chant_multiline
+#undef gegl_chant_object
+#undef gegl_chant_pointer
+#undef gegl_chant_color
+#undef gegl_chant_curve
+#undef gegl_chant_path
+
+
   g_object_set_data_full (obj, "chant-data", obj, gegl_chant_destroy_notify);
   return obj;
 }
@@ -703,9 +740,9 @@ gegl_chant_class_intern_init (gpointer klass)
                                                         G_PARAM_READWRITE |  \
                                                         G_PARAM_CONSTRUCT |  \
                                                         GEGL_PARAM_PAD_INPUT)));
-#define gegl_chant_path(name, nick, def, blurb)                              \
+#define gegl_chant_file_path(name, nick, def, blurb)                              \
   g_object_class_install_property (object_class, PROP_##name,                \
-                                   gegl_param_spec_path (#name, nick, blurb, \
+                                   gegl_param_spec_file_path (#name, nick, blurb, \
                                                          FALSE, FALSE,       \
                                                          def,                \
                                                          (GParamFlags) (     \
@@ -740,6 +777,14 @@ gegl_chant_class_intern_init (gpointer klass)
                                    gegl_param_spec_color_from_string (#name, nick, blurb,\
                                                           def,               \
                                                           (GParamFlags) (    \
+                                                          G_PARAM_READWRITE |\
+														  G_PARAM_CONSTRUCT | \
+                                                          GEGL_PARAM_PAD_INPUT)));
+#define gegl_chant_path(name, nick, blurb)                                 \
+  g_object_class_install_property (object_class, PROP_##name,                \
+                                   gegl_param_spec_path (#name, nick, blurb,\
+                                                           NULL,             \
+                                                          (GParamFlags) (    \
                                                           G_PARAM_READWRITE |\
                                                           G_PARAM_CONSTRUCT |\
                                                           GEGL_PARAM_PAD_INPUT)));
@@ -751,14 +796,6 @@ gegl_chant_class_intern_init (gpointer klass)
                                                           G_PARAM_READWRITE |\
                                                           G_PARAM_CONSTRUCT |\
                                                           GEGL_PARAM_PAD_INPUT)));
-#define gegl_chant_vector(name, nick, blurb)                                 \
-  g_object_class_install_property (object_class, PROP_##name,                \
-                                   gegl_param_spec_vector (#name, nick, blurb,\
-                                                           NULL,             \
-                                                          (GParamFlags) (    \
-                                                          G_PARAM_READWRITE |\
-                                                          G_PARAM_CONSTRUCT |\
-                                                          GEGL_PARAM_PAD_INPUT)));
 
 
 #include GEGL_CHANT_C_FILE
@@ -767,13 +804,13 @@ gegl_chant_class_intern_init (gpointer klass)
 #undef gegl_chant_double
 #undef gegl_chant_boolean
 #undef gegl_chant_string
-#undef gegl_chant_path
+#undef gegl_chant_file_path
 #undef gegl_chant_multiline
 #undef gegl_chant_object
 #undef gegl_chant_pointer
 #undef gegl_chant_color
 #undef gegl_chant_curve
-#undef gegl_chant_vector
+#undef gegl_chant_path
 }
 
 
