@@ -25,6 +25,8 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#include <locale.h>
+
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
@@ -68,7 +70,7 @@ guint gegl_debug_flags = 0;
 #include "gegl-init.h"
 #include "module/geglmodule.h"
 #include "module/geglmoduledb.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "buffer/gegl-buffer.h"
 #include "operation/gegl-operation.h"
 #include "operation/gegl-operations.h"
@@ -94,8 +96,8 @@ gegl_swap_dir (void)
         }
       else
         {
-          swapdir = g_build_filename (g_get_home_dir(),
-                                      "." GEGL_LIBRARY,
+          swapdir = g_build_filename (g_get_user_cache_dir(),
+                                      GEGL_LIBRARY,
                                       "swap",
                                       NULL);
         }
@@ -247,8 +249,7 @@ gegl_get_option_group (void)
   return group;
 }
 
-GObject *gegl_config (void);
-GObject *gegl_config (void)
+GeglConfig *gegl_config (void)
 {
   if (!config)
     {
@@ -270,7 +271,7 @@ GObject *gegl_config (void)
       if (gegl_swap_dir())
         config->swap = g_strdup(gegl_swap_dir ());
     }
-  return G_OBJECT (config);
+  return GEGL_CONFIG (config);
 }
 
 void gegl_tile_backend_ram_stats (void);
@@ -333,7 +334,7 @@ gegl_exit (void)
       module_db = NULL;
     }
 
-  babl_destroy ();
+  babl_exit ();
 
   timing = gegl_ticks () - timing;
   gegl_instrument ("gegl", "gegl_exit", timing);
@@ -512,9 +513,9 @@ gegl_post_parse_hook (GOptionContext *context,
           gegl_module_db_load (module_db, module_path);
           g_free (module_path);
 
-          /* also load plug-ins from ~/.gegl-0.0/plug-ins */
-          module_path = g_build_filename (g_get_home_dir (),
-                                          "." GEGL_LIBRARY,
+          /* also load plug-ins from ~/.local/share/gegl-0.0/plugins */
+          module_path = g_build_filename (g_get_user_data_dir (),
+                                          GEGL_LIBRARY,
                                           "plug-ins",
                                           NULL);
 
