@@ -20,10 +20,10 @@
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
-
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 
 
 inline gint
@@ -175,6 +175,32 @@ gegl_rectangle_dup (const GeglRectangle *rectangle)
   return result;
 }
 
+GeglRectangle
+gegl_rectangle_infinite_plane (void)
+{
+  GeglRectangle infinite_plane_rect = {G_MININT / 2, G_MININT / 2, G_MAXINT, G_MAXINT};
+  return infinite_plane_rect;
+}
+
+gboolean
+gegl_rectangle_is_infinite_plane (const GeglRectangle *rectangle)
+{
+  return (rectangle->x      == G_MININT / 2 &&
+          rectangle->y      == G_MININT / 2 &&
+          rectangle->width  == G_MAXINT     &&
+          rectangle->height == G_MAXINT);
+}
+
+void
+gegl_rectangle_dump (const GeglRectangle *rectangle)
+{
+  g_print ("%d, %d, %d×%d\n",
+           rectangle->x,
+           rectangle->y,
+           rectangle->width,
+           rectangle->height);
+}
+
 GType
 gegl_rectangle_get_type (void)
 {
