@@ -25,7 +25,7 @@
 #include <limits.h>
 
 #include "gegl.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "graph/gegl-node.h"
 #include "graph/gegl-pad.h"
 #include "operation/gegl-operation.h"
@@ -544,305 +544,6 @@ free_clone_id (gpointer key,
   g_free (value);
 }
 
-#if 0
-
-static void
-tuple_old (GString     *buf,
-           const gchar *key,
-           const gchar *value)
-{
-  g_assert (key);
-
-  if (value)
-    {
-      gchar *text = g_markup_escape_text (value, -1);
-      gchar *p;
-
-      g_string_append_c (buf, ' ');
-      g_string_append (buf, key);
-      g_string_append_c (buf, '=');
-      g_string_append_c (buf, '\'');
-      for (p = text; *p; p++)
-        {
-          if (*p == '\n')
-            g_string_append (buf, "&#10;");
-          else
-            g_string_append_c (buf, *p);
-        }
-      g_string_append_c (buf, '\'');
-
-      g_free (text);
-    }
-}
-
-static void
-encode_node_attributes_old (SerializeState *ss,
-                            GeglNode       *node,
-                            const gchar    *id)
-{
-  GParamSpec **properties;
-  guint        n_properties;
-  gchar       *class;
-  gint         i;
-
-  properties = gegl_list_properties (gegl_node_get_operation (node),
-                                     &n_properties);
-
-  if (!ss->terse)
-    {
-      gegl_node_get (node, "operation", &class, NULL);
-      tuple_old (ss->buf, "operation", class);
-      g_free (class);
-    }
-
-  for (i = 0; i < n_properties; i++)
-    {
-      if (strcmp (properties[i]->name, "input") &&
-          strcmp (properties[i]->name, "output") &&
-          strcmp (properties[i]->name, "aux"))
-        {
-          if (g_type_is_a (G_PARAM_SPEC_TYPE (properties[i]),
-                           GEGL_TYPE_PARAM_PATH))
-            {
-              gchar *value;
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-
-              if (value)
-                {
-                  if (ss->path_root &&
-                      !strncmp (ss->path_root, value, strlen (ss->path_root)))
-                    {
-                      tuple_old (ss->buf, properties[i]->name, &value[strlen (ss->path_root)]);
-                    }
-                  else
-                    {
-                      tuple_old (ss->buf, properties[i]->name, value);
-                    }
-                }
-
-              g_free (value);
-            }
-          else if (properties[i]->value_type == G_TYPE_FLOAT)
-            {
-              gfloat value;
-              gchar  str[G_ASCII_DTOSTR_BUF_SIZE];
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-              g_ascii_dtostr (str, sizeof(str), value);
-              tuple_old (ss->buf, properties[i]->name, str);
-            }
-          else if (properties[i]->value_type == G_TYPE_DOUBLE)
-            {
-              gdouble value;
-              gchar   str[G_ASCII_DTOSTR_BUF_SIZE];
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-              g_ascii_dtostr (str, sizeof(str), value);
-              tuple_old (ss->buf, properties[i]->name, str);
-            }
-          else if (properties[i]->value_type == G_TYPE_INT)
-            {
-              gint  value;
-              gchar str[64];
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-              g_snprintf (str, sizeof (str), "%i", value);
-              tuple_old (ss->buf, properties[i]->name, str);
-            }
-          else if (properties[i]->value_type == G_TYPE_BOOLEAN)
-            {
-              gboolean value;
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-              if (value)
-                {
-                  tuple_old (ss->buf, properties[i]->name, "true");
-                }
-              else
-                {
-                  tuple_old (ss->buf, properties[i]->name, "false");
-                }
-            }
-          else if (properties[i]->value_type == G_TYPE_STRING)
-            {
-              gchar *value;
-              gegl_node_get (node, properties[i]->name, &value, NULL);
-              tuple_old (ss->buf, properties[i]->name, value);
-              g_free (value);
-            }
-          else if (properties[i]->value_type == GEGL_TYPE_COLOR)
-            {
-              GeglColor *color;
-              gchar     *value;
-              gegl_node_get (node, properties[i]->name, &color, NULL);
-              g_object_get (color, "string", &value, NULL);
-              g_object_unref (color);
-              tuple_old (ss->buf, properties[i]->name, value);
-              g_free (value);
-            }
-          else
-            {
-              g_warning ("%s: serialization of %s proeprties not implemented",
-                         properties[i]->name, g_type_name (properties[i]->value_type));
-            }
-        }
-    }
-  if (id != NULL)
-    tuple_old (ss->buf, "id", id);
-
-  g_free (properties);
-}
-
-static void
-add_stack_old (SerializeState *ss,
-               gint            indent,
-               GeglNode       *head)
-{
-  if (GEGL_IS_NODE (head))
-    {
-      GeglNode *iter = head;
-
-      while (iter)
-        {
-          GeglPad     *input, *aux;
-          const gchar *id = NULL;
-
-          input = gegl_node_get_pad (iter, "input");
-          aux   = gegl_node_get_pad (iter, "aux");
-
-          if (gegl_node_get_num_sinks (iter) > 1)
-            {
-              const gchar *new_id = g_hash_table_lookup (ss->clones, iter);
-              if (new_id)
-                {
-                  ind; g_string_append (ss->buf, "<clone ref='");
-                  g_string_append (ss->buf, new_id);
-                  g_string_append (ss->buf, "'/>\n");
-                  return; /* terminate the stack, the cloned part is already
-                             serialized */
-                }
-              else
-                {
-                  gchar temp_id[64];
-                  g_snprintf (temp_id, sizeof (temp_id),
-                              "clone%i", ss->clone_count++);
-                  id = g_strdup (temp_id);
-                  g_hash_table_insert (ss->clones, iter, (gchar *) id);
-                  /* the allocation is freed by the hash table */
-                }
-            }
-
-          if (aux &&
-              gegl_pad_get_connected_to (aux))
-            {
-              GeglPad  *source_pad;
-              GeglNode *source_node;
-              source_pad  = gegl_pad_get_connected_to (aux);
-              source_node = gegl_pad_get_node (source_pad);
-              {
-                GeglNode *graph = g_object_get_data (G_OBJECT (source_node),
-                                                     "graph");
-                if (graph)
-                  source_node = graph;
-              }
-              ind; if (ss->terse)
-                {
-                  g_string_append (ss->buf, "<");
-                  g_string_append (ss->buf, gegl_node_get_operation (iter));
-                }
-              else
-                {
-                  g_string_append (ss->buf, "<node");
-                }
-              encode_node_attributes_old (ss, iter, id);
-              g_string_append (ss->buf, ">\n");
-              add_stack_old (ss, indent + 4, source_node);
-
-              ind; if (ss->terse)
-                {
-                  g_string_append (ss->buf, "</");
-                  g_string_append (ss->buf, gegl_node_get_operation (iter));
-                  g_string_append (ss->buf, ">\n");
-                }
-              else
-                {
-                  g_string_append (ss->buf, "</node\n>");
-                }
-            }
-          else
-            {
-              gchar *class;
-              gegl_node_get (iter, "operation", &class, NULL);
-
-              if (class)
-                {
-                  if (strcmp (class, "nop") &&
-                      strcmp (class, "clone"))
-                    {
-                      ind; if (ss->terse)
-                        {
-                          g_string_append (ss->buf, "<");
-                          g_string_append (ss->buf, class);
-                        }
-                      else
-                        {
-                          g_string_append (ss->buf, "<node");
-                        }
-
-                      encode_node_attributes_old (ss, iter, id);
-                      g_string_append (ss->buf, "/>\n");
-                    }
-                  g_free (class);
-                }
-            }
-          id = NULL;
-          if (input)
-            {
-              GeglPad *source_pad;
-              source_pad = gegl_pad_get_connected_to (input);
-              if (source_pad)
-                {
-                  GeglNode *source_node = gegl_pad_get_node (source_pad);
-                  GeglNode *graph       = g_object_get_data (G_OBJECT (source_node),
-                                                             "graph");
-                  if (graph)
-                    source_node = graph;
-                  iter = source_node;
-                }
-              else
-                iter = NULL;
-            }
-          else
-            iter = NULL;
-        }
-    }
-}
-
-
-gchar *
-gegl_node_to_xml_old (GeglNode    *gegl,
-                      const gchar *path_root)
-{
-  SerializeState  ss;
-
-  ss.buf         = g_string_new ("");
-  ss.path_root   = path_root;
-  ss.clone_count = 0;
-  ss.clones      = g_hash_table_new (NULL, NULL);
-  ss.terse       = TRUE;
-
-  gegl = gegl_node_get_output_proxy (gegl, "output");
-
-  g_string_append (ss.buf, "<?xml version='1.0' encoding='UTF-8'?>\n");
-  g_string_append (ss.buf, "<gegl>\n");
-
-  add_stack_old (&ss, 2, gegl);
-
-  g_string_append (ss.buf, "</gegl>\n");
-
-  g_hash_table_foreach (ss.clones, free_clone_id, NULL);
-  g_hash_table_destroy (ss.clones);
-
-  return g_string_free (ss.buf, FALSE);
-}
-#endif
-
 static void
 xml_attr (GString     *buf,
           const gchar *key,
