@@ -26,14 +26,10 @@
 
 G_BEGIN_DECLS
 
-#ifndef GEGL_TYPE_NODE
-#define GEGL_TYPE_NODE            (gegl_node_get_type ())
-#define GEGL_NODE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEGL_TYPE_NODE, GeglNode))
 #define GEGL_NODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  GEGL_TYPE_NODE, GeglNodeClass))
-#define GEGL_IS_NODE(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEGL_TYPE_NODE))
 #define GEGL_IS_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GEGL_TYPE_NODE))
 #define GEGL_NODE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GEGL_TYPE_NODE, GeglNodeClass))
-#endif
+/* The rest is in gegl-types.h */
 
 
 typedef struct _GeglNodeClass   GeglNodeClass;
@@ -43,42 +39,46 @@ struct _GeglNode
 {
   GObject         parent_instance;
 
+  /* The current operation associated with this node */
   GeglOperation  *operation;
+
+  /* The region for which this node provides pixel data */
   GeglRectangle   have_rect;
+
+  /* If TRUE the above have_rect is correct and can be returned
+   * directly instead of computed
+   */
+  gboolean        valid_have_rect;
+
+  /* All the pads on this node, depends on operation */
   GSList         *pads;
+
+  /* The input pads */
   GSList         *input_pads;
+
+  /* The output pads */
   GSList         *output_pads;
-  GSList         *sources;
-  GSList         *sinks;
-
-  gboolean        is_root;
-  gboolean        enabled;
 
+  /* If a node is a graph it means it has children. Typically the
+   * children connect to the input/output proxies of their graph
+   * node. This results in that the graph node can more or less be
+   * transparently treated as a normal node in most contexts
+   */
   gboolean        is_graph;
 
-  GeglCache      *cache;  /* For a node, the cache should be created at
-                             first demand if applicable, and the cache object
-                             reused for all subsequent requests for the cache
-                             object.*/
+  /* For a node, the cache should be created at first demand if
+   * applicable, and the cache object reused for all subsequent
+   * requests for the cache object.
+   */
+  GeglCache      *cache;
 
-  gboolean        dont_cache; /* whether result is cached or not, inherited
-                                 by children */
-  GMutex          *mutex;
+  /* Whether result is cached or not, inherited by children */
+  gboolean        dont_cache;
 
   /*< private >*/
   GeglNodePrivate *priv;
 };
 
-#ifndef GEGL_BLIT_FLAGS
-#define GEGL_BLIT_FLAGS
-typedef enum
-{
-  GEGL_BLIT_DEFAULT  = 0,
-  GEGL_BLIT_CACHE    = 1 << 0,
-  GEGL_BLIT_DIRTY    = 1 << 1,
-} GeglBlitFlags;
-#endif
-
 struct _GeglNodeClass
 {
   GObjectClass parent_class;
@@ -94,6 +94,7 @@ void          gegl_node_blit                (GeglNode            *node,
                                              gint                 rowstride,
                                              GeglBlitFlags        flags);
 
+void          gegl_node_process             (GeglNode      *self);
 void          gegl_node_link                (GeglNode      *source,
                                              GeglNode      *sink);
 
@@ -124,8 +125,6 @@ void          gegl_node_get                 (GeglNode      *self,
 
 
 GeglNode    * gegl_node_get_parent          (GeglNode      *self);
-GeglNode    * gegl_node_adopt_child         (GeglNode      *self,
-                                             GeglNode      *child);
 
 /* functions below are internal to gegl */
 
@@ -152,9 +151,7 @@ GeglNode    * gegl_node_get_producer        (GeglNode      *self,
                                              gchar         *pad_name,
                                              gchar        **output_pad);
 GSList      * gegl_node_get_depends_on      (GeglNode      *self);
-GeglBuffer  * gegl_node_apply               (GeglNode      *self,
-                                             const gchar   *output_pad_name);
-void          gegl_node_process             (GeglNode      *self);
+void          gegl_node_dump_depends_on     (GeglNode      *self);
 void          gegl_node_set_valist          (GeglNode      *object,
                                              const gchar   *first_property_name,
                                              va_list        var_args);
@@ -214,15 +211,14 @@ gint          gegl_node_get_consumers       (GeglNode      *node,
 
 GeglCache   * gegl_node_get_cache           (GeglNode      *node);
 void          gegl_node_invalidated         (GeglNode      *node,
-                                             const GeglRectangle *rect);
+                                             const GeglRectangle *rect,
+                                             gboolean             clean_cache);
 GeglRectangle gegl_node_get_bounding_box    (GeglNode      *root);
 
 const gchar * gegl_node_get_name            (GeglNode      *self);
 void          gegl_node_set_name            (GeglNode      *self,
                                              const gchar   *name);
 
-void          gegl_node_lock                (GeglNode *node);
-void          gegl_node_unlock              (GeglNode *node);
 
 G_END_DECLS
 
