@@ -16,13 +16,13 @@
  * Copyright 2006 Øyvind Kolås
  */
 
-#define GEGL_INTERNAL
-
 #include "config.h"
 
 #include <glib-object.h>
 #include <string.h>
-#include "gegl-types.h"
+
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation-composer3.h"
 #include "gegl-utils.h"
 #include "graph/gegl-node.h"
@@ -37,7 +37,7 @@ enum
   PROP_OUTPUT,
   PROP_INPUT,
   PROP_AUX,
-  PROP_AUX2,
+  PROP_AUX2
 };
 
 static void     get_property (GObject              *gobject,
@@ -189,6 +189,10 @@ gegl_operation_composer3_process (GeglOperation        *operation,
       aux2 != NULL)
     {
       success = klass->process (operation, input, aux, aux2, output, result);
+
+      if (output == GEGL_BUFFER (operation->node->cache))
+        gegl_cache_computed (operation->node->cache, result);
+
       if (input)
         g_object_unref (input);
       if (aux)
