@@ -19,14 +19,13 @@
 
 #include "config.h"
 
-#define GEGL_INTERNAL
-
 #include <string.h>
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
-
+#include "gegl.h"
+#include "gegl/gegl-utils.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation-context.h"
 #include "gegl/graph/gegl-node.h"
 #include "gegl-config.h"
@@ -238,36 +237,47 @@ void gegl_operation_context_destroy (GeglOperationContext *self)
   g_slice_free (GeglOperationContext, self);
 }
 
-
 void
 gegl_operation_context_set_object (GeglOperationContext *context,
                                    const gchar          *padname,
                                    GObject              *data)
 {
-  GeglOperation *operation;
-  GParamSpec    *pspec;
-  GValue         value = {0,};
+  /* Make it simple, just add an extra ref and then take the object */
+  if (data)
+    g_object_ref (data);
+  gegl_operation_context_take_object (context, padname, data);
+}
+
+void
+gegl_operation_context_take_object (GeglOperationContext *context,
+                                    const gchar          *padname,
+                                    GObject              *data)
+{
+  GParamSpec *pspec;
 
   /* FIXME: check that there isn't already an existing 
    *        output object/value set?
    */
 
-  operation = context->operation;
   pspec = g_object_class_find_property (G_OBJECT_GET_CLASS (G_OBJECT (context->operation)), padname);
+
   if (pspec)
-  {
-    g_value_init (&value, G_PARAM_SPEC_VALUE_TYPE (pspec));
-    g_value_set_object (&value, data);
-    gegl_operation_context_set_property (context, padname, &value);
-  }
+    {
+      GValue value = {0, };
+      g_value_init (&value, G_PARAM_SPEC_VALUE_TYPE (pspec));
+
+      g_value_take_object (&value, data);
+      gegl_operation_context_set_property (context, padname, &value);
+
+      g_value_unset (&value);
+    }
   else
     {
-      g_warning ("eeek! %s\n", padname);
-      if (data)
-        g_object_unref (data); /* are we stealing the initial reference? */
+      g_warning ("%s: No paramspec found for pad '%s' on \"%s\"\n",
+                 G_STRFUNC,
+                 padname,
+                 gegl_operation_get_name (context->operation));
     }
-  g_value_unset (&value);
-  g_object_unref (data); /* are we stealing the initial reference? */
 }
 
 GObject *
@@ -369,14 +379,26 @@ gegl_operation_context_get_target (GeglOperationContext *context,
     {
       GeglBuffer    *cache;
       cache = GEGL_BUFFER (gegl_node_get_cache (node));
-      output = gegl_buffer_create_sub_buffer (cache, result);
+
+      /* Only use the cache if the result is within the cache
+       * extent. This is certainly not optimal. My gut feeling is that
+       * the current caching mechanism needs to be redesigned
+       */
+      if (gegl_rectangle_contains (gegl_buffer_get_extent (cache), result))
+        {
+          output = gegl_buffer_create_sub_buffer (cache, result);
+        }
+      else
+        {
+          output = gegl_buffer_new_ram (result, format);
+        }
     }
   else
     {
       output = gegl_buffer_new_ram (result, format);
     }
 
-  gegl_operation_context_set_object (context, padname, G_OBJECT (output));
+  gegl_operation_context_take_object (context, padname, G_OBJECT (output));
   return output;
 }
 
