@@ -16,13 +16,13 @@
  * Copyright 2006 Øyvind Kolås
  */
 
-#define GEGL_INTERNAL
-
 #include "config.h"
 
 #include <glib-object.h>
 #include <string.h>
-#include "gegl-types.h"
+
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation-filter.h"
 #include "gegl-utils.h"
 #include "graph/gegl-node.h"
@@ -35,7 +35,7 @@ enum
 {
   PROP_0,
   PROP_OUTPUT,
-  PROP_INPUT,
+  PROP_INPUT
 };
 
 static void     get_property          (GObject       *gobject,
@@ -206,6 +206,10 @@ gegl_operation_filter_process (GeglOperation   *operation,
   output = gegl_operation_context_get_target (context, "output");
     {
       success = klass->process (operation, input, output, result);
+
+      if (output == GEGL_BUFFER (operation->node->cache))
+        gegl_cache_computed (operation->node->cache, result);
+
       if (input != NULL)
         g_object_unref (input);
     }
