@@ -17,11 +17,12 @@
  */
 
 
-#define GEGL_INTERNAL
 #include "config.h"
 
 #include <glib-object.h>
-#include "gegl-types.h"
+
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation-point-composer.h"
 #include "gegl-utils.h"
 #include "graph/gegl-node.h"
@@ -172,6 +173,9 @@ gegl_operation_composer_process2 (GeglOperation       *operation,
       if (!done)
         {
           success = klass->process (operation, input, aux, output, result);
+
+          if (output == GEGL_BUFFER (operation->node->cache))
+            gegl_cache_computed (operation->node->cache, result);
         }
       if (input)
          g_object_unref (input);
