@@ -17,11 +17,12 @@
  */
 
 
-#define GEGL_INTERNAL
 #include "config.h"
 
 #include <glib-object.h>
-#include "gegl-types.h"
+
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation-point-filter.h"
 #include "graph/gegl-pad.h"
 #include "graph/gegl-node.h"
