@@ -17,14 +17,13 @@
  *           2005-2008 Øyvind Kolås
  */
 
-#define GEGL_INTERNAL
-
 #include "config.h"
 
 #include <glib-object.h>
 #include <string.h>
 
-#include "gegl-types.h"
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-operation.h"
 #include "gegl-utils.h"
 #include "graph/gegl-node.h"
@@ -55,6 +54,7 @@ gegl_operation_class_init (GeglOperationClass *klass)
                                              * operation lookup by
                                              * name
                                              */
+  klass->compat_name               = NULL;
   klass->description               = NULL;
   klass->categories                = NULL;
   klass->attach                    = attach;
@@ -116,13 +116,16 @@ gegl_operation_process (GeglOperation       *operation,
       (result->width == 0 || result->height == 0))
     {
       GeglBuffer *output = gegl_buffer_new (NULL, NULL);
-      gegl_operation_context_set_object (context, "output", G_OBJECT (output));
+      gegl_operation_context_take_object (context, "output", G_OBJECT (output));
       return TRUE;
     }
 
   return klass->process (operation, context, output_pad, result);
 }
 
+/* Calls an extending class' get_bound_box method if defined otherwise
+ * just returns a zero-initiliased bouding box
+ */
 GeglRectangle
 gegl_operation_get_bounding_box (GeglOperation *self)
 {
@@ -164,14 +167,12 @@ get_required_for_output (GeglOperation        *operation,
                          const gchar         *input_pad,
                          const GeglRectangle *roi)
 {
-  GeglRectangle result = *roi;
-
   if (operation->node->is_graph)
     {
       return gegl_operation_get_required_for_output (operation, input_pad, roi);
     }
 
-  return result;
+  return *roi;
 }
 
 GeglRectangle
@@ -230,6 +231,7 @@ gegl_operation_attach (GeglOperation *self,
   klass->attach (self);
 }
 
+/* Calls the prepare function on the operation that extends this base class */
 void
 gegl_operation_prepare (GeglOperation *self)
 {
@@ -257,7 +259,7 @@ gegl_operation_get_source_node (GeglOperation *operation,
   if (!pad)
     return NULL;
 
-  pad = gegl_pad_get_internal_connected_to (pad);
+  pad = gegl_pad_get_connected_to (pad);
 
   if (!pad)
     return NULL;
@@ -416,10 +418,22 @@ gegl_operation_get_format (GeglOperation *self,
   return pad->format;
 }
 
+const gchar *
+gegl_operation_get_name (GeglOperation *operation)
+{
+  GeglOperationClass *klass;
+
+  g_return_val_if_fail (GEGL_IS_OPERATION (operation), NULL);
+
+  klass = GEGL_OPERATION_GET_CLASS (operation);
+
+  return klass->name;
+}
 
 void
 gegl_operation_invalidate (GeglOperation       *operation,
-                           const GeglRectangle *roi)
+                           const GeglRectangle *roi,
+                           gboolean             clear_cache)
 {
   GeglNode *node = NULL;
 
@@ -429,5 +443,5 @@ gegl_operation_invalidate (GeglOperation       *operation,
   g_return_if_fail (GEGL_IS_OPERATION (operation));
   node = operation->node;
 
-  gegl_node_invalidated (node, roi);
+  gegl_node_invalidated (node, roi, TRUE);
 }
