@@ -20,15 +20,16 @@
 
 #include <glib-object.h>
 
+#include "gegl.h"
+#include "gegl-debug.h"
 #include "buffer/gegl-region.h"
-
 #include "graph/gegl-node.h"
 
 #include "operation/gegl-operation-sink.h"
 
 #include "gegl-config.h"
 #include "gegl-processor.h"
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 #include "gegl-utils.h"
 
 
@@ -53,10 +54,10 @@ static void      gegl_processor_get_property (GObject               *gobject,
                                               guint                  prop_id,
                                               GValue                *value,
                                               GParamSpec            *pspec);
-static GObject * gegl_processor_constructor  (GType                  type,
-                                              guint                  n_params,
-                                              GObjectConstructParam *params);
+static void      gegl_processor_set_node     (GeglProcessor         *processor,
+                                              GeglNode              *node);
 static gdouble   gegl_processor_progress     (GeglProcessor         *processor);
+static gint      gegl_processor_get_band_size(gint                   size) G_GNUC_CONST;
 
 
 struct _GeglProcessor
@@ -68,7 +69,6 @@ struct _GeglProcessor
   GeglOperationContext *context;
 
   GeglRegion      *valid_region;     /* used when doing unbuffered rendering */
-  GeglRegion      *queued_region;
   GSList          *dirty_rectangles;
   gint             chunk_size;
 
@@ -78,7 +78,7 @@ struct _GeglProcessor
 };
 
 
-G_DEFINE_TYPE (GeglProcessor, gegl_processor, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GeglProcessor, gegl_processor, G_TYPE_OBJECT)
 
 
 static void
@@ -87,7 +87,6 @@ gegl_processor_class_init (GeglProcessorClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
   gobject_class->finalize     = gegl_processor_finalize;
-  gobject_class->constructor  = gegl_processor_constructor;
   gobject_class->set_property = gegl_processor_set_property;
   gobject_class->get_property = gegl_processor_get_property;
 
@@ -127,49 +126,10 @@ gegl_processor_init (GeglProcessor *processor)
   processor->node             = NULL;
   processor->input            = NULL;
   processor->context          = NULL;
-  processor->queued_region    = NULL;
   processor->dirty_rectangles = NULL;
   processor->chunk_size       = 128 * 128;
 }
 
-static GObject *
-gegl_processor_constructor (GType                  type,
-                            guint                  n_params,
-                            GObjectConstructParam *params)
-{
-  GObject       *object;
-  GeglProcessor *processor;
-
-  object    = G_OBJECT_CLASS (gegl_processor_parent_class)->constructor (type, n_params, params);
-  processor = GEGL_PROCESSOR (object);
-
-  if (processor->node->operation &&
-      g_type_is_a (G_OBJECT_TYPE (processor->node->operation),
-                   GEGL_TYPE_OPERATION_SINK))
-    {
-      processor->input = gegl_node_get_producer (processor->node, "input", NULL);
-      if (!gegl_operation_sink_needs_full (processor->node->operation))
-        {
-          processor->valid_region = gegl_region_new ();
-        }
-      else
-        {
-          processor->valid_region = NULL;
-        }
-    }
-  else
-    {
-      processor->input = processor->node;
-      processor->valid_region = NULL;
-    }
-
-  g_object_ref (processor->input);
-
-  processor->queued_region = gegl_region_new ();
-
-  return object;
-}
-
 static void
 gegl_processor_finalize (GObject *self_object)
 {
@@ -185,11 +145,6 @@ gegl_processor_finalize (GObject *self_object)
       g_object_unref (processor->input);
     }
 
-  if (processor->queued_region)
-    {
-      gegl_region_destroy (processor->queued_region);
-    }
-
   if (processor->valid_region)
     {
       gegl_region_destroy (processor->valid_region);
@@ -209,11 +164,7 @@ gegl_processor_set_property (GObject      *gobject,
   switch (property_id)
     {
       case PROP_NODE:
-        if (self->node)
-          {
-            g_object_unref (self->node);
-          }
-        self->node = GEGL_NODE (g_value_dup_object (value));
+        gegl_processor_set_node (self, g_value_get_object (value));
         break;
 
       case PROP_CHUNK_SIZE:
@@ -261,12 +212,44 @@ gegl_processor_get_property (GObject    *gobject,
     }
 }
 
+static void
+gegl_processor_set_node (GeglProcessor *processor,
+                         GeglNode      *node)
+{
+  g_return_if_fail (GEGL_IS_NODE (node));
+  g_return_if_fail (GEGL_IS_OPERATION (node->operation));
+
+  if (processor->node)
+    g_object_unref (processor->node);
+  processor->node = g_object_ref (node);
+
+  if (processor->valid_region)
+    gegl_region_destroy (processor->valid_region);
+  processor->valid_region = gegl_region_new ();
+
+  /* Sinks doesn't produce any data, so we need to use the source
+   * node as input in that case
+   */
+  if (GEGL_IS_OPERATION_SINK (node->operation))
+    {
+      processor->input = g_object_ref (gegl_node_get_producer (processor->node, "input", NULL));
+    }
+  else
+    {
+      processor->input = g_object_ref (processor->node);
+    }
+}
+
+/* Sets the processor->rectangle to the given rectangle (or the node
+ * bounding box if rectangle is NULL) and removes any
+ * dirty_rectangles, then updates node context_id with result rect and
+ * need rect
+ */
 void
 gegl_processor_set_rectangle (GeglProcessor       *processor,
                               const GeglRectangle *rectangle)
 {
   GSList        *iter;
-  GeglRectangle  bounds;
   GeglRectangle  input_bounding_box;
 
   if (! rectangle)
@@ -275,11 +258,25 @@ gegl_processor_set_rectangle (GeglProcessor       *processor,
       rectangle          = &input_bounding_box;
     }
 
+  GEGL_NOTE (GEGL_DEBUG_PROCESS, "gegl_processor_set_rectangle() node = %s rectangle = %d, %d %d×%d\n",
+             gegl_node_get_debug_name (processor->node),
+             rectangle->x, rectangle->y, rectangle->width, rectangle->height);
+
+  /* if the processor's rectangle isn't already set to the node's bounding box,
+   * then set it and remove processor->dirty_rectangles (set to NULL)  */
   if (! gegl_rectangle_equal (&processor->rectangle, rectangle))
     {
-      bounds               = gegl_node_get_bounding_box (processor->input);
+
+#if 0
+    /* XXX: this is a large penalty hit, so we assume the rectangle
+     * we're getting is part of the bounding box we're hitting */
+      GeglRectangle  bounds;
+      bounds               = processor->bounds;/*gegl_node_get_bounding_box (processor->input);*/
+#endif
       processor->rectangle = *rectangle;
+#if 0
       gegl_rectangle_intersect (&processor->rectangle, &processor->rectangle, &bounds);
+#endif
 
       /* remove already queued dirty rectangles */
       for (iter = processor->dirty_rectangles; iter; iter = g_slist_next (iter))
@@ -287,8 +284,40 @@ gegl_processor_set_rectangle (GeglProcessor       *processor,
           g_slice_free (GeglRectangle, iter->data);
         }
       g_slist_free (processor->dirty_rectangles);
-
       processor->dirty_rectangles = NULL;
+
+      /* We assume that the GeglProcessor client keeps track of dirty
+       * regions for us, so just clear the valid_region when the rect
+       * changes
+       */
+      if (processor->valid_region)
+        gegl_region_destroy (processor->valid_region);
+      processor->valid_region = gegl_region_new ();
+    }
+
+  /* if the node's operation is a sink and it needs the full content then
+   * a context will be set up together with a cache and
+   * needed and result rectangles */
+  if (GEGL_IS_OPERATION_SINK (processor->node->operation) &&
+      gegl_operation_sink_needs_full (processor->node->operation))
+    {
+      GeglCache *cache;
+      GValue     value = { 0, };
+
+      cache = gegl_node_get_cache (processor->input);
+
+      if (!gegl_node_get_context (processor->node, cache))
+        processor->context = gegl_node_add_context (processor->node, cache);
+
+      g_value_init (&value, GEGL_TYPE_BUFFER);
+      g_value_set_object (&value, cache);
+      gegl_operation_context_set_property (processor->context, "input", &value);
+      g_value_unset (&value);
+
+      gegl_operation_context_set_result_rect (processor->context,
+                                              &processor->rectangle);
+      gegl_operation_context_set_need_rect   (processor->context,
+                                              &processor->rectangle);
     }
 }
 
@@ -296,42 +325,45 @@ GeglProcessor *
 gegl_node_new_processor (GeglNode            *node,
                          const GeglRectangle *rectangle)
 {
-  GeglProcessor *processor;
-
   g_return_val_if_fail (GEGL_IS_NODE (node), NULL);
 
-  processor = g_object_new (GEGL_TYPE_PROCESSOR,
-                            "node",      node,
-                            "rectangle", rectangle,
-                            NULL);
-
-  if (node->operation                          &&
-      GEGL_IS_OPERATION_SINK (node->operation) &&
-      gegl_operation_sink_needs_full (node->operation))
-    {
-      GeglCache *cache;
-
-      cache = gegl_node_get_cache (processor->input);
-
-      processor->context = gegl_node_add_context (node, cache);
-      {
-        GValue value = { 0, };
-        g_value_init (&value, GEGL_TYPE_BUFFER);
-        g_value_set_object (&value, cache);
-        gegl_operation_context_set_property (processor->context, "input", &value);
-        g_value_unset (&value);
-      }
-
-      gegl_operation_context_set_result_rect (processor->context,
-                                              &processor->rectangle);
-      gegl_operation_context_set_need_rect   (processor->context,
-                                              &processor->rectangle);
-    }
-
-  return processor;
+  return g_object_new (GEGL_TYPE_PROCESSOR,
+                       "node",      node,
+                       "rectangle", rectangle,
+                       NULL);
 }
 
-/* returns TRUE if there is more work */
+/* Will generate band_sizes that are adapted to the size of the tiles */
+static gint
+gegl_processor_get_band_size (gint size)
+{
+  gint band_size;
+
+  band_size = size / 2;
+
+  /* try to make the rects generated match better with potential 2^n sized
+   * tiles, XXX: should be improved to make the next slice fit as well. */
+  if (band_size <= 256)
+    {
+      band_size = MIN(band_size, 128); /* prefer a band_size of 128,
+                                          hoping to hit tiles */
+    }
+  else if (band_size <= 512)
+    {
+      band_size = MIN(band_size, 256); /* prefer a band_size of 128,
+                                          hoping to hit tiles */
+    }
+
+  if (band_size < 1)
+    band_size = 1;
+
+  return band_size;
+}
+
+/* If the processor's dirty rectangle is too big then it will be cut, added
+ * to the processor's list of dirty rectangles and TRUE will be returned.
+ * If the rectangle is small enough it will be processed, using a buffer or
+ * not as appropriate, and will return TRUE if there is more work */
 static gboolean
 render_rectangle (GeglProcessor *processor)
 {
@@ -340,6 +372,8 @@ render_rectangle (GeglProcessor *processor)
   GeglCache *cache    = NULL;
   gint       pxsize;
 
+  /* Retreive the cache if the processor's node is not buffered if it's
+   * operation is a sink and it doesn't use the full area  */
   buffered = !(GEGL_IS_OPERATION_SINK(processor->node->operation) &&
                !gegl_operation_sink_needs_full (processor->node->operation));
   if (buffered)
@@ -352,49 +386,39 @@ render_rectangle (GeglProcessor *processor)
     {
       GeglRectangle *dr = processor->dirty_rectangles->data;
 
+      /* If a dirty rectangle is bigger than the max area, then cut it
+       * to smaller pieces */
       if (dr->height * dr->width > max_area && 1)
         {
           gint band_size;
 
-          if (dr->height > dr->width)
-            {
-              GeglRectangle *fragment;
+          {
+            GeglRectangle *fragment;
 
-              band_size = dr->height / 2;
+            fragment = g_slice_dup (GeglRectangle, dr);
 
-              if (band_size < 1)
-                band_size = 1;
+            /* When splitting a rectangle, we'll do it on the biggest side */
+            if (dr->width > dr->height)
+              {
+                band_size = gegl_processor_get_band_size ( dr->width );
+              
+                fragment->width = band_size;
+                dr->width      -= band_size;
+                dr->x          += band_size;
+              }
+            else
+              {
+                band_size = gegl_processor_get_band_size (dr->height);
 
-              fragment = g_slice_dup (GeglRectangle, dr);
-
-              fragment->height = band_size;
-              dr->height      -= band_size;
-              dr->y           += band_size;
-
-              processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
-
-              return TRUE;
-            }
-          else
-            {
-              GeglRectangle *fragment;
-
-              band_size = dr->width / 2;
-
-              if (band_size < 1)
-                band_size = 1;
-
-              fragment = g_slice_dup (GeglRectangle, dr);
-
-              fragment->width = band_size;
-              dr->width      -= band_size;
-              dr->x          += band_size;
-
-              processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
-
-              return TRUE;
-            }
+                fragment->height = band_size;
+                dr->height      -= band_size;
+                dr->y           += band_size;
+              }
+            processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles, fragment);
+          }
+          return TRUE;
         }
+      /* remove the rectangle that will be processed from the list of dirty ones */
       processor->dirty_rectangles = g_slist_remove (processor->dirty_rectangles, dr);
 
       if (!dr->width || !dr->height)
@@ -407,27 +431,30 @@ render_rectangle (GeglProcessor *processor)
       if (buffered)
         {
           /* only do work if the rectangle is not completely inside the valid
-           * region of the cache
-           */
-          if (gegl_region_rect_in (cache->valid_region, dr) !=
+           * region of the cache */
+          if (gegl_region_rect_in (processor->valid_region, dr) !=
               GEGL_OVERLAP_RECTANGLE_IN)
             {
+              /* create a buffer and initialise it */
               guchar *buf;
 
-              gegl_region_union_with_rect (cache->valid_region, dr);
+              gegl_region_union_with_rect (processor->valid_region, dr);
               buf = g_malloc (dr->width * dr->height * pxsize);
               g_assert (buf);
 
+              /* do the image calculations using the buffer */
               gegl_node_blit (cache->node, 1.0, dr, cache->format, buf,
                               GEGL_AUTO_ROWSTRIDE, GEGL_BLIT_DEFAULT);
 
 
-              /* check that we haven't been recently */
+              /* copy the buffer data into the cache */
               gegl_buffer_set (GEGL_BUFFER (cache), dr, cache->format, buf,
                                GEGL_AUTO_ROWSTRIDE);
 
+              /* tells the cache that the rectangle (dr) has been computed */
               gegl_cache_computed (cache, dr);
 
+              /* release the buffer */
               g_free (buf);
             }
         }
@@ -450,6 +477,7 @@ rect_area (GeglRectangle *rectangle)
   return rectangle->width * rectangle->height;
 }
 
+/* returns the total area covered by a region */
 static gint
 region_area (GeglRegion *region)
 {
@@ -469,6 +497,7 @@ region_area (GeglRegion *region)
   return sum;
 }
 
+/* returns the area not covered by the rectangle */
 static gint
 area_left (GeglRegion    *area,
            GeglRectangle *rectangle)
@@ -483,34 +512,22 @@ area_left (GeglRegion    *area,
   return sum;
 }
 
+/* returns true if everything is rendered */
 static gboolean
 gegl_processor_is_rendered (GeglProcessor *processor)
 {
-  if (gegl_region_empty (processor->queued_region) &&
-      processor->dirty_rectangles == NULL)
-    return TRUE;
-  return FALSE;
+  return processor->dirty_rectangles == NULL;
 }
 
 static gdouble
 gegl_processor_progress (GeglProcessor *processor)
 {
-  GeglRegion *valid_region;
-  gint        valid;
-  gint        wanted;
-  gdouble     ret;
-
-  if (processor->valid_region)
-    {
-      valid_region = processor->valid_region;
-    }
-  else
-    {
-      valid_region = gegl_node_get_cache (processor->input)->valid_region;
-    }
+  gint    valid;
+  gint    wanted;
+  gdouble ret;
 
   wanted = rect_area (&(processor->rectangle));
-  valid  = wanted - area_left (valid_region, &(processor->rectangle));
+  valid  = wanted - area_left (processor->valid_region, &(processor->rectangle));
   if (wanted == 0)
     {
       if (gegl_processor_is_rendered (processor))
@@ -530,22 +547,13 @@ gegl_processor_progress (GeglProcessor *processor)
   return ret;
 }
 
+/* Processes the rectangle (might be only splitting it to smaller ones) and
+ * updates the progress indicator */
 static gboolean
 gegl_processor_render (GeglProcessor *processor,
                        GeglRectangle *rectangle,
                        gdouble       *progress)
 {
-  GeglRegion *valid_region;
-
-  if (processor->valid_region)
-    {
-      valid_region = processor->valid_region;
-    }
-  else
-    {
-      valid_region = gegl_node_get_cache (processor->input)->valid_region;
-    }
-
   {
     gboolean more_work = render_rectangle (processor);
 
@@ -555,16 +563,18 @@ gegl_processor_render (GeglProcessor *processor,
           {
             gint valid;
             gint wanted;
+
             if (rectangle)
               {
                 wanted = rect_area (rectangle);
-                valid  = wanted - area_left (valid_region, rectangle);
+                valid  = wanted - area_left (processor->valid_region, rectangle);
               }
             else
               {
-                valid  = region_area (valid_region);
-                wanted = region_area (processor->queued_region);
+                valid  = region_area (processor->valid_region);
+                wanted = 0;
               }
+
             if (wanted == 0)
               {
                 *progress = 1.0;
@@ -573,7 +583,6 @@ gegl_processor_render (GeglProcessor *processor,
               {
                 *progress = (double) valid / wanted;
               }
-            wanted = 1;
           }
 
         return more_work;
@@ -588,17 +597,13 @@ gegl_processor_render (GeglProcessor *processor,
       gint           n_rectangles;
       gint           i;
 
-      gegl_region_subtract (region, valid_region);
+      gegl_region_subtract (region, processor->valid_region);
       gegl_region_get_rectangles (region, &rectangles, &n_rectangles);
       gegl_region_destroy (region);
 
       for (i = 0; i < n_rectangles && i < 1; i++)
         {
           GeglRectangle  roi = rectangles[i];
-          GeglRegion    *tr = gegl_region_rectangle (&roi);
-          gegl_region_subtract (processor->queued_region, tr);
-          gegl_region_destroy (tr);
-
           processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles,
                                                          g_slice_dup (GeglRectangle, &roi));
         }
@@ -608,38 +613,13 @@ gegl_processor_render (GeglProcessor *processor,
       if (n_rectangles != 0)
         {
           if (progress)
-            *progress = 1.0 - ((double) area_left (valid_region, rectangle) /
+            *progress = 1.0 - ((double) area_left (processor->valid_region, rectangle) /
                                rect_area (rectangle));
           return TRUE;
         }
 
       return FALSE;
     }
-  else if (!gegl_region_empty (processor->queued_region) &&
-           !processor->dirty_rectangles)
-    { /* XXX: this branch of the else can probably be removed if gegl-processors
-         should only work with rectangular queued regions
-       */
-      GeglRectangle *rectangles;
-      gint           n_rectangles;
-      gint           i;
-
-      gegl_region_get_rectangles (processor->queued_region, &rectangles,
-                                  &n_rectangles);
-
-      for (i = 0; i < n_rectangles && i < 1; i++)
-        {
-          GeglRectangle  roi = rectangles[i];
-          GeglRegion    *tr = gegl_region_rectangle (&roi);
-          gegl_region_subtract (processor->queued_region, tr);
-          gegl_region_destroy (tr);
-
-          processor->dirty_rectangles = g_slist_prepend (processor->dirty_rectangles,
-                                                         g_slice_dup (GeglRectangle, &roi));
-        }
-
-      g_free (rectangles);
-    }
 
   if (progress)
     {
@@ -649,6 +629,8 @@ gegl_processor_render (GeglProcessor *processor,
   return !gegl_processor_is_rendered (processor);
 }
 
+/* Will call gegl_processor_render and when there is no more work to be done,
+ * it will write the result to the destination */
 gboolean
 gegl_processor_work (GeglProcessor *processor,
                      gdouble       *progress)
@@ -662,6 +644,11 @@ gegl_processor_work (GeglProcessor *processor,
       return TRUE;
     }
 
+  if (progress)
+    {
+      *progress = 1.0;
+    }
+
   if (processor->context)
     {
       /* the actual writing to the destination */
@@ -672,19 +659,10 @@ gegl_processor_work (GeglProcessor *processor,
                               );
       gegl_node_remove_context (processor->node, cache);
       processor->context = NULL;
-      if (progress)
-        {
-          *progress = 1.0;
-        }
 
       return TRUE;
     }
 
-  if (progress)
-    {
-      *progress = 1.0;
-    }
-
   return FALSE;
 }
 
