@@ -19,16 +19,15 @@
 #ifndef __GEGL_PROCESSOR_H__
 #define __GEGL_PROCESSOR_H__
 
-#include "gegl-types.h"
+#include "gegl-types-internal.h"
 
 G_BEGIN_DECLS
 
-#define GEGL_TYPE_PROCESSOR            (gegl_processor_get_type ())
-#define GEGL_PROCESSOR(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEGL_TYPE_PROCESSOR, GeglProcessor))
 #define GEGL_PROCESSOR_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass),  GEGL_TYPE_PROCESSOR, GeglProcessorClass))
-#define GEGL_IS_PROCESSOR(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEGL_TYPE_PROCESSOR))
 #define GEGL_IS_PROCESSOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass),  GEGL_TYPE_PROCESSOR))
 #define GEGL_PROCESSOR_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj),  GEGL_TYPE_PROCESSOR, GeglProcessorClass))
+/* The rest is in gegl-types.h */
+
 
 typedef struct _GeglProcessorClass GeglProcessorClass;
 
