@@ -22,8 +22,8 @@
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
-
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-color.h"
 
 
@@ -83,7 +83,8 @@ static const ColorNameEntity color_names[] =
   { "navy",    { 0.f,      0.f,      0.50196f, 1.f } },
   { "blue",    { 0.f,      0.f,      1.f,      1.f } },
   { "teal",    { 0.f,      0.50196f, 0.50196f, 1.f } },
-  { "aqua",    { 0.f,      1.f,      1.f,      1.f } }
+  { "aqua",    { 0.f,      1.f,      1.f,      1.f } },
+  { "none",    { 0.f,      0.f,      0.f,      0.f } }
 };
 
 /* Copied into GeglColor:s instances when parsing a color from a string fails. */
@@ -92,7 +93,7 @@ static const gfloat parsing_error_color[4] = { 0.f, 1.f, 1.f, 0.67f };
 /* Copied into all GeglColor:s at their instantiation. */
 static const gfloat init_color[4] = { 1.f, 1.f, 1.f, 1.f };
 
-G_DEFINE_TYPE (GeglColor, gegl_color, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GeglColor, gegl_color, G_TYPE_OBJECT)
 
 #define GEGL_COLOR_GET_PRIVATE(o)    (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEGL_TYPE_COLOR, GeglColorPrivate))
 
@@ -249,6 +250,7 @@ parse_hex (GeglColor   *color,
   return FALSE;
 }
 
+#if 0
 const gfloat *
 gegl_color_float4 (GeglColor *self)
 {
@@ -257,32 +259,29 @@ gegl_color_float4 (GeglColor *self)
   priv = GEGL_COLOR_GET_PRIVATE (self);
   return &priv->rgba_color[0];
 }
+#endif
 
 void
-gegl_color_get_rgba (GeglColor *self,
-                     gfloat    *r,
-                     gfloat    *g,
-                     gfloat    *b,
-                     gfloat    *a)
+gegl_color_get_rgba4f (GeglColor   *color,
+                       gfloat      *rgba)
 {
   GeglColorPrivate *priv;
+  gint i;
 
-  g_return_if_fail (GEGL_IS_COLOR (self));
+  g_return_if_fail (GEGL_IS_COLOR (color));
 
-  priv = GEGL_COLOR_GET_PRIVATE (self);
+  priv = GEGL_COLOR_GET_PRIVATE (color);
 
-  *r = priv->rgba_color[0];
-  *g = priv->rgba_color[1];
-  *b = priv->rgba_color[2];
-  *a = priv->rgba_color[3];
+  for (i=0; i< 4; i++)
+    rgba[i] = priv->rgba_color[i];
 }
 
 void
 gegl_color_set_rgba (GeglColor *self,
-                     gfloat     r,
-                     gfloat     g,
-                     gfloat     b,
-                     gfloat     a)
+                     gdouble    r,
+                     gdouble    g,
+                     gdouble    b,
+                     gdouble    a)
 {
   GeglColorPrivate *priv;
 
@@ -296,6 +295,25 @@ gegl_color_set_rgba (GeglColor *self,
   priv->rgba_color[3] = a;
 }
 
+void
+gegl_color_get_rgba (GeglColor *self,
+                     gdouble   *r,
+                     gdouble   *g,
+                     gdouble   *b,
+                     gdouble   *a)
+{
+  GeglColorPrivate *priv;
+
+  g_return_if_fail (GEGL_IS_COLOR (self));
+
+  priv = GEGL_COLOR_GET_PRIVATE (self);
+
+  *r = priv->rgba_color[0];
+  *g = priv->rgba_color[1];
+  *b = priv->rgba_color[2];
+  *a = priv->rgba_color[3];
+}
+
 static void
 gegl_color_set_from_string (GeglColor   *self,
                             const gchar *color_string)
@@ -477,6 +495,7 @@ gegl_param_color_finalize (GParamSpec *self)
   parent_class->finalize (self);
 }
 
+#if 0
 static void
 value_set_default (GParamSpec *param_spec,
                    GValue     *value)
@@ -485,6 +504,7 @@ value_set_default (GParamSpec *param_spec,
 
   g_value_set_object (value, gegl_color->default_color);
 }
+#endif
 
 GType
 gegl_param_color_get_type (void)
@@ -499,7 +519,7 @@ gegl_param_color_get_type (void)
         gegl_param_color_init,
         0,
         gegl_param_color_finalize,
-        value_set_default,
+        NULL, /*value_set_default,*/
         NULL,
         NULL
       };
@@ -523,10 +543,10 @@ gegl_param_spec_color (const gchar *name,
 
   param_color = g_param_spec_internal (GEGL_TYPE_PARAM_COLOR,
                                        name, nick, blurb, flags);
-
+/*
   param_color->default_color = default_color;
   if (default_color)
-    g_object_ref (default_color);
+    g_object_ref (default_color);*/
 
   return G_PARAM_SPEC (param_color);
 }
@@ -542,9 +562,9 @@ gegl_param_spec_color_from_string (const gchar *name,
 
   param_color = g_param_spec_internal (GEGL_TYPE_PARAM_COLOR,
                                        name, nick, blurb, flags);
-
+/*
   param_color->default_color = g_object_new (GEGL_TYPE_COLOR,
                                              "string", default_color_string,
-                                             NULL);
+                                             NULL);*/
   return G_PARAM_SPEC (param_color);
 }
