@@ -44,20 +44,71 @@ struct _GeglColorClass
 
 GType        gegl_color_get_type               (void) G_GNUC_CONST;
 
+
+/***
+ * GeglColor:
+ *
+ * GeglColor is an object containing a color at the moment only RGB colors
+ * are supported, in the future a GeglColor might also indicate other
+ * enumerated or natively in other color representations colors.
+ */
+
+/**
+ * gegl_color_new:
+ * @string: a string describing the color to be created.
+ *
+ * Creates a new #GeglColor.
+ *
+ * Returns the newly created #GeglColor.
+ */
 GeglColor *  gegl_color_new                    (const gchar *string);
 
-void         gegl_color_get_rgba               (GeglColor   *self,
-                                                gfloat      *r,
-                                                gfloat      *g,
-                                                gfloat      *b,
-                                                gfloat      *a);
+/**
+ * gegl_color_get_rgba:
+ * @color: a #GeglColor
+ * @red: red return location.
+ * @green: green return location.
+ * @blue: blue return location.
+ * @alpha: alpha return location.
+ *
+ * Retrieves the current set color as linear light non premultipled RGBA data,
+ * any of the return pointers can be omitted.
+ */
+void         gegl_color_get_rgba               (GeglColor   *color,
+                                                gdouble     *red,
+                                                gdouble     *green,
+                                                gdouble     *blue,
+                                                gdouble     *alpha);
 
-void         gegl_color_set_rgba               (GeglColor   *self,
-                                                gfloat       r,
-                                                gfloat       g,
-                                                gfloat       b,
-                                                gfloat       a);
+/**
+ * gegl_color_get_rgba4f:
+ * @color: a #GeglColor
+ * @buf: pointer to a buffer for a single "RGBA float" pixel.
+ *
+ * Retrieves the current set color as linear light non premultipled RGBA data,
+ * and stores it at the memory location in @buf
+ */
+void         gegl_color_get_rgba4f             (GeglColor   *color,
+                                                gfloat      *buf);
 
+/**
+ * gegl_color_set_rgba:
+ * @color: a #GeglColor
+ * @red: red value
+ * @green: green value
+ * @blue: blue value
+ * @alpha: alpha value
+ *
+ * Retrieves the current set color as linear light non premultipled RGBA data
+ */
+void         gegl_color_set_rgba               (GeglColor   *color,
+                                                gdouble      red,
+                                                gdouble      green,
+                                                gdouble      blue,
+                                                gdouble      alpha);
+
+/***
+ */
 
 #define GEGL_TYPE_PARAM_COLOR           (gegl_param_color_get_type ())
 #define GEGL_IS_PARAM_SPEC_COLOR(pspec) (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), GEGL_TYPE_PARAM_COLOR))
