@@ -24,8 +24,8 @@
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
-
+#include "gegl.h"
+#include "gegl-types-internal.h"
 #include "gegl-curve.h"
 
 
@@ -64,7 +64,7 @@ static void get_property (GObject      *gobject,
                           GValue       *value,
                           GParamSpec   *pspec);
 
-G_DEFINE_TYPE (GeglCurve, gegl_curve, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GeglCurve, gegl_curve, G_TYPE_OBJECT)
 
 #define GEGL_CURVE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o),\
                                    GEGL_TYPE_CURVE, GeglCurvePrivate))
@@ -185,7 +185,10 @@ gegl_curve_add_point (GeglCurve    *self,
                       gdouble       y)
 {
   GeglCurvePrivate *priv  = GEGL_CURVE_GET_PRIVATE (GEGL_CURVE (self));
-  GeglCurvePoint    point = { x, y };
+  GeglCurvePoint    point;
+
+  point.x = x;
+  point.y = y;
 
   g_array_append_val (priv->points, point);
 
@@ -217,7 +220,10 @@ gegl_curve_set_point (GeglCurve      *self,
                       gdouble         y)
 {
   GeglCurvePrivate *priv  = GEGL_CURVE_GET_PRIVATE (GEGL_CURVE (self));
-  GeglCurvePoint    point = { x, y };
+  GeglCurvePoint    point;
+
+  point.x = x;
+  point.y = y;
 
   g_assert (index < priv->points->len);
   g_array_index (priv->points, GeglCurvePoint, index) = point;
