@@ -23,11 +23,6 @@
 
 #include <glib-object.h>
 
-#include "gegl-types.h"
-
-#include "gegl-buffer-private.h"
-
-
 #define GEGL_PATH_INTERNAL
 typedef struct Point
 {
@@ -38,10 +33,12 @@ typedef struct Point
 typedef struct GeglPathItem
 {
   gchar  type; /* should perhaps be padded out? */
-  Point  point[]; /* variable length internally */
+  Point  point[1]; /* variable length internally */
 } GeglPathItem;
 
-
+#include "gegl.h"
+#include "gegl-types-internal.h"
+#include "gegl-buffer-private.h"
 #include "gegl-path.h"
 #include "gegl-color.h"
 #include "gegl-utils.h"
@@ -59,7 +56,7 @@ typedef struct GeglPathItem
 typedef struct InstructionInfo
 {
   gchar  type;
-  gint   pairs;
+  gint   n_items;
   gchar *name;
 
   /* a flatten function pointer is kept for all stored InstructionInfo's but are only
@@ -85,13 +82,13 @@ static GeglPathList *flatten_curve     (GeglMatrix3 matrix, GeglPathList *head,
 
 static InstructionInfo knot_types[64]= /* reserve space for a total of up to 64 types of instructions. */
 {
-  {'M',  1, "move to",              flatten_copy},
-  {'L',  1, "line to",              flatten_copy},
-  {'C',  3, "curve to",             flatten_curve},
+  {'M',  2, "move to",              flatten_copy},
+  {'L',  2, "line to",              flatten_copy},
+  {'C',  6, "curve to",             flatten_curve},
 
-  {'m',  1, "rel move to",          flatten_rel_copy},
-  {'l',  1, "rel line to",          flatten_rel_copy},
-  {'c',  3, "rel curve to",         flatten_rel_copy},
+  {'m',  2, "rel move to",          flatten_rel_copy},
+  {'l',  2, "rel line to",          flatten_rel_copy},
+  {'c',  6, "rel curve to",         flatten_rel_copy},
 
   {'s',  0, "sentinel",             flatten_nop},
   {'z',  0, "sentinel",             flatten_nop},
@@ -115,7 +112,7 @@ static void transform_data (
   InstructionInfo *dst_info = lookup_instruction_info(dst->type);
   gint i;
 
-  for (i=0;i<dst_info->pairs;i++)
+  for (i=0;i<(dst_info->n_items+1)/2;i++)
     {
       gdouble x = dst->point[i].x;
       gdouble y = dst->point[i].y;
@@ -125,26 +122,37 @@ static void transform_data (
     }
 }
 
+/* XXX: copy_data should exit for internal to external conversions */
+
 static void copy_data (const GeglPathItem *src,
                        GeglPathItem       *dst)
 {
-  InstructionInfo *src_info = lookup_instruction_info(src->type);
-  InstructionInfo *dst_info = lookup_instruction_info(dst->type);
+  InstructionInfo *src_info;
+  InstructionInfo *dst_info;
   gint i;
 
-  g_assert (src_info->pairs <= dst_info->pairs);
+  if (!src)
+    return;
+
+  src_info = lookup_instruction_info(src->type);
+  dst_info = lookup_instruction_info(dst->type);
+
+/*
+  g_assert (src_info->pairs <= dst_info->pairs);*/
 
   dst->type = src->type;  
-  for (i=0;i<src_info->pairs;i++)
+  for (i=0;i<(src_info->n_items+1)/2;i++)
     {
       dst->point[i].x = src->point[i].x;
       dst->point[i].y = src->point[i].y;
     }
 }
 
+
+
 void
 gegl_path_add_type (gchar        type, 
-                    gint         pairs,
+                    gint         n_items,
                     const gchar *name)
 {
   gint i;
@@ -155,7 +163,7 @@ gegl_path_add_type (gchar        type,
         return;
       }
   knot_types[i].type = type;
-  knot_types[i].pairs = pairs;
+  knot_types[i].n_items = n_items;
   knot_types[i].name = g_strdup (name);
   knot_types[i].flatten = flatten_copy;
   knot_types[i+1].type = '\0';
@@ -178,14 +186,14 @@ gegl_path_list_append_item  (GeglPathList  *head,
   if (iter)
     {
       iter->next = 
-        g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *info->pairs);
+        g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *(info->n_items+1)/2);
       iter->next->d.type = type;
       iter = iter->next;
     }
   else /* creating new path */
     {
       head = 
-        g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *info->pairs);
+        g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *(info->n_items+1)/2);
       head->d.type = type;
       iter=head;
     }
@@ -229,7 +237,7 @@ flatten_rel_copy (GeglMatrix3   matrix,
   head = gegl_path_list_append_item (head, self->d.type, &newp, NULL);
   copy_data (&self->d, &newp->d);
   info = lookup_instruction_info (self->d.type);
-  for (i=0;i<info->pairs;i++)
+  for (i=0;i<(info->n_items+1)/2;i++)
     {
       newp->d.point[i].x += prev->d.point[0].x;
       newp->d.point[i].y += prev->d.point[0].y;
@@ -371,7 +379,7 @@ GeglPathList * gegl_path_list_append (GeglPathList *head,
   head = gegl_path_list_append_item (head, type, &iter, NULL);
 
   iter->d.type       = type;
-  for (pair_no=0;pair_no<info->pairs;pair_no++)
+  for (pair_no=0;pair_no<(info->n_items+2)/2;pair_no++)
     {
       iter->d.point[pair_no].x = va_arg (var_args, gdouble);
       iter->d.point[pair_no].y = va_arg (var_args, gdouble);
@@ -395,7 +403,7 @@ path_calc (GeglPathList *path,
 
   while (iter)
     {
-      //fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);
+      /*fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);*/
       switch (iter->d.type)
         {
           case 'M':
@@ -485,7 +493,7 @@ static void path_calc_values (GeglPathList *path,
   iter = path;
   while (iter)
     {
-      //fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);
+      /*fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);*/
       switch (iter->d.type)
         {
           case 'M':
@@ -651,14 +659,10 @@ struct _GeglPathPrivate
   GeglPathList *tail; /*< for fast appending */
   GeglPathList *flat_path; /*< cache of flat path */
   gboolean      flat_path_clean;
-  GeglPath     *parent_path;
 
   gdouble       length;
   gboolean      length_clean;
 
-  GSList *parameter_names;
-  GSList *parameter_paths;
-
   GeglRectangle dirtied;
   GeglRectangle cached_extent;
   GeglMatrix3   matrix;
@@ -692,7 +696,7 @@ static GeglPathList *ensure_tail (GeglPathPrivate *priv)
 
 enum
 {
-  PROP_0,
+  PROP_0
 };
 
 
@@ -715,7 +719,7 @@ static void get_property (GObject      *gobject,
                           GValue       *value,
                           GParamSpec   *pspec);
 
-G_DEFINE_TYPE (GeglPath, gegl_path, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GeglPath, gegl_path, G_TYPE_OBJECT)
 
 #define GEGL_PATH_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o),\
                                    GEGL_TYPE_PATH, GeglPathPrivate))
@@ -836,7 +840,8 @@ gegl_path_class_init (GeglPathClass *klass)
                   G_TYPE_NONE, /*return type */
                   1, G_TYPE_POINTER);
 
-  gegl_path_add_type ('_', 1, "linear curve position associated value");
+  /* FIXME: should this just be 2 ? (and is this even currently in use?) */
+  gegl_path_add_type ('_', 2, "linear curve position associated value");
 }
 
 static void
@@ -1018,7 +1023,7 @@ gegl_path_calc (GeglPath   *self,
   if (!self)
     return;
   ensure_flattened (self);
-  return path_calc (priv->flat_path, pos, xd, yd);
+  path_calc (priv->flat_path, pos, xd, yd);
 }
 
 
@@ -1032,7 +1037,7 @@ gegl_path_calc_values (GeglPath *self,
   if (!self)
     return;
   ensure_flattened (self);
-  return path_calc_values (priv->flat_path, num_samples, xs, ys);
+  path_calc_values (priv->flat_path, num_samples, xs, ys);
 }
 
 
@@ -1152,7 +1157,7 @@ gegl_path_to_string (GeglPath  *vector)
       InstructionInfo *info = lookup_instruction_info(iter->d.type);
 
       g_string_append_c (str, iter->d.type);
-      for (i=0;i<info->pairs;i++)
+      for (i=0;i<(info->n_items+1)/2;i++)
         {
           gchar buf[16];
           gchar *eptr;
@@ -1162,63 +1167,25 @@ gegl_path_to_string (GeglPath  *vector)
               *eptr='\0';
           if (*eptr=='.')
             *eptr='\0';
-          g_string_append_printf (str, "%s,", buf);
-          sprintf (buf, "%f", iter->d.point[i].y);
+         
+          /* FIXME: make this work better also for other odd count
+           * of n_items
+           */ 
+          if (info->n_items>1)
+            {
+              g_string_append_printf (str, "%s,", buf);
+              sprintf (buf, "%f", iter->d.point[i].y);
 
-          for (eptr = &buf[strlen(buf)-1];eptr != buf && (*eptr=='0');eptr--)
-              *eptr='\0';
-          if (*eptr=='.')
-            *eptr='\0';
+              for (eptr = &buf[strlen(buf)-1];eptr != buf && (*eptr=='0');eptr--)
+                  *eptr='\0';
+              if (*eptr=='.')
+                *eptr='\0';
+            }
 
           g_string_append_printf (str, "%s ", buf);
         }
     }
 
-  /* iterate through the parameter datas */
-  {
-    GSList *names = gegl_path_parameter_get_names (vector, NULL);
-    GSList *iterb;
-
-    for (iterb = names; iterb; iterb=iterb->next)
-      {
-        GeglPath *subpath;
-        g_string_append_printf (str, "!%s ", (gchar*)iterb->data);
-        subpath = gegl_path_get_parameter_path (vector, iterb->data);
-
-        priv = GEGL_PATH_GET_PRIVATE (subpath);
-        for (iter = priv->path; iter; iter=iter->next)
-          {
-            gint i;
-            InstructionInfo *info = lookup_instruction_info(iter->d.type);
-
-            g_string_append_c (str, iter->d.type);
-            for (i=0;i<info->pairs;i++)
-              {
-                gchar buf[16];
-                gchar *eptr;
-                g_sprintf (buf, "%f", iter->d.point[i].x);
-
-                for (eptr = &buf[strlen(buf)-1];eptr != buf && (*eptr=='0');eptr--)
-                    *eptr='\0';
-                if (*eptr=='.')
-                  *eptr='\0';
-                g_string_append_printf (str, "%s,", buf);
-                sprintf (buf, "%f", iter->d.point[i].y);
-
-                for (eptr = &buf[strlen(buf)-1];eptr != buf && (*eptr=='0');eptr--)
-                    *eptr='\0';
-                if (*eptr=='.')
-                  *eptr='\0';
-
-                g_string_append_printf (str, "%s ", buf);
-              }
-          }
-
-
-      }
-  }
-
-
   ret = str->str;
   g_string_free (str, FALSE);
   return ret;
@@ -1285,65 +1252,34 @@ void gegl_path_parse_string (GeglPath *vector,
                 }
             }
 
-          if (param_name)
+          if (info)
             {
-              GeglPathPrivate *priv2 = GEGL_PATH_GET_PRIVATE (gegl_path_add_parameter_path (vector, param_name));
-              g_assert (priv2);
-              if (info)
+              switch (info->n_items)
                 {
-                  switch (info->pairs)
-                    {
-                      case 0:
-                        priv2->path = gegl_path_list_append (priv2->path, type, x0, y0);
-                        /* coordinates are ignored, all of these could have used add3)*/
-                        break;
-                      case 1:
-                        p = parse_float_pair (p, &x0, &y0);
-                        priv2->path = gegl_path_list_append (priv2->path, type, x0, y0);
-                        continue;
-                      case 2:
-                        p = parse_float_pair (p, &x0, &y0);
-                        p = parse_float_pair (p, &x1, &y1);
-                        priv2->path = gegl_path_list_append (priv2->path, type, x0, y0, x1, y1);
-                        continue;
-                      case 3:
-                        p = parse_float_pair (p, &x0, &y0);
-                        p = parse_float_pair (p, &x1, &y1);
-                        p = parse_float_pair (p, &x2, &y2);
-                        priv2->path = gegl_path_list_append (priv2->path, type, x0, y0, x1, y1, x2, y2);
-                        continue;
-                    }
-                  previnfo = info;
-                }
-            }
-          else
-            {
-              if (info)
-                {
-                  switch (info->pairs)
-                    {
-                      case 0:
-                        priv->path = gegl_path_list_append (priv->path, type, x0, y0);
-                        /* coordinates are ignored, all of these could have used add3)*/
-                        break;
-                      case 1:
-                        p = parse_float_pair (p, &x0, &y0);
-                        priv->path = gegl_path_list_append (priv->path, type, x0, y0);
-                        continue;
-                      case 2:
-                        p = parse_float_pair (p, &x0, &y0);
-                        p = parse_float_pair (p, &x1, &y1);
-                        priv->path = gegl_path_list_append (priv->path, type, x0, y0, x1, y1);
-                        continue;
-                      case 3:
-                        p = parse_float_pair (p, &x0, &y0);
-                        p = parse_float_pair (p, &x1, &y1);
-                        p = parse_float_pair (p, &x2, &y2);
-                        priv->path = gegl_path_list_append (priv->path, type, x0, y0, x1, y1, x2, y2);
-                        continue;
-                    }
-                  previnfo = info;
+                  case 0:
+                    priv->path = gegl_path_list_append (priv->path, type, x0, y0);
+                    /* coordinates are ignored, all of these could have used add3)*/
+                    break;
+                  case 2:
+                    p = parse_float_pair (p, &x0, &y0);
+                    priv->path = gegl_path_list_append (priv->path, type, x0, y0);
+                    continue;
+                  case 4:
+                    p = parse_float_pair (p, &x0, &y0);
+                    p = parse_float_pair (p, &x1, &y1);
+                    priv->path = gegl_path_list_append (priv->path, type, x0, y0, x1, y1);
+                    continue;
+                  case 6:
+                    p = parse_float_pair (p, &x0, &y0);
+                    p = parse_float_pair (p, &x1, &y1);
+                    p = parse_float_pair (p, &x2, &y2);
+                    priv->path = gegl_path_list_append (priv->path, type, x0, y0, x1, y1, x2, y2);
+                    continue;
+                  default:
+                    g_warning ("parsing of data %i items not implemented\n", info->n_items);
+                    continue;
                 }
+              previnfo = info;
             }
           if (*p)
             p++;
@@ -1381,9 +1317,10 @@ gegl_path_get_n_nodes  (GeglPath *vector)
 
 }
 
-const GeglPathItem *
-gegl_path_get_node (GeglPath *vector,
-                    gint      pos)
+gboolean
+gegl_path_get_node (GeglPath     *vector,
+                    gint          index,
+                    GeglPathItem *node)
 {
   GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (vector);
   GeglPathList *iter;
@@ -1392,15 +1329,19 @@ gegl_path_get_node (GeglPath *vector,
   for (iter = priv->path; iter; iter=iter->next)
     {
       last=&iter->d;
-      if (count == pos)
-        return last;
+      if (count == index)
+        {
+          copy_data (last, node);
+          return TRUE;
+        }
       count ++;
     }
-  if (pos==-1)
+  if (index==-1)
     {
-      return last;
+      copy_data (last, node);
+      return TRUE;
     }
-  return NULL;
+  return FALSE;
 }
 
 /* -1 means last */
@@ -1412,11 +1353,11 @@ gegl_path_get_node (GeglPath *vector,
 static void gegl_path_item_free (GeglPathList *p)
 {
   InstructionInfo *info = lookup_instruction_info(p->d.type);
-  g_slice_free1 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *info->pairs, p);
+  g_slice_free1 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 * (info->n_items+1)/2, p);
 }
 
 void  gegl_path_remove_node  (GeglPath *vector,
-                         gint      pos)
+                              gint      pos)
 {
   GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (vector);
   GeglPathList *iter;
@@ -1463,7 +1404,7 @@ void  gegl_path_insert_node     (GeglPath           *vector,
     {
       if (count == pos)
         {
-          GeglPathList *new = g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *info->pairs);
+          GeglPathList *new = g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *(info->n_items+1)/2);
           new->d.type=knot->type;
           copy_data (knot, &new->d);
           new->next = iter->next;
@@ -1480,7 +1421,7 @@ void  gegl_path_insert_node     (GeglPath           *vector,
     }
   if (pos==-1)
     {
-      GeglPathList *new = g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *info->pairs);
+      GeglPathList *new = g_slice_alloc0 (sizeof (gpointer) + sizeof (gchar) + sizeof (gfloat)*2 *(info->n_items+1)/2);
       new->d.type = knot->type;
       copy_data (knot, &new->d);
       new->next = NULL;
@@ -1606,15 +1547,11 @@ gegl_path_append (GeglPath *self,
   priv->path = gegl_path_list_append_item (priv->path, type, &iter, ensure_tail(priv));
 
   iter->d.type       = type;
-  for (pair_no=0;pair_no<info->pairs;pair_no++)
+  for (pair_no=0;pair_no < (info->n_items+1)/2;pair_no++)
     {
       iter->d.point[pair_no].x = va_arg (var_args, gdouble);
       iter->d.point[pair_no].y = va_arg (var_args, gdouble);
     }
-  if (priv->parent_path && iter->d.point[0].x < 0.0)
-    {
-      iter->d.point[0].x = gegl_path_get_length (priv->parent_path);
-    }
 
   va_end (var_args);
   priv->flat_path_clean = FALSE;
@@ -1762,199 +1699,6 @@ gegl_path_closest_point (GeglPath *path,
   return closest_val * 1.0;
 }
 
-GeglPath *gegl_path_get_parameter_path (GeglPath    *path,
-                                        const gchar *parameter_name)
-{
-  GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (path);
-  GSList *iter;
-  gint i;
-  for (iter=priv->parameter_names,i=0;iter;iter=iter->next,i++)
-    {
-      if (g_str_equal (parameter_name, (gchar*)iter->data))
-        return (GeglPath*) g_slist_nth_data (priv->parameter_paths, i);
-    }
-  return NULL;
-}
-
-static void subpath_changed (GeglPath *path, const GeglRectangle *roi,
-                             gpointer userdata)
-{
-  gegl_path_emit_changed (userdata, NULL); /* change the full path for
-                                            now, shouldbe possible to
-                                            limit for the bounding box
-                                            of the length that has been
-                                            changed. */
-}
-
-/* creates a new path if one doesn't already exist */
-GeglPath *gegl_path_add_parameter_path (GeglPath    *self,
-                                        const gchar *parameter_name)
-{
-  GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (self);
-  GeglPath *parameter_path;
-
-  parameter_path = gegl_path_get_parameter_path (self, parameter_name);
-  if (parameter_path)
-    return parameter_path;
-
-  priv->parameter_names = g_slist_append (priv->parameter_names, g_strdup (parameter_name));
-  parameter_path = gegl_path_new ();
-
-  g_signal_connect (parameter_path, "changed", G_CALLBACK (subpath_changed), self);
-  GEGL_PATH_GET_PRIVATE (parameter_path)->parent_path = self;
-#if 0
-  /* hard coded for line width,.. */
-
-  gegl_path_append (parameter_path, '_', 0.0, 4.0);
-  gegl_path_append (parameter_path, '_', 10.0, 8.0);
-  gegl_path_append (parameter_path, '_', 45.0, 2.0);
-  gegl_path_append (parameter_path, '_', 80.0, 20.0);
-  gegl_path_append (parameter_path, '_', 90.0, 2.0);
-  gegl_path_append (parameter_path, '_', 120.0, 8.0);
-  gegl_path_append (parameter_path, '_', 250.0, 4.0);
-  gegl_path_append (parameter_path, '_', 340.0, 3.0);
-#endif
-
-  priv->parameter_paths = g_slist_append (priv->parameter_paths, parameter_path);
-  return parameter_path;
-}
-
-GSList              *gegl_path_parameter_get_names   (GeglPath   *path,
-                                                      gint       *count)
-{
-  GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (path);
-  /* XXX: count NYI */
-  return priv->parameter_names;
-}
-
-static gdouble param_calc (GeglPath *path,
-                           gdouble   pos)
-{
-  GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (path);
-  GeglPathList *iter;
-
-  /* for linear,. I need one value above, and one below */
-  gboolean  got_below = FALSE;
-  gboolean  got_above = FALSE;
-  gdouble    belowpos = -999999999;
-  gdouble    abovepos = 999999999;
-  gdouble    below = 0;
-  gdouble    above = 0;
-
-  iter = priv->path;
-  while (iter && (!got_above || !got_below))
-    {
-      gdouble iterpos = iter->d.point[0].x;
-      gdouble iterval = iter->d.point[0].y;
-
-      if (iterpos <= pos && iterpos >= belowpos)
-        {
-          belowpos = iterpos;
-          below = iterval;
-          got_below = 1;
-        }
-      if (iterpos > pos && iterpos < abovepos)
-        {
-          abovepos = iterpos;
-          above = iterval;
-          got_above = 1;
-        }
-      iter = iter->next;
-    }
-  if (got_below)
-    {
-      if (got_above)
-        {
-          if (fabs (belowpos - abovepos) < 0.0001)
-            {
-              return above;
-            }
-          else
-            {
-              return
-                below + (pos -
-                      belowpos) * ((above - below) / (abovepos - belowpos));
-            }
-        }
-      else
-        {
-          return below;
-        }
-    }
-  else if (got_above)
-    {
-      return above;
-    }
-  else
-    {
-      return 0.0;
-    }
-}
-
-static void param_bounds (GeglPath *path,
-                          gdouble   max_pos,
-                          gdouble  *min_ret,
-                          gdouble  *max_ret)
-{
-  GeglPathPrivate *priv = GEGL_PATH_GET_PRIVATE (path);
-  GeglPathList *iter;
-
-  gdouble    min =  99999999;
-  gdouble    max = -99999999;
-  gdouble iterpos = max_pos-1;
-
-  iter = priv->path;
-  while (iter && iterpos < max_pos)
-    {
-      gdouble iterval = iter->d.point[0].y;
-      iterpos = iter->d.point[0].x;
-
-      if (iterval > max)
-        max = iterval;
-      if (iterval < min)
-        min = iterval;
-      iter = iter->next;
-    }
-  if (min_ret)
-    *min_ret = min;
-  if (max_ret)
-    *max_ret = max;
-}
-
-gdouble              gegl_path_parameter_calc        (GeglPath     *path,
-                                                      const gchar  *parameter_name,
-                                                      gdouble       pos)
-{
-  GeglPath *parameter_path = gegl_path_get_parameter_path (path, parameter_name);
-  return param_calc (parameter_path, pos);
-}
-
-void                 gegl_path_parameter_get_bounds  (GeglPath     *self,
-                                                      const gchar  *parameter_name,
-                                                      gdouble      *min_value,
-                                                      gdouble      *max_value)
-{
-  GeglPath *parameter_path = gegl_path_get_parameter_path (self, parameter_name);
-  param_bounds (parameter_path, gegl_path_get_length (self), min_value, max_value);
-}
-
-/* FIXME: this is terribly inefficient */
-void                 gegl_path_parameter_calc_values (GeglPath    *self,
-                                                      const gchar *parameter_name,
-                                                      guint        num_samples,
-                                                      gdouble     *samples)
-{
-  GeglPath *parameter_path = gegl_path_get_parameter_path (self, parameter_name);
-  gdouble length = gegl_path_get_length (self);
-  gint i;
-  for (i=0; i<num_samples; i++)
-    {
-      samples[i] = param_calc (parameter_path, (i*1.0)/num_samples * length);
-    }
-}
-
-
-
 /**************************************/
 
 #if 0
@@ -2019,6 +1763,15 @@ static void gegl_buffer_accumulate (GeglBuffer    *buffer,
   gegl_buffer_set (buffer, roi, format, buf, 0);
 }
 
+
+/* XXX: should be removed?  */
+void gegl_path_fill (GeglBuffer *buffer,
+                     GeglPath   *vector,
+                     GeglColor  *color,
+                     gboolean    winding);
+
+
+
 void gegl_path_fill (GeglBuffer *buffer,
                      GeglPath   *vector,
                      GeglColor  *color,
@@ -2045,10 +1798,9 @@ void gegl_path_fill (GeglBuffer *buffer,
   extent.height = ceil (ymax) - extent.y;
 
   {
-    GSList *scanlines[extent.height * versubi];
-
-    gdouble xs[samples];
-    gdouble ys[samples];
+    GSList **scanlines;
+    gdouble *xs;
+    gdouble *ys;
 
     gint i;
     gdouble prev_x;
@@ -2058,9 +1810,12 @@ void gegl_path_fill (GeglBuffer *buffer,
     gint    lastline=-1;
     gint    lastdir=-2;
 
+    xs = g_newa (gdouble, samples);
+    ys = g_newa (gdouble, samples);
     path_calc_values (priv->flat_path, samples, xs, ys);
 
     /* clear scanline intersection lists */
+    scanlines = g_newa (GSList*, extent.height * versubi);
     for (i=0; i < extent.height * versub; i++)
       scanlines[i]=NULL;
 
@@ -2125,10 +1880,11 @@ fill_close:  /* label used for goto to close last segment */
 
     /* Fill the spans */
 {
-    const gfloat *colc = gegl_color_float4 (color);
-    gfloat col[4] = {colc[0],colc[1],colc[2],colc[3]};
+    gfloat col[4];
     gfloat factor = 1.0/(horsub * versub);
 
+    gegl_color_get_rgba4f (color, col);
+
     col[0] *= factor;
     col[1] *= factor;
     col[2] *= factor;
@@ -2153,7 +1909,12 @@ fill_close:  /* label used for goto to close last segment */
 
             for (j=0;j<horsub;j++)
             {
-              GeglRectangle roi={(startx+j)/horsub, extent.y + i/versub, (endx - startx-j + horsub) / horsub, 1};
+              GeglRectangle roi;
+
+              roi.x = (startx+j)/horsub;
+              roi.y = extent.y + i/versub;
+              roi.width = (endx - startx-j + horsub) / horsub;
+              roi.height = 1;
               gegl_buffer_accumulate (buffer, &roi, col);
             }
 
@@ -2195,17 +1956,20 @@ static void gegl_path_stamp (GeglBuffer *buffer,
                              GeglColor  *color,
                              gdouble     opacity)
 {
-  const gfloat *col = gegl_color_float4 (color);
+  gfloat col[4];
   static StampStatic s = {FALSE,}; /* XXX: 
                                       we will ultimately leak the last valid
                                       cached brush. */
 
-  GeglRectangle roi = {floor(x-radius),
-                       floor(y-radius),
-                       ceil (x+radius) - floor (x-radius),
-                       ceil (y+radius) - floor (y-radius)};
-
   GeglRectangle temp;
+  GeglRectangle roi;
+
+  roi.x = floor(x-radius);
+  roi.y = floor(y-radius);
+  roi.width = ceil (x+radius) - floor (x-radius);
+  roi.height = ceil (y+radius) - floor (y-radius);
+
+  gegl_color_get_rgba4f (color, col);
 
   /* bail out if we wouldn't leave a mark on the buffer */
   if (!gegl_rectangle_intersect (&temp, &roi, clip_rect))
@@ -2271,6 +2035,15 @@ static void gegl_path_stamp (GeglBuffer *buffer,
 }
 
 
+void gegl_path_stroke (GeglBuffer *buffer,
+                       const GeglRectangle *clip_rect,
+                       GeglPath *vector,
+                       GeglColor  *color,
+                       gdouble     linewidth,
+                       gdouble     hardness,
+                       gdouble     opacity);
+
+
 void gegl_path_stroke (GeglBuffer *buffer,
                        const GeglRectangle *clip_rect,
                        GeglPath *vector,
@@ -2317,7 +2090,7 @@ void gegl_path_stroke (GeglBuffer *buffer,
 
   while (iter)
     {
-      //fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);
+      /*fprintf (stderr, "%c, %i %i\n", iter->d.type, iter->d.point[0].x, iter->d.point[0].y);*/
       switch (iter->d.type)
         {
           case 'M':
@@ -2360,25 +2133,13 @@ void gegl_path_stroke (GeglBuffer *buffer,
                      local_pos += spacing)
                   {
                     Point spot;
-                    gfloat gopacity;
                     gfloat ratio = local_pos / distance;
                     gfloat radius = linewidth/2;
-                       /* XXX: gegl_path_parameter_calc (vector, "linewidth",
-                                       traveled_length) / 2;*/
-                                 /* horizon used to refetch the radius
-                                  * for each step from the tool, to be
-                                  * able to have variable line width
-                                  */
-                    if (gegl_path_get_parameter_path (vector, "linewidth"))
-                      radius *= gegl_path_parameter_calc (vector, "linewidth", traveled_length);
-                    gopacity = opacity;
-                    if (gegl_path_get_parameter_path (vector, "opacity"))
-                      gopacity *= gegl_path_parameter_calc (vector, "opacity", traveled_length);
 
                     lerp (&spot, &a, &b, ratio);
 
                     gegl_path_stamp (buffer, clip_rect,
-                      spot.x, spot.y, radius, hardness, color, gopacity);
+                      spot.x, spot.y, radius, hardness, color, opacity);
 
                     traveled_length += spacing;
                   }
@@ -2405,3 +2166,11 @@ void gegl_path_stroke (GeglBuffer *buffer,
   if (gegl_buffer_is_shared (buffer))
   gegl_buffer_unlock (buffer);
 }
+
+gint gegl_path_type_get_n_items (gchar type)
+{
+  InstructionInfo *info = lookup_instruction_info (type);
+  if (!info)
+    return -1;
+  return info->n_items;
+}
