@@ -37,7 +37,6 @@
 
 #include "affine.h"
 #include "module.h"
-#include "matrix.h"
 
 enum
 {
@@ -48,38 +47,43 @@ enum
   PROP_LANCZOS_WIDTH
 };
 
-/* *** static prototypes *** */
 
-static void          get_property            (GObject             *object,
-                                              guint                prop_id,
-                                              GValue              *value,
-                                              GParamSpec          *pspec);
-static void          set_property            (GObject             *object,
-                                              guint                prop_id,
-                                              const GValue        *value,
-                                              GParamSpec          *pspec);
-static void          bounding_box            (gdouble             *points,
-                                              gint                 num_points,
-                                              GeglRectangle       *output);
-static gboolean      is_intermediate_node    (OpAffine            *affine);
-static gboolean      is_composite_node       (OpAffine            *affine);
-static void          get_source_matrix       (OpAffine            *affine,
-                                              Matrix3              output);
-static GeglRectangle get_bounding_box       (GeglOperation       *op);
-static GeglRectangle get_invalidated_by_change (GeglOperation       *operation,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *input_region);
-static GeglRectangle get_required_for_output(GeglOperation       *self,
-                                              const gchar         *input_pad,
-                                              const GeglRectangle *region);
+static void          gegl_affine_get_property              (GObject              *object,
+                                                            guint                 prop_id,
+                                                            GValue               *value,
+                                                            GParamSpec           *pspec);
+static void          gegl_affine_set_property              (GObject              *object,
+                                                            guint                 prop_id,
+                                                            const GValue         *value,
+                                                            GParamSpec           *pspec);
+static void          gegl_affine_bounding_box              (gdouble              *points,
+                                                            gint                  num_points,
+                                                            GeglRectangle        *output);
+static gboolean      gegl_affine_is_intermediate_node      (OpAffine             *affine);
+static gboolean      gegl_affine_is_composite_node         (OpAffine             *affine);
+static void          gegl_affine_get_source_matrix         (OpAffine             *affine,
+                                                            GeglMatrix3           output);
+static GeglRectangle gegl_affine_get_bounding_box          (GeglOperation        *op);
+static GeglRectangle gegl_affine_get_invalidated_by_change (GeglOperation        *operation,
+                                                            const gchar          *input_pad,
+                                                            const GeglRectangle  *input_region);
+static GeglRectangle gegl_affine_get_required_for_output   (GeglOperation        *self,
+                                                            const gchar          *input_pad,
+                                                            const GeglRectangle  *region);
+#if 0
+static gboolean      gegl_affine_process                   (GeglOperation       *op,
+                                                            GeglBuffer          *input,
+                                                            GeglBuffer          *output,
+                                                            const GeglRectangle *result);
+#endif
+static gboolean      gegl_affine_process                   (GeglOperation        *operation,
+                                                            GeglOperationContext *context,
+                                                            const gchar          *output_prop,
+                                                            const GeglRectangle  *result);
+static GeglNode    * gegl_affine_detect                    (GeglOperation        *operation,
+                                                            gint                  x,
+                                                            gint                  y);
 
-static gboolean      process                 (GeglOperation       *op,
-                                              GeglBuffer          *input,
-                                              GeglBuffer          *output,
-                                              const GeglRectangle *result);
-static GeglNode    * detect                  (GeglOperation       *operation,
-                                              gint                 x,
-                                              gint                 y);
 
 /* ************************* */
 
@@ -169,7 +173,7 @@ op_affine_sampler_init (OpAffine *self)
 }
 
 static void
-prepare (GeglOperation *operation)
+gegl_affine_prepare (GeglOperation *operation)
 {
   OpAffine  *affine = (OpAffine *) operation;
   Babl      *format = babl_format ("RaGaBaA float");
@@ -180,7 +184,7 @@ prepare (GeglOperation *operation)
 }
 
 static void
-finalize (GObject *object)
+gegl_affine_finalize (GObject *object)
 {
   OpAffine  *affine = (OpAffine *) object;
   if (affine->sampler != NULL)
@@ -194,22 +198,23 @@ static void
 op_affine_class_init (OpAffineClass *klass)
 {
   GObjectClass             *gobject_class = G_OBJECT_CLASS (klass);
-  GeglOperationFilterClass *filter_class  = GEGL_OPERATION_FILTER_CLASS (klass);
+  /*GeglOperationFilterClass *filter_class  = GEGL_OPERATION_FILTER_CLASS (klass);*/
   GeglOperationClass       *op_class      = GEGL_OPERATION_CLASS (klass);
 
-  gobject_class->set_property = set_property;
-  gobject_class->get_property = get_property;
-  gobject_class->finalize = finalize;
+  gobject_class->set_property         = gegl_affine_set_property;
+  gobject_class->get_property         = gegl_affine_get_property;
+  gobject_class->finalize             = gegl_affine_finalize;
 
-  op_class->get_invalidated_by_change = get_invalidated_by_change;
-  op_class->get_bounding_box = get_bounding_box;
-  op_class->get_required_for_output = get_required_for_output;
-  op_class->detect = detect;
-  op_class->categories = "transform";
-  op_class->prepare = prepare;
+  op_class->get_invalidated_by_change = gegl_affine_get_invalidated_by_change;
+  op_class->get_bounding_box          = gegl_affine_get_bounding_box;
+  op_class->get_required_for_output   = gegl_affine_get_required_for_output;
+  op_class->detect                    = gegl_affine_detect;
+  op_class->process                   = gegl_affine_process;
+  op_class->categories                = "transform";
+  op_class->prepare                   = gegl_affine_prepare;
+  op_class->no_cache                  = TRUE;
 
-
-  filter_class->process = process;
+  /*filter_class->process               = gegl_affine_process;*/
 
   klass->create_matrix = NULL;
 
@@ -256,14 +261,14 @@ op_affine_class_init (OpAffineClass *klass)
 static void
 op_affine_init (OpAffine *self)
 {
-  matrix3_identity (self->matrix);
+  gegl_matrix3_identity (self->matrix);
 }
 
 static void
-get_property (GObject    *object,
-              guint       prop_id,
-              GValue     *value,
-              GParamSpec *pspec)
+gegl_affine_get_property (GObject    *object,
+                          guint       prop_id,
+                          GValue     *value,
+                          GParamSpec *pspec)
 {
   OpAffine *self = OP_AFFINE (object);
 
@@ -291,10 +296,10 @@ get_property (GObject    *object,
 }
 
 static void
-set_property (GObject      *object,
-              guint         prop_id,
-              const GValue *value,
-              GParamSpec   *pspec)
+gegl_affine_set_property (GObject      *object,
+                          guint         prop_id,
+                          const GValue *value,
+                          GParamSpec   *pspec)
 {
   OpAffine *self = OP_AFFINE (object);
 
@@ -323,9 +328,9 @@ set_property (GObject      *object,
 }
 
 static void
-bounding_box (gdouble       *points,
-              gint           num_points,
-              GeglRectangle *output)
+gegl_affine_bounding_box (gdouble       *points,
+                          gint           num_points,
+                          GeglRectangle *output)
 {
   gint    i;
   gdouble min_x,
@@ -362,7 +367,7 @@ bounding_box (gdouble       *points,
 }
 
 static gboolean
-is_intermediate_node (OpAffine *affine)
+gegl_affine_is_intermediate_node (OpAffine *affine)
 {
   GSList        *connections;
   GeglOperation *op = GEGL_OPERATION (affine);
@@ -388,7 +393,7 @@ is_intermediate_node (OpAffine *affine)
 }
 
 static gboolean
-is_composite_node (OpAffine *affine)
+gegl_affine_is_composite_node (OpAffine *affine)
 {
   GSList        *connections;
   GeglOperation *op = GEGL_OPERATION (affine);
@@ -406,8 +411,8 @@ is_composite_node (OpAffine *affine)
 }
 
 static void
-get_source_matrix (OpAffine *affine,
-                   Matrix3   output)
+gegl_affine_get_source_matrix (OpAffine    *affine,
+                               GeglMatrix3  output)
 {
   GSList        *connections;
   GeglOperation *op = GEGL_OPERATION (affine);
@@ -420,11 +425,11 @@ get_source_matrix (OpAffine *affine,
   source = gegl_connection_get_source_node (connections->data)->operation;
   g_assert (IS_OP_AFFINE (source));
 
-  matrix3_copy (output, OP_AFFINE (source)->matrix);
+  gegl_matrix3_copy (output, OP_AFFINE (source)->matrix);
 }
 
 static GeglRectangle
-get_bounding_box (GeglOperation *op)
+gegl_affine_get_bounding_box (GeglOperation *op)
 {
   OpAffine      *affine  = (OpAffine *) op;
   OpAffineClass *klass   = OP_AFFINE_GET_CLASS (affine);
@@ -436,6 +441,7 @@ get_bounding_box (GeglOperation *op)
   GeglRectangle  context_rect;
   GeglSampler   *sampler;
 
+  op_affine_sampler_init (affine);
   sampler = affine->sampler;
   context_rect = sampler->context_rect;
 
@@ -445,21 +451,21 @@ get_bounding_box (GeglOperation *op)
 
   /* invoke child's matrix creation function */
   g_assert (klass->create_matrix);
-  matrix3_identity (affine->matrix);
+  gegl_matrix3_identity (affine->matrix);
   klass->create_matrix (op, affine->matrix);
 
   if (affine->origin_x || affine->origin_y)
-    matrix3_originate (affine->matrix, affine->origin_x, affine->origin_y);
+    gegl_matrix3_originate (affine->matrix, affine->origin_x, affine->origin_y);
 
-  if (is_composite_node (affine))
+  if (gegl_affine_is_composite_node (affine))
     {
-      Matrix3 source;
+      GeglMatrix3 source;
 
-      get_source_matrix (affine, source);
-      matrix3_multiply (source, affine->matrix, affine->matrix);
+      gegl_affine_get_source_matrix (affine, source);
+      gegl_matrix3_multiply (source, affine->matrix, affine->matrix);
     }
-  if (is_intermediate_node (affine) ||
-      matrix3_is_identity (affine->matrix))
+  if (gegl_affine_is_intermediate_node (affine) ||
+      gegl_matrix3_is_identity (affine->matrix))
     {
       return in_rect;
     }
@@ -482,27 +488,27 @@ get_bounding_box (GeglOperation *op)
   have_points [7] = in_rect.y + in_rect.height ;
 
   for (i = 0; i < 8; i += 2)
-    matrix3_transform_point (affine->matrix,
+    gegl_matrix3_transform_point (affine->matrix,
                              have_points + i, have_points + i + 1);
 
-  bounding_box (have_points, 4, &have_rect);
+  gegl_affine_bounding_box (have_points, 4, &have_rect);
   return have_rect;
 }
 
 static GeglNode *
-detect (GeglOperation *operation,
-        gint           x,
-        gint           y)
+gegl_affine_detect (GeglOperation *operation,
+                    gint           x,
+                    gint           y)
 {
   GeglNode *source_node = gegl_operation_get_source_node (operation, "input");
 
   OpAffine *affine = (OpAffine *) operation;
-  Matrix3   inverse;
+  GeglMatrix3   inverse;
   gdouble   need_points [2];
   gint      i;
 
-  if (is_intermediate_node (affine) ||
-      matrix3_is_identity (inverse))
+  if (gegl_affine_is_intermediate_node (affine) ||
+      gegl_matrix3_is_identity (inverse))
     {
       return gegl_operation_detect (source_node->operation, x, y);
     }
@@ -510,11 +516,11 @@ detect (GeglOperation *operation,
   need_points [0] = x;
   need_points [1] = y;
 
-  matrix3_copy (inverse, affine->matrix);
-  matrix3_invert (inverse);
+  gegl_matrix3_copy (inverse, affine->matrix);
+  gegl_matrix3_invert (inverse);
 
   for (i = 0; i < 2; i += 2)
-    matrix3_transform_point (inverse,
+    gegl_matrix3_transform_point (inverse,
                              need_points + i, need_points + i + 1);
 
   return gegl_operation_detect (source_node->operation,
@@ -522,12 +528,12 @@ detect (GeglOperation *operation,
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *op,
-                         const gchar         *input_pad,
-                         const GeglRectangle *region)
+gegl_affine_get_required_for_output (GeglOperation       *op,
+                                     const gchar         *input_pad,
+                                     const GeglRectangle *region)
 {
   OpAffine      *affine = (OpAffine *) op;
-  Matrix3        inverse;
+  GeglMatrix3    inverse;
   GeglRectangle  requested_rect,
                  need_rect;
   GeglRectangle  context_rect;
@@ -539,11 +545,11 @@ get_required_for_output (GeglOperation       *op,
   sampler = affine->sampler;
   context_rect = sampler->context_rect;
 
-  matrix3_copy (inverse, affine->matrix);
-  matrix3_invert (inverse);
+  gegl_matrix3_copy (inverse, affine->matrix);
+  gegl_matrix3_invert (inverse);
 
-  if (is_intermediate_node (affine) ||
-      matrix3_is_identity (inverse))
+  if (gegl_affine_is_intermediate_node (affine) ||
+      gegl_matrix3_is_identity (inverse))
     {
       return requested_rect;
     }
@@ -560,13 +566,13 @@ get_required_for_output (GeglOperation       *op,
   need_points [6] = requested_rect.x;
   need_points [7] = requested_rect.y + requested_rect.height ;
 
-  matrix3_copy (inverse, affine->matrix);
-  matrix3_invert (inverse);
+  gegl_matrix3_copy (inverse, affine->matrix);
+  gegl_matrix3_invert (inverse);
 
   for (i = 0; i < 8; i += 2)
-    matrix3_transform_point (inverse,
+    gegl_matrix3_transform_point (inverse,
                              need_points + i, need_points + i + 1);
-  bounding_box (need_points, 4, &need_rect);
+  gegl_affine_bounding_box (need_points, 4, &need_rect);
 
   need_rect.x      += context_rect.x;
   need_rect.y      += context_rect.y;
@@ -576,9 +582,9 @@ get_required_for_output (GeglOperation       *op,
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *op,
-                           const gchar         *input_pad,
-                           const GeglRectangle *input_region)
+gegl_affine_get_invalidated_by_change (GeglOperation       *op,
+                                       const gchar         *input_pad,
+                                       const GeglRectangle *input_region)
 {
   OpAffine          *affine  = (OpAffine *) op;
   OpAffineClass     *klass   = OP_AFFINE_GET_CLASS (affine);
@@ -594,21 +600,21 @@ get_invalidated_by_change (GeglOperation       *op,
   context_rect = sampler->context_rect;
   /* invoke child's matrix creation function */
   g_assert (klass->create_matrix);
-  matrix3_identity (affine->matrix);
+  gegl_matrix3_identity (affine->matrix);
   klass->create_matrix (op, affine->matrix);
 
   if (affine->origin_x || affine->origin_y)
-    matrix3_originate (affine->matrix, affine->origin_x, affine->origin_y);
+    gegl_matrix3_originate (affine->matrix, affine->origin_x, affine->origin_y);
 
-  if (is_composite_node (affine))
+  if (gegl_affine_is_composite_node (affine))
     {
-      Matrix3 source;
+      GeglMatrix3 source;
 
-      get_source_matrix (affine, source);
-      matrix3_multiply (source, affine->matrix, affine->matrix);
+      gegl_affine_get_source_matrix (affine, source);
+      gegl_matrix3_multiply (source, affine->matrix, affine->matrix);
     }
-  if (is_intermediate_node (affine) ||
-      matrix3_is_identity (affine->matrix))
+  if (gegl_affine_is_intermediate_node (affine) ||
+      gegl_matrix3_is_identity (affine->matrix))
     {
       return region;
     }
@@ -631,27 +637,27 @@ get_invalidated_by_change (GeglOperation       *op,
   affected_points [7] = region.y + region.height ;
 
   for (i = 0; i < 8; i += 2)
-    matrix3_transform_point (affine->matrix,
+    gegl_matrix3_transform_point (affine->matrix,
                              affected_points + i, affected_points + i + 1);
 
-  bounding_box (affected_points, 4, &affected_rect);
+  gegl_affine_bounding_box (affected_points, 4, &affected_rect);
   return affected_rect;
 
 }
 
 
 static void
-affine_generic (GeglBuffer        *dest,
-                GeglBuffer        *src,
-                Matrix3            matrix,
-                GeglSampler       *sampler)
+affine_generic (GeglBuffer  *dest,
+                GeglBuffer  *src,
+                GeglMatrix3  matrix,
+                GeglSampler *sampler)
 {
   GeglBufferIterator *i;
   const GeglRectangle *dest_extent;
   gint                  x, y;
   gfloat               *dest_buf,
                        *dest_ptr;
-  Matrix3               inverse;
+  GeglMatrix3           inverse;
   gdouble               u_start,
                         v_start,
                         u_float,
@@ -677,8 +683,8 @@ affine_generic (GeglBuffer        *dest,
       GeglRectangle *roi = &i->roi[0];
       dest_buf           = (gfloat *)i->data[0];
 
-      matrix3_copy (inverse, matrix);
-      matrix3_invert (inverse);
+      gegl_matrix3_copy (inverse, matrix);
+      gegl_matrix3_invert (inverse);
 
       u_start = inverse[0][0] * roi->x + inverse[0][1] * roi->y + inverse[0][2];
       v_start = inverse[1][0] * roi->x + inverse[1][1] * roi->y + inverse[1][2];
@@ -711,43 +717,65 @@ void  gegl_sampler_prepare     (GeglSampler *self);
    */
 
 static gboolean
-process (GeglOperation       *operation,
-         GeglBuffer          *input,
-         GeglBuffer          *output,
-         const GeglRectangle *result)
+gegl_affine_process (GeglOperation        *operation,
+                     GeglOperationContext *context,
+                     const gchar          *output_prop,
+                     const GeglRectangle  *result)
 {
+  GeglBuffer          *input;
+  GeglBuffer          *output;
   OpAffine            *affine = (OpAffine *) operation;
 
-  if (is_intermediate_node (affine) ||
-      matrix3_is_identity (affine->matrix))
+  if (gegl_affine_is_intermediate_node (affine) ||
+      gegl_matrix3_is_identity (affine->matrix))
     {
-      /* XXX: make the copying smarter, by perhaps even COW sharing
-       * of tiles (in the gegl_buffer_copy code)
-       */
-      gegl_buffer_copy (input, NULL, output, NULL);
+      /* passing straight through (like gegl:nop) */
+      input  = gegl_operation_context_get_source (context, "input");
+      if (!input)
+        {
+          g_warning ("transform received NULL input");
+          return FALSE;
+        }
+
+      gegl_operation_context_take_object (context, "output", G_OBJECT (input));
     }
-#if 0  /* XXX: port to use newer APIs, perhaps not possible to achieve COW,
-                but should still be faster than a full resampling when it
-                is not needed */
-  else if (matrix3_is_translate (affine->matrix) &&
+  else if (gegl_matrix3_is_translate (affine->matrix) &&
            (! strcmp (affine->filter, "nearest") ||
             (affine->matrix [0][2] == (gint) affine->matrix [0][2] &&
              affine->matrix [1][2] == (gint) affine->matrix [1][2])))
     {
-      GeglRectangle input_rectangle = *result;
-      input_rectangle.x += (gint) affine->matrix [0][2];
-      input_rectangle.y += (gint) affine->matrix [1][2];
-      gegl_buffer_copy (input, NULL, output, &input_rectangle);
+      /* doing a buffer shifting trick, (enhanced nop) */
+      input  = gegl_operation_context_get_source (context, "input");
+
+      output = g_object_new (GEGL_TYPE_BUFFER,
+                             "source",    input,
+                             "shift-x",   (int)-affine->matrix[0][2],
+                             "shift-y",   (int)-affine->matrix[1][2],
+                             "abyss-width", -1,  /* turn of abyss
+                                                    (relying on abyss
+                                                    of source) */
+                         NULL);
+
+      gegl_operation_context_take_object (context, "output", G_OBJECT (output));
+
+      if (input != NULL)
+        g_object_unref (input);
     }
-#endif
   else
     {
-      /* XXX: add back more samplers */
+      /* for all other cases, do a proper resampling */
+
+      input  = gegl_operation_context_get_source (context, "input");
+      output = gegl_operation_context_get_target (context, "output");
+
       g_object_set(affine->sampler, "buffer", input, NULL);
       gegl_sampler_prepare (affine->sampler);
       affine_generic (output, input, affine->matrix, affine->sampler);
       g_object_unref(affine->sampler->buffer);
       affine->sampler->buffer = NULL;
+
+      if (input != NULL)
+        g_object_unref (input);
     }
 
   return TRUE;
