@@ -166,7 +166,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   /* specify the name this operation is found under in the GUI/when
    * programming/in XML
    */
-  operation_class->name        = "brightness-contrast";
+  operation_class->name        = "gegl:brightness-contrast";
 
   /* a colon separated list of categories/tags for this operations */
   operation_class->categories  = "color";
