@@ -27,7 +27,7 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_string(composite_op, _("Operation"), "over",
+gegl_chant_string(composite_op, _("Operation"), "gegl:over",
                   _("Composite operation to use"))
 gegl_chant_double(opacity, _("Opacity"), 0.0, 1.0, 1.0,
                   _("Opacity"))
@@ -37,7 +37,7 @@ gegl_chant_double(y, _("Y"), -G_MAXDOUBLE, G_MAXDOUBLE, 0.0,
                   _("Vertical position"))
 gegl_chant_double(scale, _("scale"), -G_MAXDOUBLE, G_MAXDOUBLE, 1.0,
                   _("Scale 1:1 size"))
-gegl_chant_path(src, _("Source"), "",
+gegl_chant_file_path(src, _("Source"), "",
                 _("Source datafile (png, jpg, raw, svg, bmp, tif, ...)"))
 
 #else
@@ -54,7 +54,7 @@ struct _GeglChant
   GeglNode *output;
 
   GeglNode *composite_op;
-  GeglNode *shift;
+  GeglNode *translate;
   GeglNode *opacity;
   GeglNode *scale;
   GeglNode *load;
@@ -75,7 +75,7 @@ typedef struct
 
 #define GEGL_CHANT_C_FILE "layer.c"
 #include "gegl-chant.h"
-GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_META);
+GEGL_DEFINE_DYNAMIC_OPERATION(GEGL_TYPE_OPERATION_META)
 
 #include <glib/gprintf.h>
 
@@ -123,7 +123,7 @@ prepare (GeglOperation *operation)
               g_free (name);
               g_warning ("load: %s", tmp);
               gegl_node_set (self->load,
-                             "operation", "text",
+                             "operation", "gegl:text",
                              "size", 12.0,
                              "string", tmp,
                              NULL);
@@ -169,7 +169,7 @@ prepare (GeglOperation *operation)
   if (o->x != self->p_x ||
       o->y != self->p_y)
     {
-      gegl_node_set (self->shift,
+      gegl_node_set (self->translate,
                      "x",  o->x,
                      "y",  o->y,
                      NULL);
@@ -197,19 +197,19 @@ static void attach (GeglOperation *operation)
                                          "operation", o->composite_op,
                                          NULL);
 
-  self->shift = gegl_node_new_child (gegl, "operation", "shift", NULL);
-  self->scale = gegl_node_new_child (gegl, "operation", "scale", NULL);
-  self->opacity = gegl_node_new_child (gegl, "operation", "opacity", NULL);
+  self->translate = gegl_node_new_child (gegl, "operation", "gegl:translate", NULL);
+  self->scale = gegl_node_new_child (gegl, "operation", "gegl:scale", NULL);
+  self->opacity = gegl_node_new_child (gegl, "operation", "gegl:opacity", NULL);
 
   self->load = gegl_node_new_child (gegl,
-                                    "operation", "text",
-                                    "string", "foo",
+                                    "operation", "gegl:text",
+                                    "string", "Load operation placeholder",
                                     NULL);
 
-  gegl_node_link_many (self->load, self->scale, self->opacity, self->shift,
+  gegl_node_link_many (self->load, self->scale, self->opacity, self->translate,
                        NULL);
   gegl_node_link_many (self->input, self->composite_op, self->output, NULL);
-  gegl_node_connect_from (self->composite_op, "aux", self->shift, "output");
+  gegl_node_connect_from (self->composite_op, "aux", self->translate, "output");
 }
 
 
@@ -237,7 +237,7 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   object_class->finalize = finalize;
 
-  operation_class->name        = "layer";
+  operation_class->name        = "gegl:layer";
   operation_class->categories  = "meta";
   operation_class->description = _("A layer in the traditional sense.");
   operation_class->attach = attach;
