@@ -17,12 +17,13 @@
  */
 
 #include "config.h"
+#include <stdlib.h>
 #include <glib/gi18n-lib.h>
 
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_path (path, _("File"), "/tmp/gegl-logo.svg", _("Path of file to load."))
+gegl_chant_file_path (path, _("File"), "/tmp/gegl-logo.svg", _("Path of file to load."))
 
 #else
 
@@ -60,7 +61,7 @@ load_cache (GeglChantO *op_magick_load)
       g_free (filename);
 
       xml = g_strdup_printf ("<gegl>"
-                             "<node operation='png-load' path='%s' />"
+                             "<node operation='gegl:png-load' path='%s' />"
                              "</gegl>",
                              escaped);
       g_free (escaped);
@@ -121,7 +122,7 @@ process (GeglOperation       *operation,
     return FALSE;
 
   /* overriding the predefined behavior */
-  gegl_operation_context_set_object (context, "output", G_OBJECT (o->chant_data));
+  gegl_operation_context_take_object (context, "output", G_OBJECT (o->chant_data));
   o->chant_data = NULL;
 
   return  TRUE;
@@ -140,7 +141,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->process = process;
   operation_class->get_bounding_box = get_bounding_box;
 
-  operation_class->name        = "magick-load";
+  operation_class->name        = "gegl:magick-load";
   operation_class->categories  = "hidden";
   operation_class->description =
         _("Image Magick wrapper using the png op.");
