@@ -24,20 +24,22 @@
 
 #ifdef GEGL_CHANT_PROPERTIES
 
-gegl_chant_int (radius, _("Radius"), 2, 5000.0, 300,
-                _("Neighbourhood taken into account"))
-gegl_chant_int (samples, _("Samples"), 0, 1000, 10,
-                _("Number of samples to do"))
+gegl_chant_int (radius, _("Radius"), 2, 3000.0, 300,
+                _("Neighbourhood taken into account, for enhancement ideal values are close to the longest side of the image, increasing this increases the runtime."))
+gegl_chant_int (samples, _("Samples"), 0, 1000, 4,
+                _("Number of samples to do per iteration looking for the range of colors."))
 gegl_chant_int (iterations, _("Iterations"), 0, 1000, 10,
-                _("Number of iterations (length of exposure)"))
-gegl_chant_boolean (same_spray, _("Same spray"), TRUE,
-                    _("Use the same spray for all pixels"))
+                _("Number of iterations, a higher number of iterations provides a less noisy rendering at computational cost."))
+
+
+/*
+
 gegl_chant_double (rgamma, _("Radial Gamma"), 0.0, 8.0, 2.0,
-                   _("Gamma applied to radial distribution"))
-gegl_chant_double (strength, _("Strength"), -10.0, 10.0, 1.0,
-                   _("Amount of correction 0=none 1.0=full"))
-gegl_chant_double (gamma, _("Gamma"), 0.0, 10.0, 1.0,
-                   _("Post correction gamma"))
+                _("Gamma applied to radial distribution"))
+
+*/
+
+
 
 #else
 
@@ -45,6 +47,10 @@ gegl_chant_double (gamma, _("Gamma"), 0.0, 10.0, 1.0,
 #define GEGL_CHANT_C_FILE       "stress.c"
 
 #include "gegl-chant.h"
+
+#define RGAMMA   2.0
+#define GAMMA    1.0
+
 #include <math.h>
 #include <stdlib.h>
 #include "envelopes.h"
@@ -54,15 +60,19 @@ static void stress (GeglBuffer *src,
                     gint        radius,
                     gint        samples,
                     gint        iterations,
-                    gboolean    same_spray,
-                    gdouble     rgamma,
-                    gdouble     strength,
-                    gdouble     gamma)
+                    gdouble     rgamma)
 {
   gint x,y;
   gint    dst_offset=0;
   gfloat *src_buf;
   gfloat *dst_buf;
+  gint    inw = gegl_buffer_get_width (src);
+  gint    inh = gegl_buffer_get_height (src);
+  gint   outw = gegl_buffer_get_width (dst);
+
+  /* this use of huge linear buffers should be avoided and
+   * most probably would lead to great speed ups
+   */
 
   src_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (src) * 4);
   dst_buf = g_new0 (gfloat, gegl_buffer_get_pixel_count (dst) * 4);
@@ -71,47 +81,38 @@ static void stress (GeglBuffer *src,
 
   for (y=radius; y<gegl_buffer_get_height (dst)+radius; y++)
     {
-      gint src_offset = ((gegl_buffer_get_width (src)*y)+radius)*4;
-      for (x=radius; x<gegl_buffer_get_width (dst)+radius; x++)
+      gint src_offset = (inw*y+radius)*4;
+      for (x=radius; x<outw+radius; x++)
         {
           gfloat *center_pix= src_buf + src_offset;
           gfloat  min_envelope[4];
           gfloat  max_envelope[4];
 
           compute_envelopes (src_buf,
-                             gegl_buffer_get_width (src),
-                             gegl_buffer_get_height (src),
+                             inw, inh,
                              x, y,
                              radius, samples,
                              iterations,
-                             same_spray,
+                             FALSE, /* same-spray */
                              rgamma,
                              min_envelope, max_envelope);
-         {
-          gint c;
-          gfloat pixel[3];
-          for (c=0;c<3;c++)
-            {
-              pixel[c] = center_pix[c];
-              if (min_envelope[c]!=max_envelope[c])
+           {
+              gint c;
+              for (c=0;c<3;c++)
                 {
-                  gfloat scaled = (pixel[c]-min_envelope[c])/(max_envelope[c]-min_envelope[c]);
-                  pixel[c] *= (1.0-strength);
-                  pixel[c] = strength * scaled;
+                  gfloat delta = max_envelope[c]-min_envelope[c];
+                  if (delta != 0)
+                    {
+                      dst_buf[dst_offset+c] =
+                         (center_pix[c]-min_envelope[c])/delta;
+                    }
+                  else
+                    {
+                      dst_buf[dst_offset+c] = 0.5;
+                    }
                 }
-            }
-          if (gamma==1.0)
-            {
-              for (c=0; c<3;c++)
-                dst_buf[dst_offset+c] = pixel[c];
-            }
-          else
-            {
-              for (c=0; c<3;c++)
-                dst_buf[dst_offset+c] = pow(pixel[c],gamma);
-            }
-          dst_buf[dst_offset+c] = center_pix[c];
-         }
+           }
+          dst_buf[dst_offset+3] = src_buf[src_offset+3];
           src_offset+=4;
           dst_offset+=4;
         }
@@ -154,10 +155,7 @@ process (GeglOperation       *operation,
           o->radius,
           o->samples,
           o->iterations,
-          o->same_spray,
-          o->rgamma,
-          o->strength,
-          o->gamma);
+          RGAMMA /*o->rgamma,*/);
 
   return  TRUE;
 }
@@ -174,7 +172,7 @@ gegl_chant_class_init (GeglChantClass *klass)
 
   filter_class->process = process;
   operation_class->prepare  = prepare;
-  /* we override defined region to avoid growing the size of what is defined
+  /* we override get_bounding_box to avoid growing the size of what is defined
    * by the filter. This also allows the tricks used to treat alpha==0 pixels
    * in the image as source data not to be skipped by the stochastic sampling
    * yielding correct edge behavior.
