@@ -61,19 +61,19 @@ static void attach (GeglOperation *operation)
       priv->input    = gegl_node_get_input_proxy (gegl, "input");
       priv->output   = gegl_node_get_output_proxy (gegl, "output");
       priv->add      = gegl_node_new_child (gegl,
-                                            "operation", "add",
+                                            "operation", "gegl:add",
                                             NULL);
 
       priv->multiply = gegl_node_new_child (gegl,
-                                            "operation", "multiply",
+                                            "operation", "gegl:multiply",
                                             NULL);
 
       priv->subtract = gegl_node_new_child (gegl,
-                                            "operation", "subtract",
+                                            "operation", "gegl:subtract",
                                             NULL);
 
       priv->blur     = gegl_node_new_child (gegl,
-                                            "operation", "gaussian-blur",
+                                            "operation", "gegl:gaussian-blur",
                                             NULL);
 
       gegl_node_link_many (priv->input, priv->subtract, priv->multiply, NULL);
@@ -100,7 +100,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class = GEGL_OPERATION_CLASS (klass);
   operation_class->attach = attach;
 
-  operation_class->name        = "unsharp-mask";
+  operation_class->name        = "gegl:unsharp-mask";
   operation_class->categories  = "meta:enhance";
   operation_class->description =
         _("Performs an unsharp mask on the input buffer (sharpens an image by "
