@@ -98,7 +98,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   point_filter_class->process = process;
   operation_class->prepare = prepare;
 
-  operation_class->name        = "whitebalance";
+  operation_class->name        = "gegl:whitebalance";
   operation_class->categories  = "color";
   operation_class->description =
         _("Allows changing the whitepoint and blackpoint of an image.");
