@@ -37,9 +37,9 @@ gegl_chant_double (height, _("Height"), -G_MAXFLOAT, G_MAXFLOAT, 10.0, _("Height
 #include <math.h>
 
 static GeglNode *
-detect (GeglOperation *operation,
-        gint           x,
-        gint           y)
+gegl_crop_detect (GeglOperation *operation,
+                  gint           x,
+                  gint           y)
 {
   GeglChantO *o = GEGL_CHANT_PROPERTIES (operation);
   GeglNode   *input_node;
@@ -56,7 +56,7 @@ detect (GeglOperation *operation,
 
 
 static GeglRectangle
-get_bounding_box (GeglOperation *operation)
+gegl_crop_get_bounding_box (GeglOperation *operation)
 {
   GeglChantO    *o = GEGL_CHANT_PROPERTIES (operation);
   GeglRectangle *in_rect = gegl_operation_source_get_bounding_box (operation, "input");
@@ -74,12 +74,17 @@ get_bounding_box (GeglOperation *operation)
 }
 
 static GeglRectangle
-get_invalidated_by_change (GeglOperation       *operation,
-                         const gchar         *input_pad,
-                         const GeglRectangle *input_region)
+gegl_crop_get_invalidated_by_change (GeglOperation       *operation,
+                                     const gchar         *input_pad,
+                                     const GeglRectangle *input_region)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
-  GeglRectangle result = {o->x, o->y, o->width, o->height};
+  GeglRectangle result;
+
+  result.x = o->x;
+  result.y = o->y;
+  result.width = o->width;
+  result.height = o->height;
 
   gegl_rectangle_intersect (&result, &result, input_region);
 
@@ -87,26 +92,37 @@ get_invalidated_by_change (GeglOperation       *operation,
 }
 
 static GeglRectangle
-get_required_for_output (GeglOperation       *operation,
-                         const gchar         *input_pad,
-                         const GeglRectangle *roi)
+gegl_crop_get_required_for_output (GeglOperation       *operation,
+                                   const gchar         *input_pad,
+                                   const GeglRectangle *roi)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
-  GeglRectangle result = {o->x, o->y, o->width, o->height};
+  GeglRectangle result;
+
+  result.x = o->x;
+  result.y = o->y;
+  result.width = o->width;
+  result.height = o->height;
+
   gegl_rectangle_intersect (&result, &result, roi);
   return result;
 }
 
 static gboolean
-process (GeglOperation       *operation,
-         GeglOperationContext     *context,
-         const gchar         *output_prop,
-         const GeglRectangle *result)
+gegl_crop_process (GeglOperation        *operation,
+                   GeglOperationContext *context,
+                   const gchar          *output_prop,
+                   const GeglRectangle  *result)
 {
   GeglChantO   *o = GEGL_CHANT_PROPERTIES (operation);
   GeglBuffer   *input;
   gboolean      success = FALSE;
-  GeglRectangle extent = {o->x, o->y, o->width, o->height};
+  GeglRectangle extent;
+
+  extent.x = o->x;
+  extent.y = o->y;
+  extent.width = o->width;
+  extent.height = o->height;
 
   if (strcmp (output_prop, "output"))
     {
@@ -121,7 +137,7 @@ process (GeglOperation       *operation,
       GeglBuffer *output;
 
       output = gegl_buffer_create_sub_buffer (input, &extent);
-      gegl_operation_context_set_object (context, "output", G_OBJECT (output));
+      gegl_operation_context_take_object (context, "output", G_OBJECT (output));
       g_object_unref (input);
       success = TRUE;
     }
@@ -143,12 +159,12 @@ gegl_chant_class_init (GeglChantClass *klass)
   GeglOperationClass *operation_class;
 
   operation_class = GEGL_OPERATION_CLASS (klass);
-  operation_class->process = process;
-  operation_class->get_bounding_box = get_bounding_box;
-  operation_class->detect = detect;
-  operation_class->get_invalidated_by_change = get_invalidated_by_change;
-  operation_class->get_bounding_box = get_bounding_box;
-  operation_class->get_required_for_output = get_required_for_output;
+
+  operation_class->process                   = gegl_crop_process;
+  operation_class->get_bounding_box          = gegl_crop_get_bounding_box;
+  operation_class->detect                    = gegl_crop_detect;
+  operation_class->get_invalidated_by_change = gegl_crop_get_invalidated_by_change;
+  operation_class->get_required_for_output   = gegl_crop_get_required_for_output;
 
   operation_class->name        = "gegl:crop";
   operation_class->categories  = "core";
