@@ -117,7 +117,12 @@ gegl_buffer_import_jpg (GeglBuffer  *gegl_buffer,
 
   while (cinfo.output_scanline < cinfo.output_height)
     {
-      GeglRectangle rect = {dest_x, dest_y + row++, cinfo.output_width, 1};
+      GeglRectangle rect;
+
+      rect.x = dest_x;
+      rect.y = dest_y + row++;
+      rect.width = cinfo.output_width;
+      rect.height = 1;
 
       jpeg_read_scanlines (&cinfo, buffer, 1);
       gegl_buffer_set (gegl_buffer, &rect, babl_format ("R'G'B' u8"), buffer[0],
@@ -209,13 +214,13 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->categories  = "hidden";
   operation_class->description = _("JPG image loader");
 
-//  static gboolean done=FALSE;
-//  if (done)
-//    return;
+/*  static gboolean done=FALSE;
+    if (done)
+      return; */
   gegl_extension_handler_register (".jpg", "gegl:jpg-load");
   gegl_extension_handler_register (".JPG", "gegl:jpg-load");
   gegl_extension_handler_register (".jpeg", "gegl:jpg-load");
   gegl_extension_handler_register (".JPEG", "gegl:jpg-load");
-//  done = TRUE;
+/*  done = TRUE; */
 }
 #endif
