@@ -89,14 +89,11 @@ gegl_buffer_export_png (GeglBuffer  *gegl_buffer,
 
   {
     const Babl *babl; /*= gegl_buffer->format;*/
-    BablType   **type;
 
     g_object_get (gegl_buffer, "format", &babl, NULL);
-    type = babl->format.type;
 
-    for (i=0; i<babl->format.components; i++)
-      if ((*type)->bits > 8)
-        bit_depth = 16;
+    if (babl_format_get_type (babl, 0) != babl_type ("u8"))
+      bit_depth = 16;
 
     if (bd == 16)
       bit_depth = 16;
@@ -156,7 +153,13 @@ gegl_buffer_export_png (GeglBuffer  *gegl_buffer,
 
   for (i=0; i< height; i++)
     {
-      GeglRectangle rect = {src_x, src_y+i, width, 1};
+      GeglRectangle rect;
+
+      rect.x = src_x;
+      rect.y = src_y+i;
+      rect.width = width;
+      rect.height = 1;
+
       gegl_buffer_get (gegl_buffer, 1.0, &rect, babl_format (format_string), pixels, GEGL_AUTO_ROWSTRIDE);
 
       png_write_rows (png, &pixels, 1);
