@@ -28,7 +28,7 @@ gegl_chant_string (font, _("Font family"), "Sans",
                    _("Font family (utf8)"))
 gegl_chant_double (size, _("Size"), 1.0, 2048.0, 10.0,
                    _("Approximate height of text in pixels."))
-gegl_chant_color  (color, _("Color"), "white",
+gegl_chant_color  (color, _("Color"), "black",
                    _("Color for the text (defaults to 'white')"))
 gegl_chant_int    (wrap, _("Wrap width"), -1, 1000000, -1,
                    _("Sets the width in pixels at which long lines will wrap. "
@@ -73,7 +73,7 @@ typedef struct
 
 #define GEGL_CHANT_C_FILE "text.c"
 #include "gegl-chant.h"
-GEGL_DEFINE_DYNAMIC_OPERATION (GEGL_TYPE_OPERATION_SOURCE);
+GEGL_DEFINE_DYNAMIC_OPERATION (GEGL_TYPE_OPERATION_SOURCE)
 
 
 
@@ -123,8 +123,7 @@ static void text_layout_text (GeglChant *self,
   attrs = pango_attr_list_new ();
   if (attrs)
   {
-    gegl_color_get_rgba (o->color,
-                         &color[0], &color[1], &color[2], &color[3]);
+    gegl_color_get_rgba4f (o->color, color);
     attr = pango_attr_foreground_new ((guint16) (color[0] * 65535),
                                       (guint16) (color[1] * 65535),
                                       (guint16) (color[2] * 65535));
