@@ -170,7 +170,7 @@ gegl_chant_class_init (GeglChantClass *klass)
   operation_class->get_required_for_output = get_required_for_output;
   operation_class->get_bounding_box = get_bounding_box;
 
-  operation_class->name        = "line-profile";
+  operation_class->name        = "gegl:line-profile";
   operation_class->categories  = "debug";
   operation_class->description =
         _("Renders luminance profiles for red green and blue components along"
