@@ -157,6 +157,8 @@ class Function
 
 
     def to_html
+
+
         ret = "<div class='function'>
                  <!--<h3>#{@name}</h3>-->
                  <div class='function_signature'>
@@ -168,7 +170,7 @@ class Function
 
         first=true
         i=0
-        if @arguments.length==0
+        if @arguments.length==0 and @return_type!=""
             ret += "<div class='argument'><div class='arg_type'><span class='const'>(void)</span></div></div>\n"
         end
         @arguments.each {|arg|
@@ -316,6 +318,10 @@ arg_no=0
 (ARGV.length-1).times {
     |file_no|
 line_no=0
+
+state=:none
+puts ARGV[file_no]
+
 IO.foreach(ARGV[file_no]) {
     |line|
     line_no = line_no+1
@@ -556,7 +562,7 @@ File.open("gegl.devhelp", "w") {|file|
     IO.foreach("operations.html"){ |line|
         if line =~ /^<li><a href='#op_.*'>.*<\/a><\/li>/
             opname=line.gsub(/.*op_/,'').gsub(/'.*/,'').strip
-            file.puts "<function name='gegl-#{opname}' link='operations.html#op_#{opname}'/>"
+            file.puts "<function name='#{opname}' link='operations.html#op_#{opname}'/>"
         end
     }
 
